import { forwardRef, Input } from '@angular/core';
import { TrendLineType, TrendLineType_$type } from "igniteui-angular-core/ES2015/TrendLineType";
import { CategorySeriesMarkerCollisionAvoidance, CategorySeriesMarkerCollisionAvoidance_$type } from "./CategorySeriesMarkerCollisionAvoidance";
import { ConsolidatedItemHitTestBehavior, ConsolidatedItemHitTestBehavior_$type } from "./ConsolidatedItemHitTestBehavior";
import { IgxCategorySeriesComponent } from "./igx-category-series-component";
import { IgxMarkerSeriesComponent } from "./igx-marker-series-component";
import { IgxSeriesComponent } from "./igx-series-component";
import { ensureEnum, brushToString, stringToBrush, toPoint } from "igniteui-angular-core/ES2015/componentUtil";
/**
 * Represents the base class for all IgxDataChartComponent anchored category/value series.
*/
export const IgxAnchoredCategorySeriesComponent_PROVIDERS = [{ provide: IgxCategorySeriesComponent, useExisting: forwardRef(() => IgxAnchoredCategorySeriesComponent) }, { provide: IgxMarkerSeriesComponent, useExisting: forwardRef(() => IgxAnchoredCategorySeriesComponent) }, { provide: IgxSeriesComponent, useExisting: forwardRef(() => IgxAnchoredCategorySeriesComponent) }];
export class IgxAnchoredCategorySeriesComponent extends IgxCategorySeriesComponent {
    constructor() {
        super();
    }
    get i() {
        return this._implementation;
    }
    /**
         * Gets or sets the value mapping property for the current series object.
        */
    get valueMemberPath() {
        return this.i.ov;
    }
    set valueMemberPath(v) {
        this.i.ov = v;
    }
    /**
         * Gets or sets the trend type for the current series object.
        */
    get trendLineType() {
        return this.i.trendLineType;
    }
    set trendLineType(v) {
        this.i.trendLineType = ensureEnum(TrendLineType_$type, v);
    }
    /**
         * Gets or sets the brush to use to draw the trend line.
        */
    get trendLineBrush() {
        return brushToString(this.i.trendLineBrush);
    }
    set trendLineBrush(v) {
        this.i.trendLineBrush = stringToBrush(v);
    }
    /**
         * Gets the effective TrendLineBrush for this series.
        */
    get actualTrendLineBrush() {
        return brushToString(this.i.pc);
    }
    /**
         * Gets or sets the thickness of the current series object's trend line.
        */
    get trendLineThickness() {
        return this.i.trendLineThickness;
    }
    set trendLineThickness(v) {
        this.i.trendLineThickness = +v;
    }
    /**
         * Gets or sets the trend line period for the current series.
         * The typical, and initial, value for trend line period is 7.
        */
    get trendLinePeriod() {
        return this.i.trendLinePeriod;
    }
    set trendLinePeriod(v) {
        this.i.trendLinePeriod = +v;
    }
    /**
         * The desired behavior for markers in this series which are placed too close together for the current view, resulting in a collision.
        */
    get markerCollisionAvoidance() {
        return this.i.oi;
    }
    set markerCollisionAvoidance(v) {
        this.i.oi = ensureEnum(CategorySeriesMarkerCollisionAvoidance_$type, v);
    }
    /**
         * Determines the item returned in hit-testing when the pointer is over an object which represents several consolidated items.
        */
    get consolidatedItemHitTestBehavior() {
        return this.i.oj;
    }
    set consolidatedItemHitTestBehavior(v) {
        this.i.oj = ensureEnum(ConsolidatedItemHitTestBehavior_$type, v);
    }
    /**
         * Scrolls the series to display the item for the specified data item.
         * The series is scrolled by the minimum amount required to place the specified data item within
         * the central 80% of the visible axis.
        
        * @param item  * The data item (item) to scroll to.
        */
    scrollIntoView(item) {
        let iv = this.i.c6(item);
        return (iv);
    }
    /**
         * Gets the item that is the best match for the specified world coordinates.
        
        * @param world  * The world coordinates to use.
        */
    getItem(world) {
        let iv = this.i.ff(toPoint(world));
        return (iv);
    }
}
IgxAnchoredCategorySeriesComponent.propDecorators = {
    "valueMemberPath": [{ type: Input },],
    "trendLineType": [{ type: Input },],
    "trendLineBrush": [{ type: Input },],
    "trendLineThickness": [{ type: Input },],
    "trendLinePeriod": [{ type: Input },],
    "markerCollisionAvoidance": [{ type: Input },],
    "consolidatedItemHitTestBehavior": [{ type: Input },],
};
//# sourceMappingURL=igx-anchored-category-series-component.js.map