import { Type } from '@angular/core';
import { IgRect } from "igniteui-angular-core/ES2015/IgRect";
import { IgPoint } from "igniteui-angular-core/ES2015/IgPoint";
import { IgxAxisComponent } from './igx-axis-component';
import { CategoryAxisBase } from './CategoryAxisBase';
export declare const IgxCategoryAxisBaseComponent_PROVIDERS: {
    provide: typeof IgxAxisComponent;
    useExisting: Type<any>;
}[];
/**
 * Represents the base class for all IgxDataChartComponent category-based axes.
*/
export declare abstract class IgxCategoryAxisBaseComponent extends IgxAxisComponent {
    constructor();
    private _chartLevelData;
    provideData(data: any[]): void;
    private updateDataSource();
    private _dataSource;
    dataSource: any;
    readonly i: CategoryAxisBase;
    /**
 * Gets if the current axis is a continuous rather than a discrete scale
*/
    readonly isContinuous: boolean;
    /**
     * Checks if the axis is of category axis type
    */
    readonly isCategory: boolean;
    /**
     * Gets the number of items in the current category axis items source.
    */
    readonly itemsCount: number;
    /**
     * Gets or sets the amount of space between adjacent categories for the current axis object.
     * The gap is silently clamped to the range [0, 1] when used.
    */
    gap: number;
    /**
     * Gets or sets the amount of overlap between adjacent categories for the current axis object.
     * The overlap is silently clamped to the range [-1, 1] when used.
    */
    overlap: number;
    /**
     * Gets or sets whether the category axis should use clustering display mode even if no series are present that would force clustering mode.
    */
    useClusteringMode: boolean;
    getCategoryBoundingBox(point: IgPoint, useInterpolation: boolean, singularWidth: number): IgRect;
    getCategoryBoundingBoxHelper(point: IgPoint, useInterpolation: boolean, singularWidth: number, isVertical: boolean): IgRect;
    /**
     * Unscales a value from screen space into axis space.
    
    * @param unscaledValue  * The scaled value in screen coordinates to unscale into axis space.
    */
    unscaleValue(unscaledValue: number): number;
    notifySetItem(index: number, oldItem: any, newItem: any): void;
    /**
     * Used to manually notify the axis that the data source has reset or cleared its items.
    
    */
    notifyClearItems(): void;
    notifyInsertItem(index: number, newItem: any): void;
    notifyRemoveItem(index: number, oldItem: any): void;
}
