/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Input, forwardRef } from '@angular/core';
import { IgxAxisComponent } from './igx-axis-component';
import { toPoint, fromRect, ensureBool } from "igniteui-angular-core/ES2015/componentUtil";
export const IgxCategoryAxisBaseComponent_PROVIDERS = [{ provide: IgxAxisComponent, useExisting: forwardRef(() => IgxCategoryAxisBaseComponent) }];
/**
 * Represents the base class for all IgxDataChartComponent category-based axes.
*/
export class IgxCategoryAxisBaseComponent extends IgxAxisComponent {
    constructor() {
        super();
        this._chartLevelData = null;
        this._dataSource = null;
    }
    provideData(data) {
        this._chartLevelData = data;
        this.updateDataSource();
    }
    updateDataSource() {
        if (this._dataSource == null) {
            this.i.itemsSource = this._chartLevelData;
        }
        else {
            this.i.itemsSource = this._dataSource;
        }
    }
    set dataSource(value) {
        this._dataSource = value;
        this.updateDataSource();
        //console.log("setting axis data source: " + value)
    }
    get dataSource() {
        if (this._dataSource != null) {
            return this._dataSource;
        }
        return this.i.itemsSource;
    }
    get i() {
        return this._implementation;
    }
    /**
         * Gets if the current axis is a continuous rather than a discrete scale
        */
    get isContinuous() {
        return this.i.b4;
    }
    /**
         * Checks if the axis is of category axis type
        */
    get isCategory() {
        return this.i.b2;
    }
    /**
         * Gets the number of items in the current category axis items source.
        */
    get itemsCount() {
        return this.i.jr;
    }
    /**
         * Gets or sets the amount of space between adjacent categories for the current axis object.
         * The gap is silently clamped to the range [0, 1] when used.
        */
    get gap() {
        return this.i.jg;
    }
    set gap(v) {
        this.i.jg = +v;
    }
    /**
         * Gets or sets the amount of overlap between adjacent categories for the current axis object.
         * The overlap is silently clamped to the range [-1, 1] when used.
        */
    get overlap() {
        return this.i.jn;
    }
    set overlap(v) {
        this.i.jn = +v;
    }
    /**
         * Gets or sets whether the category axis should use clustering display mode even if no series are present that would force clustering mode.
        */
    get useClusteringMode() {
        return this.i.jb;
    }
    set useClusteringMode(v) {
        this.i.jb = ensureBool(v);
    }
    getCategoryBoundingBox(point, useInterpolation, singularWidth) {
        let iv = this.i.km(toPoint(point), useInterpolation, singularWidth);
        return fromRect(iv);
    }
    getCategoryBoundingBoxHelper(point, useInterpolation, singularWidth, isVertical) {
        let iv = this.i.kn(toPoint(point), useInterpolation, singularWidth, isVertical);
        return fromRect(iv);
    }
    /**
         * Unscales a value from screen space into axis space.
        
        * @param unscaledValue  * The scaled value in screen coordinates to unscale into axis space.
        */
    unscaleValue(unscaledValue) {
        let iv = this.i.jo(unscaledValue);
        return (iv);
    }
    notifySetItem(index, oldItem, newItem) {
        this.i.j9(index, oldItem, newItem);
    }
    /**
         * Used to manually notify the axis that the data source has reset or cleared its items.
        
        */
    notifyClearItems() {
        this.i.j6();
    }
    notifyInsertItem(index, newItem) {
        this.i.j7(index, newItem);
    }
    notifyRemoveItem(index, oldItem) {
        this.i.j8(index, oldItem);
    }
}
IgxCategoryAxisBaseComponent.propDecorators = {
    "dataSource": [{ type: Input },],
    "gap": [{ type: Input },],
    "overlap": [{ type: Input },],
    "useClusteringMode": [{ type: Input },],
};
//# sourceMappingURL=igx-category-axis-base-component.js.map