import { Component, ViewContainerRef, Injector, ComponentFactoryResolver, Renderer2, ViewChild, Inject, Input, NgZone, ChangeDetectionStrategy } from '@angular/core';
import { DOCUMENT } from '@angular/platform-browser';
import { AngularRenderer, AngularWrapper } from "igniteui-angular-core/ES2015/angular-renderer";
import { TypeRegistrar } from "igniteui-angular-core/ES2015/type";
import { CategoryChart } from './CategoryChart';
import { CategoryChartType, CategoryChartType_$type } from './CategoryChartType';
import { CategorySeriesMarkerCollisionAvoidance, CategorySeriesMarkerCollisionAvoidance_$type } from './CategorySeriesMarkerCollisionAvoidance';
import { CategoryTransitionInMode, CategoryTransitionInMode_$type } from './CategoryTransitionInMode';
import { TransitionInSpeedType, TransitionInSpeedType_$type } from './TransitionInSpeedType';
import { fromBrushCollection, toBrushCollection, ensureEnum, ensureBool } from "igniteui-angular-core/ES2015/componentUtil";
import { IgxXYChartComponent } from './igx-xy-chart-component';
import { DataChartStylingDefaults } from './DataChartStylingDefaults';
import { DataSeriesType } from "igniteui-angular-core/ES2015/DataSeriesType";
import { DataContext } from "igniteui-angular-core/ES2015/igx-data-context";
import { IgxCategoryXAxisComponent } from './igx-category-x-axis-component';
import { IgxNumericYAxisComponent } from './igx-numeric-y-axis-component';
export const IgxCategoryChartComponent_PROVIDERS = [];
/**
 * Represents a chart with an ordinal X-axis and a numeric Y-axis.
*/
export class IgxCategoryChartComponent extends IgxXYChartComponent {
    constructor(renderer, _elRef, document, ngZone, injector, componentFactoryResolver) {
        super();
        this.renderer = renderer;
        this._elRef = _elRef;
        this.document = document;
        this.ngZone = ngZone;
        this.injector = injector;
        this.componentFactoryResolver = componentFactoryResolver;
        this._dataSource = null;
        this._defaultTooltips = null;
        this._zoneRunner = (act) => ngZone.run(act);
        this.container = renderer.createElement("div");
        renderer.appendChild(_elRef.element.nativeElement, this.container);
        renderer.setStyle(this.container, "display", "block");
        renderer.setStyle(this.container, "width", "100%");
        renderer.setStyle(this.container, "height", "100%");
        var root;
        root = this.container;
        if (this.container != null) {
            root = this.container;
        }
        var ren = new AngularRenderer(root, this.renderer, this.document, this.ngZone, true, DataChartStylingDefaults);
        this._wrapper = ren;
        var chart = this.i;
        this._chart = chart;
        if (chart.xAxis) {
            let x = new IgxCategoryXAxisComponent();
            x._provideRenderer(ren);
            x._implementation = chart.xAxis;
            chart.xAxis.externalObject = x;
        }
        if (chart.yAxis) {
            let y = new IgxNumericYAxisComponent();
            y._provideRenderer(ren);
            y._implementation = chart.yAxis;
            chart.yAxis.externalObject = y;
        }
        chart.provideContainer(ren);
        this.bindData();
        chart.notifyResized();
        ren.addSizeWatcher(() => {
            this._chart.notifyResized();
        });
    }
    set height(value) {
        this._height = value;
        this.renderer.setStyle(this._elRef.element.nativeElement, "height", value);
        this._chart.notifyResized();
    }
    get height() {
        return this._height;
    }
    set width(value) {
        this._width = value;
        this.renderer.setStyle(this._elRef.element.nativeElement, "width", value);
        this._chart.notifyResized();
    }
    get width() {
        return this._width;
    }
    ngOnDestroy() {
        this._chart.destroy();
        this._wrapper.destroy();
    }
    createImplementation() {
        return new CategoryChart();
    }
    get i() {
        return this._implementation;
    }
    createSeriesComponent(type) {
        if (TypeRegistrar.isRegistered(type)) {
            let s = TypeRegistrar.create(type);
            s.owner = this;
            s._provideRenderer(this.renderer);
            return s;
        }
        else {
            //we shouldn't get here, hopefully.
            throw Error("series type not loaded: " + type);
        }
    }
    createSeries(type) {
        switch (type) {
            case DataSeriesType.Area:
                return this.createSeriesComponent('IgxAreaSeriesComponent');
            case DataSeriesType.Column:
                return this.createSeriesComponent('IgxColumnSeriesComponent');
            case DataSeriesType.Line:
                return this.createSeriesComponent('IgxLineSeriesComponent');
            case DataSeriesType.Point:
                return this.createSeriesComponent('IgxPointSeriesComponent');
            case DataSeriesType.Spline:
                return this.createSeriesComponent('IgxSplineSeriesComponent');
            case DataSeriesType.SplineArea:
                return this.createSeriesComponent('IgxSplineAreaSeriesComponent');
            case DataSeriesType.StepArea:
                return this.createSeriesComponent('IgxStepAreaSeriesComponent');
            case DataSeriesType.StepLine:
                return this.createSeriesComponent('IgxStepLineSeriesComponent');
            case DataSeriesType.Waterfall:
                return this.createSeriesComponent('IgxWaterfallSeriesComponent');
            default:
                return this.createSeriesComponent('IgxColumnSeriesComponent');
        }
    }
    set dataSource(value) {
        this._dataSource = value;
        this.bindData();
    }
    get dataSource() {
        return this._dataSource;
    }
    bindData() {
        if (this._chart != null && this._chart !== undefined) {
            this._chart.itemsSource = this._dataSource;
        }
    }
    ngAfterContentInit() {
        if (TypeRegistrar.isRegistered("IgxDataChartDefaultTooltipsComponent")) {
            let c = TypeRegistrar.get("IgxDataChartDefaultTooltipsComponent");
            let cf = this.componentFactoryResolver.resolveComponentFactory(c);
            //let cr = cf.create(this.injector);
            let cr = this._dynamicContent.createComponent(cf);
            this._defaultTooltips = cr;
            cr.instance.onContentReady.subscribe(() => {
                this._onDefaultTooltipsReady(cr);
            });
            this.container.appendChild(cr.location.nativeElement);
        }
    }
    createTooltip() {
        if (!TypeRegistrar.isRegistered("IgxTooltipContainerComponent")) {
            return null;
        }
        let t = TypeRegistrar.get("IgxTooltipContainerComponent");
        let cf = this.componentFactoryResolver.resolveComponentFactory(t);
        //let cr = cf.create(this.injector);
        let cr = this._dynamicContent.createComponent(cf);
        let ele = cr.location.nativeElement;
        let self = this;
        ele.updateToolTip = function (c) {
            if (c.externalObject) {
                c = c.externalObject;
            }
            else {
                let ext = new DataContext();
                ext._implementation = c;
                c = ext;
            }
            if (ele.parentElement != self.container) {
                if (ele.parentElement != null) {
                    ele.parentElement.removeChild(ele);
                }
                self.container.appendChild(ele);
            }
            cr.instance.context = c;
            ele.style.display = "block";
            return true;
        };
        ele.hideToolTip = function () {
            ele.style.display = "none";
        };
        ele.style.display = "none";
        return cr;
    }
    _ensureTooltipCreated(series) {
        series._ensureTooltipCreated(() => this.createTooltip(), (ele) => {
            let wrapper = new AngularWrapper(ele, this.renderer, this.ngZone);
            wrapper.updateToolTip = ele.updateToolTip;
            wrapper.hideToolTip = ele.hideToolTip;
            return wrapper;
        });
    }
    _createXAxis() {
        let x = new IgxCategoryXAxisComponent();
        x._provideRenderer(this.renderer);
        return x.i;
    }
    _createYAxis() {
        let y = new IgxNumericYAxisComponent();
        y.provideRenderer(this.renderer);
        return y.i;
    }
    _ensureDefaultTooltip(series) {
        if (this._defaultTooltips == null) {
            return;
        }
        this._defaultTooltips.instance["ensureDefaultTooltip"](series);
    }
    _onDefaultTooltipsReady(cr) {
        if (this.i.dataChart) {
            var currSeries = this.i.dataChart.series;
            for (var i = 0; i < currSeries.count; i++) {
                if (currSeries.item(i).externalObject.showDefaultTooltip) {
                    this._ensureDefaultTooltip(currSeries.item(i).externalObject);
                }
            }
        }
    }
    /**
         * Gets or sets the duration used for animating series plots when the chart is loading into view
        */
    get transitionInDuration() {
        return this.i.oh;
    }
    set transitionInDuration(v) {
        this.i.oh = +v;
    }
    /**
         * Gets or sets the easing function used for animating series plots when the chart is loading into view
         * This can be set to one of the known values "linear" or "cubic," or it can be set to an easing function which takes a single numeric parameter and returns a number.
        */
    get transitionInEasingFunction() {
        return this.i.ni;
    }
    set transitionInEasingFunction(v) {
        this.i.ni = v;
    }
    /**
         * Gets or sets the type of chart series to generate from the data.
        */
    get chartType() {
        return this.i.m3;
    }
    set chartType(v) {
        this.i.m3 = ensureEnum(CategoryChartType_$type, v);
    }
    /**
         * Gets or sets the behavior for markers in each series which are placed too close together for the current view, resulting in a collision.
        */
    get markerCollisionAvoidance() {
        return this.i.m5;
    }
    set markerCollisionAvoidance(v) {
        this.i.m5 = ensureEnum(CategorySeriesMarkerCollisionAvoidance_$type, v);
    }
    /**
         * Gets or sets whether animation of series plots is enabled when the chart is loading into view
        */
    get isTransitionInEnabled() {
        return this.i.no;
    }
    set isTransitionInEnabled(v) {
        this.i.no = ensureBool(v);
    }
    /**
         * Gets or sets the method that determines how to animate series plots when the chart is loading into view
        */
    get transitionInMode() {
        return this.i.m7;
    }
    set transitionInMode(v) {
        this.i.m7 = ensureEnum(CategoryTransitionInMode_$type, v);
    }
    /**
         * Gets or sets the arrival speed used for animating series plots when the chart is loading into view
        */
    get transitionInSpeedType() {
        return this.i.ng;
    }
    set transitionInSpeedType(v) {
        this.i.ng = ensureEnum(TransitionInSpeedType_$type, v);
    }
    /**
         * Gets or sets the frequency of displayed labels along the X-axis.
         * Gets or sets the set value is a factor that determines which labels will be hidden. For example, an interval of 2 will display every other label.
        */
    get xAxisInterval() {
        return this.i.n6;
    }
    set xAxisInterval(v) {
        this.i.n6 = +v;
    }
    /**
         * Gets or sets the frequency of displayed minor lines along the X-axis.
         * Gets or sets the set value is a factor that determines how the minor lines will be displayed.
        */
    get xAxisMinorInterval() {
        return this.i.n7;
    }
    set xAxisMinorInterval(v) {
        this.i.n7 = +v;
    }
    /**
         * Gets or sets the amount of space between adjacent categories for the X-axis.
         * The gap is silently clamped to the range [0, 1] when used.
        */
    get xAxisGap() {
        return this.i.n5;
    }
    set xAxisGap(v) {
        this.i.n5 = +v;
    }
    /**
         * Gets or sets the amount of overlap between adjacent categories for the X-axis.
         * Gets or sets the overlap is silently clamped to the range [-1, 1] when used.
        */
    get xAxisOverlap() {
        return this.i.n8;
    }
    set xAxisOverlap(v) {
        this.i.n8 = +v;
    }
    /**
         * Gets or sets the distance between each label and grid line along the Y-axis.
        */
    get yAxisInterval() {
        return this.i.ob;
    }
    set yAxisInterval(v) {
        this.i.ob = +v;
    }
    /**
         * Gets or sets whether the Y-axis should use a logarithmic scale instead of a linear one.
         * Since log(-1) is imaginary and log(0) is undefined, it is recommended to enable this property only when the Y-axis minimum is greater than zero.
        */
    get yAxisIsLogarithmic() {
        return this.i.nq;
    }
    set yAxisIsLogarithmic(v) {
        this.i.nq = ensureBool(v);
    }
    /**
         * Gets or sets the base value to use in the log function when mapping the position of data items along the Y-axis.
         * This property is effective only when YAxisIsLogarithmic is true.
        */
    get yAxisLogarithmBase() {
        return this.i.oi;
    }
    set yAxisLogarithmBase(v) {
        this.i.oi = +v;
    }
    /**
         * Gets or sets the data value corresponding to the minimum value of the Y-axis.
        */
    get yAxisMinimumValue() {
        return this.i.od;
    }
    set yAxisMinimumValue(v) {
        this.i.od = +v;
    }
    /**
         * Gets or sets the data value corresponding to the maximum value of the Y-axis.
        */
    get yAxisMaximumValue() {
        return this.i.oc;
    }
    set yAxisMaximumValue(v) {
        this.i.oc = +v;
    }
    /**
         * Gets or sets the frequency of displayed minor lines along the Y-axis.
        */
    get yAxisMinorInterval() {
        return this.i.oe;
    }
    set yAxisMinorInterval(v) {
        this.i.oe = +v;
    }
    /**
         * Gets the current minimum value for the X-axis.
        */
    get xAxisActualMinimum() {
        return this.i.n4;
    }
    /**
         * Gets the current maximum value for the X-axis.
        */
    get xAxisActualMaximum() {
        return this.i.n3;
    }
    /**
         * Gets the current minimum value for the Y-axis.
        */
    get yAxisActualMinimum() {
        return this.i.oa;
    }
    /**
         * Gets the current maximum value for the Y-axis.
        */
    get yAxisActualMaximum() {
        return this.i.n9;
    }
    /**
         * Gets or sets the palette used for coloring negative items of Waterfall chart type.
        */
    get negativeBrushes() {
        return fromBrushCollection(this.i.m0);
    }
    set negativeBrushes(v) {
        this.i.m0 = toBrushCollection(v);
    }
    /**
         * Brushes to use for drawing negative elements, when using a chart type with contextual coloring, such as Waterfall.
        */
    get negativeOutlines() {
        return fromBrushCollection(this.i.m1);
    }
    set negativeOutlines(v) {
        this.i.m1 = toBrushCollection(v);
    }
    /**
         * Gets or sets whether the series animations should be allowed when a range change has been detected on an axis.
        */
    get animateSeriesWhenAxisRangeChanges() {
        return this.i.nn;
    }
    set animateSeriesWhenAxisRangeChanges(v) {
        this.i.nn = ensureBool(v);
    }
    /**
         * Gets or sets whether the large numbers on the Y-axis labels are abbreviated.
        */
    get yAxisAbbreviateLargeNumbers() {
        return this.i.np;
    }
    set yAxisAbbreviateLargeNumbers(v) {
        this.i.np = ensureBool(v);
    }
    /**
         * Export serialized visual data.
        
        */
    exportSerializedVisualData() {
        let iv = this.i.ol();
        return (iv);
    }
    /**
         * Converts the given visual location to a data value.
        
        * @param unscaledValue  * The x-coordinate of the location to scale.
        */
    getScaledValueX(unscaledValue) {
        let iv = this.i.nz(unscaledValue);
        return (iv);
    }
    /**
         * Converts the given data value to a visual location.
        
        * @param scaledValue  * The data value to unscale.
        */
    getUnscaledValueX(scaledValue) {
        let iv = this.i.n1(scaledValue);
        return (iv);
    }
    /**
         * Converts the given visual location to a data value.
        
        * @param unscaledValue  * The y-coordinate of the location to scale.
        */
    getScaledValueY(unscaledValue) {
        let iv = this.i.n0(unscaledValue);
        return (iv);
    }
    /**
         * Converts the given data value to a visual location.
        
        * @param scaledValue  * The data value to unscale.
        */
    getUnscaledValueY(scaledValue) {
        let iv = this.i.n2(scaledValue);
        return (iv);
    }
}
IgxCategoryChartComponent.decorators = [
    { type: Component, args: [{
                selector: 'igx-category-chart',
                template: `<ng-container #dynamicContent></ng-container>`,
                changeDetection: ChangeDetectionStrategy.OnPush,
                providers: IgxCategoryChartComponent_PROVIDERS,
                styles: [`
		:host {
			display: block;
		}
	`]
            },] },
];
//@@ZoneRunner
/** @nocollapse */
IgxCategoryChartComponent.ctorParameters = () => [
    { type: Renderer2, },
    { type: ViewContainerRef, },
    { type: undefined, decorators: [{ type: Inject, args: [DOCUMENT,] },] },
    { type: NgZone, },
    { type: Injector, },
    { type: ComponentFactoryResolver, },
];
IgxCategoryChartComponent.propDecorators = {
    "_dynamicContent": [{ type: ViewChild, args: ["dynamicContent", { read: ViewContainerRef },] },],
    "height": [{ type: Input },],
    "width": [{ type: Input },],
    "dataSource": [{ type: Input },],
    "transitionInDuration": [{ type: Input },],
    "transitionInEasingFunction": [{ type: Input },],
    "chartType": [{ type: Input },],
    "markerCollisionAvoidance": [{ type: Input },],
    "isTransitionInEnabled": [{ type: Input },],
    "transitionInMode": [{ type: Input },],
    "transitionInSpeedType": [{ type: Input },],
    "xAxisInterval": [{ type: Input },],
    "xAxisMinorInterval": [{ type: Input },],
    "xAxisGap": [{ type: Input },],
    "xAxisOverlap": [{ type: Input },],
    "yAxisInterval": [{ type: Input },],
    "yAxisIsLogarithmic": [{ type: Input },],
    "yAxisLogarithmBase": [{ type: Input },],
    "yAxisMinimumValue": [{ type: Input },],
    "yAxisMaximumValue": [{ type: Input },],
    "yAxisMinorInterval": [{ type: Input },],
    "negativeBrushes": [{ type: Input },],
    "negativeOutlines": [{ type: Input },],
    "animateSeriesWhenAxisRangeChanges": [{ type: Input },],
    "yAxisAbbreviateLargeNumbers": [{ type: Input },],
};
//# sourceMappingURL=igx-category-chart-component.js.map