import { Component, forwardRef, Input, ChangeDetectionStrategy } from '@angular/core';
import { IgxCategoryAxisBaseComponent } from "./igx-category-axis-base-component";
import { IgxAnnotationLayerComponent } from "./igx-annotation-layer-component";
import { IgxSeriesComponent } from "./igx-series-component";
import { CategoryHighlightLayer } from "./CategoryHighlightLayer";
import { ensureBool } from "igniteui-angular-core/ES2015/componentUtil";
/**
 * Represents an annotation layer that targets a category axis, or all category axes in the chart.
 * If the axis contains any series that are aligned between major gridlines of the axis (column, waterfall, etc) this will render a shape that fills the current category.
 * Otherwise it will render a band with an adjustable thickness at the closest gridline to the pointer position.
 * Setting UseIterpolation to true will cause the x position in the latter case to become affixed to the x position of the pointer.
*/
export const IgxCategoryHighlightLayerComponent_PROVIDERS = [{ provide: IgxAnnotationLayerComponent, useExisting: forwardRef(() => IgxCategoryHighlightLayerComponent) }, { provide: IgxSeriesComponent, useExisting: forwardRef(() => IgxCategoryHighlightLayerComponent) }];
export class IgxCategoryHighlightLayerComponent extends IgxAnnotationLayerComponent {
    constructor() {
        super();
    }
    createImplementation() {
        return new CategoryHighlightLayer();
    }
    get i() {
        return this._implementation;
    }
    /**
         * Gets or sets the axis to target this annotation to. If null, this annotation targets all category axes simultaneously.
        */
    get targetAxis() {
        if (this.i.mj == null) {
            return null;
        }
        return this.i.mj.externalObject;
    }
    set targetAxis(v) {
        v == null ? this.i.mj = null : this.i.mj = v.i;
    }
    /**
         * Gets or sets whether to use value interpolation when drawing a line through the best value for the pointer position.
        */
    get useInterpolation() {
        return this.i.mm;
    }
    set useInterpolation(v) {
        this.i.mm = ensureBool(v);
    }
    /**
         * Gets or sets the width to use for the highlight region if drawing a band rather than filling a category.
        */
    get bandHighlightWidth() {
        return this.i.mn;
    }
    set bandHighlightWidth(v) {
        this.i.mn = +v;
    }
}
IgxCategoryHighlightLayerComponent.decorators = [
    { type: Component, args: [{
                selector: 'igx-category-highlight-layer',
                template: ``,
                providers: [{ provide: IgxAnnotationLayerComponent, useExisting: forwardRef(() => IgxCategoryHighlightLayerComponent) }, { provide: IgxSeriesComponent, useExisting: forwardRef(() => IgxCategoryHighlightLayerComponent) }],
                changeDetection: ChangeDetectionStrategy.OnPush
            },] },
];
/** @nocollapse */
IgxCategoryHighlightLayerComponent.ctorParameters = () => [];
IgxCategoryHighlightLayerComponent.propDecorators = {
    "targetAxis": [{ type: Input },],
    "useInterpolation": [{ type: Input },],
    "bandHighlightWidth": [{ type: Input },],
};
//# sourceMappingURL=igx-category-highlight-layer-component.js.map