import { Component, forwardRef, Input, ChangeDetectionStrategy } from '@angular/core';
import { IgxAnnotationLayerComponent } from "./igx-annotation-layer-component";
import { IgxSeriesComponent } from "./igx-series-component";
import { CategoryToolTipLayer } from "./CategoryToolTipLayer";
import { ensureBool } from "igniteui-angular-core/ES2015/componentUtil";
/**
 * Represents an annotation layer that displays grouped tooltips for series that use a category axis.
*/
export const IgxCategoryToolTipLayerComponent_PROVIDERS = [{ provide: IgxAnnotationLayerComponent, useExisting: forwardRef(() => IgxCategoryToolTipLayerComponent) }, { provide: IgxSeriesComponent, useExisting: forwardRef(() => IgxCategoryToolTipLayerComponent) }];
export class IgxCategoryToolTipLayerComponent extends IgxAnnotationLayerComponent {
    constructor() {
        super();
    }
    createImplementation() {
        return new CategoryToolTipLayer();
    }
    get i() {
        return this._implementation;
    }
    /**
         * Gets whether the default tooltip behaviors for the chart are disabled if this layer is present.
        */
    get isDefaultTooltipBehaviorDisabled() {
        return this.i.cm;
    }
    /**
         * Gets or sets whether to use value interpolation when drawing the tooltips.
        */
    get useInterpolation() {
        return this.i.mn;
    }
    set useInterpolation(v) {
        this.i.mn = ensureBool(v);
    }
}
IgxCategoryToolTipLayerComponent.decorators = [
    { type: Component, args: [{
                selector: 'igx-category-tool-tip-layer',
                template: ``,
                providers: [{ provide: IgxAnnotationLayerComponent, useExisting: forwardRef(() => IgxCategoryToolTipLayerComponent) }, { provide: IgxSeriesComponent, useExisting: forwardRef(() => IgxCategoryToolTipLayerComponent) }],
                changeDetection: ChangeDetectionStrategy.OnPush
            },] },
];
/** @nocollapse */
IgxCategoryToolTipLayerComponent.ctorParameters = () => [];
IgxCategoryToolTipLayerComponent.propDecorators = {
    "useInterpolation": [{ type: Input },],
};
//# sourceMappingURL=igx-category-tool-tip-layer-component.js.map