import { Component, forwardRef, Input, ChangeDetectionStrategy } from '@angular/core';
import { ConsolidatedItemsPosition, ConsolidatedItemsPosition_$type } from "./ConsolidatedItemsPosition";
import { IgxHorizontalAnchoredCategorySeriesComponent } from "./igx-horizontal-anchored-category-series-component";
import { IgxAnchoredCategorySeriesComponent } from "./igx-anchored-category-series-component";
import { IgxCategorySeriesComponent } from "./igx-category-series-component";
import { IgxMarkerSeriesComponent } from "./igx-marker-series-component";
import { IgxSeriesComponent } from "./igx-series-component";
import { ColumnSeries } from "./ColumnSeries";
import { ensureEnum, toPoint, fromRect } from "igniteui-angular-core/ES2015/componentUtil";
/**
 * Represents a IgxDataChartComponent column series.
 * Compare values across categories by using vertical rectangles.Use it when the order of categories is not important or for displaying
 * item counts such as a histogram.
*/
export const IgxColumnSeriesComponent_PROVIDERS = [{ provide: IgxHorizontalAnchoredCategorySeriesComponent, useExisting: forwardRef(() => IgxColumnSeriesComponent) }, { provide: IgxAnchoredCategorySeriesComponent, useExisting: forwardRef(() => IgxColumnSeriesComponent) }, { provide: IgxCategorySeriesComponent, useExisting: forwardRef(() => IgxColumnSeriesComponent) }, { provide: IgxMarkerSeriesComponent, useExisting: forwardRef(() => IgxColumnSeriesComponent) }, { provide: IgxSeriesComponent, useExisting: forwardRef(() => IgxColumnSeriesComponent) }];
export class IgxColumnSeriesComponent extends IgxHorizontalAnchoredCategorySeriesComponent {
    constructor() {
        super();
    }
    createImplementation() {
        return new ColumnSeries();
    }
    get i() {
        return this._implementation;
    }
    /**
         * Gets or sets the x-radius of the ellipse that is used to round the corners of the column.
        */
    get radiusX() {
        return this.i.p2;
    }
    set radiusX(v) {
        this.i.p2 = +v;
    }
    /**
         * Gets or sets the y-radius of the ellipse that is used to round the corners of the column.
        */
    get radiusY() {
        return this.i.p3;
    }
    set radiusY(v) {
        this.i.p3 = +v;
    }
    /**
         * The positioning logic to use for columns which have been consolidated into a single visual element.
        */
    get consolidatedColumnVerticalPosition() {
        return this.i.p0;
    }
    set consolidatedColumnVerticalPosition(v) {
        this.i.p0 = ensureEnum(ConsolidatedItemsPosition_$type, v);
    }
    /**
         * If possible, will return the best available value bounding box within the series that has the best value match for the world position provided.
        
        * @param world  * The world coordinate for which to get a value bounding box for
        */
    getSeriesValueBoundingBox(world) {
        let iv = this.i.lb(toPoint(world));
        return fromRect(iv);
    }
    /**
         * For a category plotted series, returns the current width of the items within the categories. This only returns a value if the items have some form of width (e.g. columns, bars, etc.) otherwise 0 is returned.
        
        */
    getItemSpan() {
        let iv = this.i.d8();
        return (iv);
    }
}
IgxColumnSeriesComponent.decorators = [
    { type: Component, args: [{
                selector: 'igx-column-series',
                template: ``,
                providers: [{ provide: IgxHorizontalAnchoredCategorySeriesComponent, useExisting: forwardRef(() => IgxColumnSeriesComponent) }, { provide: IgxAnchoredCategorySeriesComponent, useExisting: forwardRef(() => IgxColumnSeriesComponent) }, { provide: IgxCategorySeriesComponent, useExisting: forwardRef(() => IgxColumnSeriesComponent) }, { provide: IgxMarkerSeriesComponent, useExisting: forwardRef(() => IgxColumnSeriesComponent) }, { provide: IgxSeriesComponent, useExisting: forwardRef(() => IgxColumnSeriesComponent) }],
                changeDetection: ChangeDetectionStrategy.OnPush
            },] },
];
/** @nocollapse */
IgxColumnSeriesComponent.ctorParameters = () => [];
IgxColumnSeriesComponent.propDecorators = {
    "radiusX": [{ type: Input },],
    "radiusY": [{ type: Input },],
    "consolidatedColumnVerticalPosition": [{ type: Input },],
};
//# sourceMappingURL=igx-column-series-component.js.map