import { Component, forwardRef, Input, ChangeDetectionStrategy } from '@angular/core';
import { IgxSeriesComponent } from "./igx-series-component";
import { Visibility, Visibility_$type } from "igniteui-angular-core/ES2015/Visibility";
import { IgxAnnotationLayerComponent } from "./igx-annotation-layer-component";
import { CrosshairLayer } from "./CrosshairLayer";
import { brushToString, stringToBrush, ensureBool, ensureEnum } from "igniteui-angular-core/ES2015/componentUtil";
/**
 * Represents an annotation layer that displays crosshair lines that cross through the closest value of the target series under the cursor.
*/
export const IgxCrosshairLayerComponent_PROVIDERS = [{ provide: IgxAnnotationLayerComponent, useExisting: forwardRef(() => IgxCrosshairLayerComponent) }, { provide: IgxSeriesComponent, useExisting: forwardRef(() => IgxCrosshairLayerComponent) }];
export class IgxCrosshairLayerComponent extends IgxAnnotationLayerComponent {
    constructor() {
        super();
    }
    createImplementation() {
        return new CrosshairLayer();
    }
    get i() {
        return this._implementation;
    }
    /**
         * Gets or sets the color to use for the horizontal line. Leave null for an automatic value.
        */
    get horizontalLineStroke() {
        return brushToString(this.i.n3);
    }
    set horizontalLineStroke(v) {
        this.i.n3 = stringToBrush(v);
    }
    /**
         * Gets or sets the color to use for vertical line. Leave null for an automatic value.
        */
    get verticalLineStroke() {
        return brushToString(this.i.n4);
    }
    set verticalLineStroke(v) {
        this.i.n4 = stringToBrush(v);
    }
    /**
         * Gets or sets the series to target this annotation to. If null, this annotation targets all series simultaneously.
        */
    get targetSeries() {
        if (this.i.mk == null) {
            return null;
        }
        return this.i.mk.externalObject;
    }
    set targetSeries(v) {
        v == null ? this.i.mk = null : this.i.mk = v.i;
    }
    /**
         * Gets or sets whether to use value interpolation when drawing a line through the best value for the cursor position.
        */
    get useInterpolation() {
        return this.i.mn;
    }
    set useInterpolation(v) {
        this.i.mn = ensureBool(v);
    }
    /**
         * Gets or sets whether to use value interpolation when drawing a line through the best value for the cursor position.
        */
    get isAxisAnnotationEnabled() {
        return this.i.ml;
    }
    set isAxisAnnotationEnabled(v) {
        this.i.ml = ensureBool(v);
    }
    /**
         * Gets or sets the color to use for the x axis annotation text. Leave unset for an automatic value.
        */
    get xAxisAnnotationTextColor() {
        return brushToString(this.i.n7);
    }
    set xAxisAnnotationTextColor(v) {
        this.i.n7 = stringToBrush(v);
    }
    /**
         * Gets or sets the color to use for the x axis annotation backing. Leave unset for an automatic value.
        */
    get xAxisAnnotationBackground() {
        return brushToString(this.i.n5);
    }
    set xAxisAnnotationBackground(v) {
        this.i.n5 = stringToBrush(v);
    }
    /**
         * Gets or sets the precision to use displaying values for interpolated crosshair positions.
        */
    get xAxisAnnotationInterpolatedValuePrecision() {
        return this.i.mu;
    }
    set xAxisAnnotationInterpolatedValuePrecision(v) {
        this.i.mu = +v;
    }
    /**
         * Gets or sets the color to use for the x axis annotation outline. Leave unset for an automatic value.
        */
    get xAxisAnnotationOutline() {
        return brushToString(this.i.n6);
    }
    set xAxisAnnotationOutline(v) {
        this.i.n6 = stringToBrush(v);
    }
    /**
         * Gets or sets the padding for the x axis annotation backing. Leave unset for an automatic value.
        */
    get xAxisAnnotationPadding() {
        return this.i.mq;
    }
    set xAxisAnnotationPadding(v) {
        this.i.mq = +v;
    }
    /**
         * Gets or sets the stroke thickness for the x axis annotation backing. Leave unset for an automatic value.
        */
    get xAxisAnnotationStrokeThickness() {
        return this.i.mr;
    }
    set xAxisAnnotationStrokeThickness(v) {
        this.i.mr = +v;
    }
    /**
         * Gets or sets the color to use for the y axis annotation text. Leave unset for an automatic value.
        */
    get yAxisAnnotationTextColor() {
        return brushToString(this.i.oa);
    }
    set yAxisAnnotationTextColor(v) {
        this.i.oa = stringToBrush(v);
    }
    /**
         * Gets or sets the color to use for the y axis annotation backing. Leave unset for an automatic value.
        */
    get yAxisAnnotationBackground() {
        return brushToString(this.i.n8);
    }
    set yAxisAnnotationBackground(v) {
        this.i.n8 = stringToBrush(v);
    }
    /**
         * Gets or sets the precision to use displaying values for interpolated crosshair positions.
        */
    get yAxisAnnotationInterpolatedValuePrecision() {
        return this.i.mv;
    }
    set yAxisAnnotationInterpolatedValuePrecision(v) {
        this.i.mv = +v;
    }
    /**
         * Gets or sets the color to use for the y axis annotation outline. Leave unset for an automatic value.
        */
    get yAxisAnnotationOutline() {
        return brushToString(this.i.n9);
    }
    set yAxisAnnotationOutline(v) {
        this.i.n9 = stringToBrush(v);
    }
    /**
         * Gets or sets the padding for the y axis annotation backing. Leave unset for an automatic value.
        */
    get yAxisAnnotationPadding() {
        return this.i.ms;
    }
    set yAxisAnnotationPadding(v) {
        this.i.ms = +v;
    }
    /**
         * Gets or sets the stroke thickness for the y axis annotation backing. Leave unset for an automatic value.
        */
    get yAxisAnnotationStrokeThickness() {
        return this.i.mt;
    }
    set yAxisAnnotationStrokeThickness(v) {
        this.i.mt = +v;
    }
    /**
         * Gets or sets whether to display the vertical line.
        */
    get verticalLineVisibility() {
        return this.i.oc;
    }
    set verticalLineVisibility(v) {
        this.i.oc = ensureEnum(Visibility_$type, v);
    }
    /**
         * Gets or sets whether to display the horizontal line.
        */
    get horizontalLineVisibility() {
        return this.i.ob;
    }
    set horizontalLineVisibility(v) {
        this.i.ob = ensureEnum(Visibility_$type, v);
    }
    /**
         * Gets or sets whether to skip unknown values when searching for series values.
        */
    get skipUnknownValues() {
        return this.i.mm;
    }
    set skipUnknownValues(v) {
        this.i.mm = ensureBool(v);
    }
}
IgxCrosshairLayerComponent.decorators = [
    { type: Component, args: [{
                selector: 'igx-crosshair-layer',
                template: ``,
                providers: [{ provide: IgxAnnotationLayerComponent, useExisting: forwardRef(() => IgxCrosshairLayerComponent) }, { provide: IgxSeriesComponent, useExisting: forwardRef(() => IgxCrosshairLayerComponent) }],
                changeDetection: ChangeDetectionStrategy.OnPush
            },] },
];
/** @nocollapse */
IgxCrosshairLayerComponent.ctorParameters = () => [];
IgxCrosshairLayerComponent.propDecorators = {
    "horizontalLineStroke": [{ type: Input },],
    "verticalLineStroke": [{ type: Input },],
    "targetSeries": [{ type: Input },],
    "useInterpolation": [{ type: Input },],
    "isAxisAnnotationEnabled": [{ type: Input },],
    "xAxisAnnotationTextColor": [{ type: Input },],
    "xAxisAnnotationBackground": [{ type: Input },],
    "xAxisAnnotationInterpolatedValuePrecision": [{ type: Input },],
    "xAxisAnnotationOutline": [{ type: Input },],
    "xAxisAnnotationPadding": [{ type: Input },],
    "xAxisAnnotationStrokeThickness": [{ type: Input },],
    "yAxisAnnotationTextColor": [{ type: Input },],
    "yAxisAnnotationBackground": [{ type: Input },],
    "yAxisAnnotationInterpolatedValuePrecision": [{ type: Input },],
    "yAxisAnnotationOutline": [{ type: Input },],
    "yAxisAnnotationPadding": [{ type: Input },],
    "yAxisAnnotationStrokeThickness": [{ type: Input },],
    "verticalLineVisibility": [{ type: Input },],
    "horizontalLineVisibility": [{ type: Input },],
    "skipUnknownValues": [{ type: Input },],
};
//# sourceMappingURL=igx-crosshair-layer-component.js.map