import { Component, forwardRef, Input, ChangeDetectionStrategy } from '@angular/core';
import { IgxSeriesComponent } from "./igx-series-component";
import { FinalValueSelectionMode, FinalValueSelectionMode_$type } from "./FinalValueSelectionMode";
import { IgxAnnotationLayerComponent } from "./igx-annotation-layer-component";
import { FinalValueLayer } from "./FinalValueLayer";
import { ensureEnum, brushToString, stringToBrush } from "igniteui-angular-core/ES2015/componentUtil";
/**
 * Represents an annotation layer that displays crosshair lines that cross through the closest value of the target series under the cursor.
*/
export const IgxFinalValueLayerComponent_PROVIDERS = [{ provide: IgxAnnotationLayerComponent, useExisting: forwardRef(() => IgxFinalValueLayerComponent) }, { provide: IgxSeriesComponent, useExisting: forwardRef(() => IgxFinalValueLayerComponent) }];
export class IgxFinalValueLayerComponent extends IgxAnnotationLayerComponent {
    constructor() {
        super();
    }
    createImplementation() {
        return new FinalValueLayer();
    }
    get i() {
        return this._implementation;
    }
    /**
         * Gets or sets the series to target this annotation to. If null, this annotation targets all series simultaneously.
        */
    get targetSeries() {
        if (this.i.ml == null) {
            return null;
        }
        return this.i.ml.externalObject;
    }
    set targetSeries(v) {
        v == null ? this.i.ml = null : this.i.ml = v.i;
    }
    /**
         * Gets or sets how to select the final value to annotate.
        */
    get finalValueSelectionMode() {
        return this.i.mk;
    }
    set finalValueSelectionMode(v) {
        this.i.mk = ensureEnum(FinalValueSelectionMode_$type, v);
    }
    /**
         * Gets or sets the color to use for the axis annotation text. Leave unset for an automatic value.
        */
    get axisAnnotationTextColor() {
        return brushToString(this.i.nb);
    }
    set axisAnnotationTextColor(v) {
        this.i.nb = stringToBrush(v);
    }
    /**
         * Gets or sets the color to use for the axis annotation backing. Leave unset for an automatic value.
        */
    get axisAnnotationBackground() {
        return brushToString(this.i.m9);
    }
    set axisAnnotationBackground(v) {
        this.i.m9 = stringToBrush(v);
    }
    /**
         * Gets or sets the precision to use displaying values for interpolated crosshair positions.
        */
    get axisAnnotationInterpolatedValuePrecision() {
        return this.i.mq;
    }
    set axisAnnotationInterpolatedValuePrecision(v) {
        this.i.mq = +v;
    }
    /**
         * Gets or sets the color to use for the axis annotation outline. Leave unset for an automatic value.
        */
    get axisAnnotationOutline() {
        return brushToString(this.i.na);
    }
    set axisAnnotationOutline(v) {
        this.i.na = stringToBrush(v);
    }
    /**
         * Gets or sets the padding for the axis annotation backing. Leave unset for an automatic value.
        */
    get axisAnnotationPadding() {
        return this.i.mo;
    }
    set axisAnnotationPadding(v) {
        this.i.mo = +v;
    }
    /**
         * Gets or sets the stroke thickness for the axis annotation backing. Leave unset for an automatic value.
        */
    get axisAnnotationStrokeThickness() {
        return this.i.mp;
    }
    set axisAnnotationStrokeThickness(v) {
        this.i.mp = +v;
    }
}
IgxFinalValueLayerComponent.decorators = [
    { type: Component, args: [{
                selector: 'igx-final-value-layer',
                template: ``,
                providers: [{ provide: IgxAnnotationLayerComponent, useExisting: forwardRef(() => IgxFinalValueLayerComponent) }, { provide: IgxSeriesComponent, useExisting: forwardRef(() => IgxFinalValueLayerComponent) }],
                changeDetection: ChangeDetectionStrategy.OnPush
            },] },
];
/** @nocollapse */
IgxFinalValueLayerComponent.ctorParameters = () => [];
IgxFinalValueLayerComponent.propDecorators = {
    "targetSeries": [{ type: Input },],
    "finalValueSelectionMode": [{ type: Input },],
    "axisAnnotationTextColor": [{ type: Input },],
    "axisAnnotationBackground": [{ type: Input },],
    "axisAnnotationInterpolatedValuePrecision": [{ type: Input },],
    "axisAnnotationOutline": [{ type: Input },],
    "axisAnnotationPadding": [{ type: Input },],
    "axisAnnotationStrokeThickness": [{ type: Input },],
};
//# sourceMappingURL=igx-final-value-layer-component.js.map