import { forwardRef, Input } from '@angular/core';
import { IgxFinancialSeriesComponent } from "./igx-financial-series-component";
import { IgxSeriesComponent } from "./igx-series-component";
/**
 * Represents the base functionality for a IgxDataChartComponent financial overlay series.
 * The difference between a FinancialIndicator and a FinancialOverlay is small.
 * Overlays are usually drawn against the same axes as the price, but they don't
 * have to be. Overlays mostly display multiple values, but not all of them, and so
 * so some indicators.
*/
export const IgxFinancialOverlayComponent_PROVIDERS = [{ provide: IgxFinancialSeriesComponent, useExisting: forwardRef(() => IgxFinancialOverlayComponent) }, { provide: IgxSeriesComponent, useExisting: forwardRef(() => IgxFinancialOverlayComponent) }];
export class IgxFinancialOverlayComponent extends IgxFinancialSeriesComponent {
    constructor() {
        super();
    }
    get i() {
        return this._implementation;
    }
    /**
         * Gets or sets the number of values to hide at the beginning of the indicator.
        */
    get ignoreFirst() {
        return this.i.oz;
    }
    set ignoreFirst(v) {
        this.i.oz = +v;
    }
    /**
         * Scrolls the series to display the item for the specified data item.
         * The series is scrolled by the minimum amount required to place the specified data item within
         * the central 80% of the visible axis.
        
        * @param item  * The data item (item) to scroll to.
        */
    scrollIntoView(item) {
        let iv = this.i.c6(item);
        return (iv);
    }
}
IgxFinancialOverlayComponent.propDecorators = {
    "ignoreFirst": [{ type: Input },],
};
//# sourceMappingURL=igx-financial-overlay-component.js.map