import { Type } from '@angular/core';
import { IgPoint } from "igniteui-angular-core/ES2015/IgPoint";
import { IgxCategoryAxisBaseComponent } from './igx-category-axis-base-component';
import { IgxNumericYAxisComponent } from './igx-numeric-y-axis-component';
import { IgxRangeCategorySeriesComponent } from './igx-range-category-series-component';
import { IgxMarkerSeriesComponent } from './igx-marker-series-component';
import { IgxSeriesComponent } from './igx-series-component';
import { IgxAxisComponent } from './igx-axis-component';
import { HorizontalRangeCategorySeries } from './HorizontalRangeCategorySeries';
export declare const IgxHorizontalRangeCategorySeriesComponent_PROVIDERS: ({
    provide: typeof IgxMarkerSeriesComponent;
    useExisting: Type<any>;
} | {
    provide: typeof IgxSeriesComponent;
    useExisting: Type<any>;
})[];
/**
 * Base class for ranged category series with a category X-axis and a numeric Y-axis.
*/
export declare abstract class IgxHorizontalRangeCategorySeriesComponent extends IgxRangeCategorySeriesComponent {
    readonly i: HorizontalRangeCategorySeries;
    constructor();
    private _xAxisName;
    xAxisName: string;
    private _yAxisName;
    yAxisName: string;
    private _boundAxes;
    bindAxes(axes: IgxAxisComponent[]): void;
    /**
 * Gets or sets the effective x-axis for the current CategorySeries object.
*/
    xAxis: IgxCategoryAxisBaseComponent;
    /**
     * Gets or sets the effective y-axis for the current CategorySeries object.
    */
    yAxis: IgxNumericYAxisComponent;
    /**
     * Checks if this series is a range series
    */
    readonly isRange: boolean;
    /**
 * Returns the offset value for this series if grouped on a category axis.

*/
    getOffsetValue(): number;
    /**
     * Returns the width of the category grouping this series is in.
    
    */
    getCategoryWidth(): number;
    getNextOrExactIndex(world: IgPoint, skipUnknowns: boolean): number;
    getPreviousOrExactIndex(world: IgPoint, skipUnknowns: boolean): number;
    getSeriesValue(world: IgPoint, useInterpolation: boolean, skipUnknowns: boolean): number;
    getSeriesLowValue(world: IgPoint, useInterpolation: boolean, skipUnknowns: boolean): number;
    getSeriesHighValue(world: IgPoint, useInterpolation: boolean, skipUnknowns: boolean): number;
    getSeriesHighValuePosition(world: IgPoint, useInterpolation: boolean, skipUnknowns: boolean): IgPoint;
    getSeriesLowValuePosition(world: IgPoint, useInterpolation: boolean, skipUnknowns: boolean): IgPoint;
    getSeriesValuePosition(world: IgPoint, useInterpolation: boolean, skipUnknowns: boolean): IgPoint;
    /**
     * Determine if object can be used as YAxis
    
    * @param axis  * The object to check
    */
    canUseAsYAxis(axis: any): boolean;
    /**
     * Determine if object can be used as XAxis
    
    * @param axis  * The object to check
    */
    canUseAsXAxis(axis: any): boolean;
}
