import { EventEmitter, Output } from '@angular/core';
import { delegateCombine } from "igniteui-angular-core/ES2015/type";
import { LegendMouseButtonEventArgs } from "./igx-legend-mouse-button-event-args";
import { LegendMouseEventArgs } from "./igx-legend-mouse-event-args";
/**
 * Represents the base class for a legend in IgxDataChartComponent.
*/
export const IgxLegendBaseComponent_PROVIDERS = [];
export class IgxLegendBaseComponent {
    constructor() {
        this._legendItemMouseLeftButtonDown = null;
        this._legendItemMouseLeftButtonUp = null;
        this._legendItemMouseEnter = null;
        this._legendItemMouseLeave = null;
        this._legendItemMouseMove = null;
        this._zoneRunner = null;
        this._implementation = this.createImplementation();
        this._implementation.externalObject = this;
        this.onImplementationCreated();
    }
    createImplementation() {
        return null;
    }
    ngOnInit() {
    }
    get i() {
        return this._implementation;
    }
    onImplementationCreated() {
    }
    /**
         * Event raised when the left mouse button is pressed while the mouse pointer is over a legend item
         * in this Legend.
        */
    get legendItemMouseLeftButtonDown() {
        if (this._legendItemMouseLeftButtonDown == null) {
            this._legendItemMouseLeftButtonDown = new EventEmitter();
            this.i.legendItemMouseLeftButtonDown = delegateCombine(this.i.legendItemMouseLeftButtonDown, (o, e) => {
                this._runInZone(() => {
                    let outerArgs = new LegendMouseButtonEventArgs();
                    outerArgs._provideImplementation(e);
                    this._legendItemMouseLeftButtonDown.emit({
                        sender: this,
                        args: outerArgs
                    });
                });
            });
        }
        return this._legendItemMouseLeftButtonDown;
    }
    /**
         * Event raised when the left mouse button is released while the mouse pointer is over a legend item
         * in this Legend.
        */
    get legendItemMouseLeftButtonUp() {
        if (this._legendItemMouseLeftButtonUp == null) {
            this._legendItemMouseLeftButtonUp = new EventEmitter();
            this.i.legendItemMouseLeftButtonUp = delegateCombine(this.i.legendItemMouseLeftButtonUp, (o, e) => {
                this._runInZone(() => {
                    let outerArgs = new LegendMouseButtonEventArgs();
                    outerArgs._provideImplementation(e);
                    this._legendItemMouseLeftButtonUp.emit({
                        sender: this,
                        args: outerArgs
                    });
                });
            });
        }
        return this._legendItemMouseLeftButtonUp;
    }
    /**
         * Event raised when the mouse pointer enters a legend item of this legend.
        */
    get legendItemMouseEnter() {
        if (this._legendItemMouseEnter == null) {
            this._legendItemMouseEnter = new EventEmitter();
            this.i.legendItemMouseEnter = delegateCombine(this.i.legendItemMouseEnter, (o, e) => {
                this._runInZone(() => {
                    let outerArgs = new LegendMouseEventArgs();
                    outerArgs._provideImplementation(e);
                    this._legendItemMouseEnter.emit({
                        sender: this,
                        args: outerArgs
                    });
                });
            });
        }
        return this._legendItemMouseEnter;
    }
    /**
         * Event raised when the mouse pointer leaves a legend item of this legend.
        */
    get legendItemMouseLeave() {
        if (this._legendItemMouseLeave == null) {
            this._legendItemMouseLeave = new EventEmitter();
            this.i.legendItemMouseLeave = delegateCombine(this.i.legendItemMouseLeave, (o, e) => {
                this._runInZone(() => {
                    let outerArgs = new LegendMouseEventArgs();
                    outerArgs._provideImplementation(e);
                    this._legendItemMouseLeave.emit({
                        sender: this,
                        args: outerArgs
                    });
                });
            });
        }
        return this._legendItemMouseLeave;
    }
    /**
         * Event raised when the mouse pointer moves over a legend item of this legend.
        */
    get legendItemMouseMove() {
        if (this._legendItemMouseMove == null) {
            this._legendItemMouseMove = new EventEmitter();
            this.i.legendItemMouseMove = delegateCombine(this.i.legendItemMouseMove, (o, e) => {
                this._runInZone(() => {
                    let outerArgs = new LegendMouseEventArgs();
                    outerArgs._provideImplementation(e);
                    this._legendItemMouseMove.emit({
                        sender: this,
                        args: outerArgs
                    });
                });
            });
        }
        return this._legendItemMouseMove;
    }
    _runInZone(act) {
        if (this._zoneRunner != null) {
            this._zoneRunner(act);
        }
        else {
            act();
        }
    }
}
IgxLegendBaseComponent.propDecorators = {
    "legendItemMouseLeftButtonDown": [{ type: Output },],
    "legendItemMouseLeftButtonUp": [{ type: Output },],
    "legendItemMouseEnter": [{ type: Output },],
    "legendItemMouseLeave": [{ type: Output },],
    "legendItemMouseMove": [{ type: Output },],
};
//# sourceMappingURL=igx-legend-base-component.js.map