import { Component, forwardRef, Input, ChangeDetectionStrategy } from '@angular/core';
import { UnknownValuePlotting, UnknownValuePlotting_$type } from "igniteui-angular-core/ES2015/UnknownValuePlotting";
import { IgxHorizontalAnchoredCategorySeriesComponent } from "./igx-horizontal-anchored-category-series-component";
import { IgxAnchoredCategorySeriesComponent } from "./igx-anchored-category-series-component";
import { IgxCategorySeriesComponent } from "./igx-category-series-component";
import { IgxMarkerSeriesComponent } from "./igx-marker-series-component";
import { IgxSeriesComponent } from "./igx-series-component";
import { LineSeries } from "./LineSeries";
import { ensureEnum } from "igniteui-angular-core/ES2015/componentUtil";
/**
 * Represents a IgxDataChartComponent line series.
 * Displays trend over time or ordered categories.Useful when there are many data points and the order is important.
*/
export const IgxLineSeriesComponent_PROVIDERS = [{ provide: IgxHorizontalAnchoredCategorySeriesComponent, useExisting: forwardRef(() => IgxLineSeriesComponent) }, { provide: IgxAnchoredCategorySeriesComponent, useExisting: forwardRef(() => IgxLineSeriesComponent) }, { provide: IgxCategorySeriesComponent, useExisting: forwardRef(() => IgxLineSeriesComponent) }, { provide: IgxMarkerSeriesComponent, useExisting: forwardRef(() => IgxLineSeriesComponent) }, { provide: IgxSeriesComponent, useExisting: forwardRef(() => IgxLineSeriesComponent) }];
export class IgxLineSeriesComponent extends IgxHorizontalAnchoredCategorySeriesComponent {
    constructor() {
        super();
    }
    createImplementation() {
        return new LineSeries();
    }
    get i() {
        return this._implementation;
    }
    /**
         * Gets whether the current series shows an area or line shape.
        */
    get isAreaOrLine() {
        return this.i.cj;
    }
    /**
         * Determines how unknown values will be plotted on the chart.
         * Null and Double.NaN are two examples of unknown values.
        */
    get unknownValuePlotting() {
        return this.i.unknownValuePlotting;
    }
    set unknownValuePlotting(v) {
        this.i.unknownValuePlotting = ensureEnum(UnknownValuePlotting_$type, v);
    }
}
IgxLineSeriesComponent.decorators = [
    { type: Component, args: [{
                selector: 'igx-line-series',
                template: ``,
                providers: [{ provide: IgxHorizontalAnchoredCategorySeriesComponent, useExisting: forwardRef(() => IgxLineSeriesComponent) }, { provide: IgxAnchoredCategorySeriesComponent, useExisting: forwardRef(() => IgxLineSeriesComponent) }, { provide: IgxCategorySeriesComponent, useExisting: forwardRef(() => IgxLineSeriesComponent) }, { provide: IgxMarkerSeriesComponent, useExisting: forwardRef(() => IgxLineSeriesComponent) }, { provide: IgxSeriesComponent, useExisting: forwardRef(() => IgxLineSeriesComponent) }],
                changeDetection: ChangeDetectionStrategy.OnPush
            },] },
];
/** @nocollapse */
IgxLineSeriesComponent.ctorParameters = () => [];
IgxLineSeriesComponent.propDecorators = {
    "unknownValuePlotting": [{ type: Input },],
};
//# sourceMappingURL=igx-line-series-component.js.map