import { forwardRef, Input } from '@angular/core';
import { MarkerType, MarkerType_$type } from "./MarkerType";
import { IgxSeriesComponent } from "./igx-series-component";
import { ensureEnum, brushToString, stringToBrush } from "igniteui-angular-core/ES2015/componentUtil";
/**
 * Represents the base class for series containing markers.
*/
export const IgxMarkerSeriesComponent_PROVIDERS = [{ provide: IgxSeriesComponent, useExisting: forwardRef(() => IgxMarkerSeriesComponent) }];
export class IgxMarkerSeriesComponent extends IgxSeriesComponent {
    constructor() {
        super();
    }
    get i() {
        return this._implementation;
    }
    /**
         * Returns whether the current series supports visual markers.
        */
    get hasMarkers() {
        return this.i.hasMarkers;
    }
    /**
         * Gets or sets the marker type for the current series object.
         * If the MarkerTemplate property is set, the setting of the MarkerType property will be ignored.
        */
    get markerType() {
        return this.i.li;
    }
    set markerType(v) {
        this.i.li = ensureEnum(MarkerType_$type, v);
    }
    /**
         * Gets or sets the MarkerTemplate for the current series object.
        */
    get markerTemplate() {
        return this.i.l1;
    }
    set markerTemplate(v) {
        this.i.l1 = v;
    }
    /**
         * Gets the effective marker template for the current series object.
        */
    get actualMarkerTemplate() {
        return this.i.lz;
    }
    /**
         * Gets or sets the brush that specifies how the current series object's marker interiors are painted.
        */
    get markerBrush() {
        return brushToString(this.i.me);
    }
    set markerBrush(v) {
        this.i.me = stringToBrush(v);
    }
    /**
         * Gets the effective marker brush for the current series object.
        */
    get actualMarkerBrush() {
        return brushToString(this.i.mc);
    }
    /**
         * Gets or sets the brush that specifies how the current series object's marker outlines are painted.
        */
    get markerOutline() {
        return brushToString(this.i.mf);
    }
    set markerOutline(v) {
        this.i.mf = stringToBrush(v);
    }
    /**
         * Gets the effective marker outline for the current series object.
        */
    get actualMarkerOutline() {
        return brushToString(this.i.md);
    }
}
IgxMarkerSeriesComponent.propDecorators = {
    "markerType": [{ type: Input },],
    "markerTemplate": [{ type: Input },],
    "markerBrush": [{ type: Input },],
    "markerOutline": [{ type: Input },],
};
//# sourceMappingURL=igx-marker-series-component.js.map