import { Component, forwardRef, Input, ChangeDetectionStrategy } from '@angular/core';
import { IgxNumericAxisBaseComponent } from "./igx-numeric-axis-base-component";
import { IgxAxisComponent } from "./igx-axis-component";
import { NumericAngleAxis } from "./NumericAngleAxis";
/**
 * Represents a IgxDataChartComponent angle based axis for polar series.
*/
export const IgxNumericAngleAxisComponent_PROVIDERS = [{ provide: IgxNumericAxisBaseComponent, useExisting: forwardRef(() => IgxNumericAngleAxisComponent) }, { provide: IgxAxisComponent, useExisting: forwardRef(() => IgxNumericAngleAxisComponent) }];
export class IgxNumericAngleAxisComponent extends IgxNumericAxisBaseComponent {
    constructor() {
        super();
    }
    createImplementation() {
        return new NumericAngleAxis();
    }
    get i() {
        return this._implementation;
    }
    /**
         * Gets if the current axis is of angular axis type
        */
    get isAngular() {
        return this.i.b0;
    }
    /**
         * Indicates the angle in degress that the chart's 0th angle should be offset.
        */
    get startAngleOffset() {
        return this.i.le;
    }
    set startAngleOffset(v) {
        this.i.le = +v;
    }
    /**
         * Gets the scaled angle value in radians based on the raw input.
        
        * @param unscaledValue  * The raw input value.
        */
    getScaledAngle(unscaledValue) {
        let iv = this.i.getScaledAngle(unscaledValue);
        return (iv);
    }
    /**
         * Gets the raw axis value back from the angle that would be used on the chart.
        
        * @param scaledValue  * The chart angle value.
        */
    getUnscaledAngle(scaledValue) {
        let iv = this.i.getUnscaledAngle(scaledValue);
        return (iv);
    }
}
IgxNumericAngleAxisComponent.decorators = [
    { type: Component, args: [{
                selector: 'igx-numeric-angle-axis',
                template: ``,
                providers: [{ provide: IgxNumericAxisBaseComponent, useExisting: forwardRef(() => IgxNumericAngleAxisComponent) }, { provide: IgxAxisComponent, useExisting: forwardRef(() => IgxNumericAngleAxisComponent) }],
                changeDetection: ChangeDetectionStrategy.OnPush
            },] },
];
/** @nocollapse */
IgxNumericAngleAxisComponent.ctorParameters = () => [];
IgxNumericAngleAxisComponent.propDecorators = {
    "startAngleOffset": [{ type: Input },],
};
//# sourceMappingURL=igx-numeric-angle-axis-component.js.map