import { Component, forwardRef, Input, ChangeDetectionStrategy } from '@angular/core';
import { IgxNumericAxisBaseComponent } from "./igx-numeric-axis-base-component";
import { IgxAxisComponent } from "./igx-axis-component";
import { NumericRadiusAxis } from "./NumericRadiusAxis";
/**
 * Represents a IgxDataChartComponent radius axis for polar and radial series.
*/
export const IgxNumericRadiusAxisComponent_PROVIDERS = [{ provide: IgxNumericAxisBaseComponent, useExisting: forwardRef(() => IgxNumericRadiusAxisComponent) }, { provide: IgxAxisComponent, useExisting: forwardRef(() => IgxNumericRadiusAxisComponent) }];
export class IgxNumericRadiusAxisComponent extends IgxNumericAxisBaseComponent {
    constructor() {
        super();
    }
    createImplementation() {
        return new NumericRadiusAxis();
    }
    get i() {
        return this._implementation;
    }
    /**
         * Checks if the axis is of radial axis type
        */
    get isRadial() {
        return this.i.cb;
    }
    /**
         * Defines the percentage of the maximum radius extent to use as the maximum radius. Should be
         * a value between 0.0 and 1.0.
        */
    get radiusExtentScale() {
        return this.i.ll;
    }
    set radiusExtentScale(v) {
        this.i.ll = +v;
    }
    /**
         * Defines the percentage of the maximum radius extent to leave blank at the center of the chart. Should be
         * a value between 0.0 and 1.0.
        */
    get innerRadiusExtentScale() {
        return this.i.lk;
    }
    set innerRadiusExtentScale(v) {
        this.i.lk = +v;
    }
    /**
         * Returns a world coordinates radius length (0 - 0.5) from a raw axis value.
        
        * @param unscaledValue  * The raw axis value.
        */
    getScaledValue(unscaledValue) {
        let iv = this.i.lh(unscaledValue);
        return (iv);
    }
    /**
         * Returns a raw axis value from the world coordinates radius length provided.
        
        * @param scaledValue  * The scaled world coordinates radius length.
        */
    getUnscaledValue(scaledValue) {
        let iv = this.i.lj(scaledValue);
        return (iv);
    }
}
IgxNumericRadiusAxisComponent.decorators = [
    { type: Component, args: [{
                selector: 'igx-numeric-radius-axis',
                template: ``,
                providers: [{ provide: IgxNumericAxisBaseComponent, useExisting: forwardRef(() => IgxNumericRadiusAxisComponent) }, { provide: IgxAxisComponent, useExisting: forwardRef(() => IgxNumericRadiusAxisComponent) }],
                changeDetection: ChangeDetectionStrategy.OnPush
            },] },
];
/** @nocollapse */
IgxNumericRadiusAxisComponent.ctorParameters = () => [];
IgxNumericRadiusAxisComponent.propDecorators = {
    "radiusExtentScale": [{ type: Input },],
    "innerRadiusExtentScale": [{ type: Input },],
};
//# sourceMappingURL=igx-numeric-radius-axis-component.js.map