import { EventEmitter, Output, Input } from '@angular/core';
import { delegateCombine } from "igniteui-angular-core/ES2015/type";
import { LabelsPosition, LabelsPosition_$type } from "./LabelsPosition";
import { Visibility, Visibility_$type } from "igniteui-angular-core/ES2015/Visibility";
import { LeaderLineType, LeaderLineType_$type } from "./LeaderLineType";
import { OthersCategoryType, OthersCategoryType_$type } from "./OthersCategoryType";
import { IndexCollection } from "./igx-index-collection";
import { SweepDirection, SweepDirection_$type } from "igniteui-angular-core/ES2015/SweepDirection";
import { SliceSelectionMode, SliceSelectionMode_$type } from "./SliceSelectionMode";
import { LabelClickEventArgs } from "./igx-label-click-event-args";
import { SelectedItemChangingEventArgs } from "./igx-selected-item-changing-event-args";
import { SelectedItemsChangingEventArgs } from "./igx-selected-items-changing-event-args";
import { SelectedItemChangedEventArgs } from "./igx-selected-item-changed-event-args";
import { SelectedItemsChangedEventArgs } from "./igx-selected-items-changed-event-args";
import { SliceClickEventArgs } from "./igx-slice-click-event-args";
import { ensureEnum, brushToString, stringToBrush, ensureBool, toBrushCollection, fromBrushCollection, toPoint } from "igniteui-angular-core/ES2015/componentUtil";
import { IndexCollection as IndexCollection_internal } from "./IndexCollection";
/**
 * Represents the base class for the pie chart.
*/
export const IgxPieChartBaseComponent_PROVIDERS = [];
export class IgxPieChartBaseComponent {
    constructor() {
        this._explodedSlices = null;
        this._labelClick = null;
        this._selectedItemChanging = null;
        this._selectedItemsChanging = null;
        this._selectedItemChanged = null;
        this._selectedItemsChanged = null;
        this._sliceClick = null;
        this._zoneRunner = null;
        this._implementation = this.createImplementation();
        this._implementation.externalObject = this;
        this.onImplementationCreated();
    }
    createImplementation() {
        return null;
    }
    ngOnInit() {
    }
    get i() {
        return this._implementation;
    }
    onImplementationCreated() {
    }
    /**
         * Gets or sets the amount of space between the center and the start of the arc. This property should be set between 0 and 1.
         * If InnerExtent is set to a value greater than 1, it will be interpreted as a percentage, effectively divided by 100.
        */
    get innerExtent() {
        return this.i.cl;
    }
    set innerExtent(v) {
        this.i.cl = +v;
    }
    /**
         * Gets or Sets the property name that contains the values.
        */
    get valueMemberPath() {
        return this.i.eg;
    }
    set valueMemberPath(v) {
        this.i.eg = v;
    }
    /**
         * Gets or sets the property name that contains the labels.
        */
    get labelMemberPath() {
        return this.i.di;
    }
    set labelMemberPath(v) {
        this.i.di = v;
    }
    /**
         * Gets or sets the property name that contains the legend labels.
        */
    get legendLabelMemberPath() {
        return this.i.dv;
    }
    set legendLabelMemberPath(v) {
        this.i.dv = v;
    }
    /**
         * Gets or sets the position of chart labels.
        */
    get labelsPosition() {
        return this.i.ao;
    }
    set labelsPosition(v) {
        this.i.ao = ensureEnum(LabelsPosition_$type, v);
    }
    /**
         * Gets or sets the color for labels rendered outside of the pie chart.
        */
    get labelOuterColor() {
        return brushToString(this.i.gw);
    }
    set labelOuterColor(v) {
        this.i.gw = stringToBrush(v);
    }
    /**
         * Gets or sets the color for labels rendered inside of the pie chart.
        */
    get labelInnerColor() {
        return brushToString(this.i.gv);
    }
    set labelInnerColor(v) {
        this.i.gv = stringToBrush(v);
    }
    /**
         * Gets or sets whether the leader lines are visible.
        */
    get leaderLineVisibility() {
        return this.i.g8;
    }
    set leaderLineVisibility(v) {
        this.i.g8 = ensureEnum(Visibility_$type, v);
    }
    /**
         * Gets or sets what type of leader lines will be used for the outside end labels.
        */
    get leaderLineType() {
        return this.i.ap;
    }
    set leaderLineType(v) {
        this.i.ap = ensureEnum(LeaderLineType_$type, v);
    }
    /**
         * Gets or sets the margin between a label and the end of its leader line. The default is 6 pixels.
        */
    get leaderLineMargin() {
        return this.i.cn;
    }
    set leaderLineMargin(v) {
        this.i.cn = +v;
    }
    /**
         * Gets or sets the ToolTip for the chart.
        */
    get toolTip() {
        return this.i.c0;
    }
    set toolTip(v) {
        this.i.c0 = v;
    }
    /**
         * Gets or sets the threshold value that determines if slices are grouped into the Others slice.
        */
    get othersCategoryThreshold() {
        return this.i.co;
    }
    set othersCategoryThreshold(v) {
        this.i.co = +v;
    }
    /**
         * Gets or sets whether to use numeric or percent-based threshold value.
        */
    get othersCategoryType() {
        return this.i.aq;
    }
    set othersCategoryType(v) {
        this.i.aq = ensureEnum(OthersCategoryType_$type, v);
    }
    /**
         * Gets or sets the label of the Others slice.
        */
    get othersCategoryText() {
        return this.i.dz;
    }
    set othersCategoryText(v) {
        this.i.dz = v;
    }
    /**
         * Determines how much the exploded slice is offset from the center. Value between 0 and 1.
        */
    get explodedRadius() {
        return this.i.cg;
    }
    set explodedRadius(v) {
        this.i.cg = +v;
    }
    /**
         * Gets or sets the scaling factor of the chart's radius. Value between 0 and 1.
        */
    get radiusFactor() {
        return this.i.cr;
    }
    set radiusFactor(v) {
        this.i.cr = +v;
    }
    /**
         * Gets or sets whether the slices can be selected.
        */
    get allowSliceSelection() {
        return this.i.bq;
    }
    set allowSliceSelection(v) {
        this.i.bq = ensureBool(v);
    }
    /**
         * Gets or sets whether the slices can be exploded.
        */
    get allowSliceExplosion() {
        return this.i.bp;
    }
    set allowSliceExplosion(v) {
        this.i.bp = ensureBool(v);
    }
    /**
         * Gets or sets the collection of exploded slice indices.
        */
    get explodedSlices() {
        if (this._explodedSlices === null) {
            let coll = new IndexCollection();
            let innerColl = this.i.al;
            let wasNull = false;
            if (!innerColl) {
                wasNull = true;
                innerColl = new IndexCollection_internal();
            }
            this._explodedSlices = coll._fromInner(innerColl);
            if (wasNull) {
                this.i.al = innerColl;
            }
        }
        return this._explodedSlices;
    }
    set explodedSlices(v) {
        let coll = new IndexCollection();
        this._explodedSlices = coll._fromOuter(v);
        let innerColl = new IndexCollection_internal();
        let va = typeof v == 'string' ? coll._splitOuter(v) : v;
        innerColl._inner = va.map(item => coll._ensureOuter(item));
        this.i.al = innerColl;
    }
    /**
         * Gets or sets the legend used for the current chart.
        */
    get legend() {
        return this.i.ai;
    }
    set legend(v) {
        this.i.ai = v;
    }
    /**
         * Gets or sets the pixel amount by which the labels are offset from the edge of the slices.
        */
    get labelExtent() {
        return this.i.cm;
    }
    set labelExtent(v) {
        this.i.cm = +v;
    }
    /**
         * Gets or sets the starting angle of the chart.
         * The default zero value is equivalent to 3 o'clock.
        */
    get startAngle() {
        return this.i.ct;
    }
    set startAngle(v) {
        this.i.ct = +v;
    }
    /**
         * Gets or sets the rotational direction of the chart.
        */
    get sweepDirection() {
        return this.i.gx;
    }
    set sweepDirection(v) {
        this.i.gx = ensureEnum(SweepDirection_$type, v);
    }
    /**
         * Gets or sets the palette of brushes to use for coloring the slices.
        */
    get brushes() {
        return fromBrushCollection(this.i.ag);
    }
    set brushes(v) {
        this.i.ag = toBrushCollection(v);
    }
    /**
         * Gets or sets the palette of brushes to use for outlines on the slices.
        */
    get outlines() {
        return fromBrushCollection(this.i.ah);
    }
    set outlines(v) {
        this.i.ah = toBrushCollection(v);
    }
    /**
         * Gets or sets the LegendItemTemplate property.
         * The legend item control content is created according to the LegendItemTemplate on-demand by
         * the chart object itself.
        */
    get legendItemTemplate() {
        return this.i.legendItemTemplate;
    }
    set legendItemTemplate(v) {
        this.i.legendItemTemplate = v;
    }
    /**
         * Gets or sets the LegendItemBadgeTemplate property.
         * The legend item badge is created according to the LegendItemBadgeTemplate on-demand by
         * the chart object itself.
        */
    get legendItemBadgeTemplate() {
        return this.i.legendItemBadgeTemplate;
    }
    set legendItemBadgeTemplate(v) {
        this.i.legendItemBadgeTemplate = v;
    }
    /**
         * Gets or sets whether all surface interactions with the plot area should be disabled.
        */
    get isSurfaceInteractionDisabled() {
        return this.i.bv;
    }
    set isSurfaceInteractionDisabled(v) {
        this.i.bv = ensureBool(v);
    }
    /**
         * Sets or gets a function which takes an object that produces a formatted label for displaying in the chart.
        */
    get formatLabel() {
        return this.i.at;
    }
    set formatLabel(v) {
        this.i.at = v;
    }
    /**
         * Sets or gets a function which takes an object that produces a formatted label for displaying in the chart's legend.
        */
    get formatLegendLabel() {
        return this.i.au;
    }
    set formatLegendLabel(v) {
        this.i.au = v;
    }
    /**
         * Gets or sets the scaling value used to affect the pixel density of the control.
         * A higher scaling ratio will produce crisper visuals at the expense of memory.  Lower values will cause the control
         * to appear blurry.
        */
    get pixelScalingRatio() {
        return this.i.cq;
    }
    set pixelScalingRatio(v) {
        this.i.cq = +v;
    }
    /**
         * Resolved pixel scaling ratio. Unless explicitly overridden by the PieChartBase.PixelScalingRatio property,
         * this one returns the default ratio enforced by device. High resolution devices will initialize this property
         * to a higher value.
        */
    get actualPixelScalingRatio() {
        return this.i.cd;
    }
    /**
         * Gets or sets which mode to use for selecting slices.
        */
    get selectionMode() {
        return this.i.a3;
    }
    set selectionMode(v) {
        this.i.a3 = ensureEnum(SliceSelectionMode_$type, v);
    }
    /**
         * Gets or sets the currently selected data item.  If a different data item is provided the pie chart
         * will select the slice associated with the new item.
        */
    get selectedItem() {
        return this.i.selectedItem;
    }
    set selectedItem(v) {
        this.i.selectedItem = v;
    }
    /**
         * Manually overrides the style to use for the labels.
        */
    get textStyle() {
        return this.i.eb;
    }
    set textStyle(v) {
        this.i.eb = v;
    }
    /**
         * Returns the chart visuals expressed as a serialized string.
        
        */
    exportSerializedVisualData() {
        let iv = this.i.c8();
        return (iv);
    }
    /**
         * Simulates a mouse click action at the specified point.
        
        * @param point  * The point to click at.
        */
    simulateLeftClick(point) {
        this.i.fl(toPoint(point));
    }
    /**
         * Invoked by the containing object to provide reference to the container.
        
        * @param container  * Reference to the container.
        */
    provideContainer(container) {
        this.i.provideContainer(container);
    }
    /**
         * Notification from the containing object that the container has been resized.
        
        */
    notifyContainerResized() {
        this.i.notifyContainerResized();
    }
    /**
         * Invoked when the instance is being destroyed.
        
        */
    destroy() {
        this.i.destroy();
    }
    /**
         * Use to force the pie chart to finish any deferred work before printing or evaluating its visual.
         * This should only be called if the visual of the pie chart needs to be synchronously saved or evaluated.
         * Calling this method too often will hinder the performance of the pie chart.
        
        */
    flush() {
        this.i.el();
    }
    notifySetItem(source_, index, oldItem, newItem) {
        this.i.eu(source_, index, oldItem, newItem);
    }
    /**
         * Manually notifies the pie chart's data source that the data it has bound to has been cleared and needs to be re-examined.
         * This should not be called if the data that the pie chart is bound to is already observable.
        
        * @param source_  * The data source.
        */
    notifyClearItems(source_) {
        this.i.eq(source_);
    }
    notifyInsertItem(source_, index, newItem) {
        this.i.es(source_, index, newItem);
    }
    notifyRemoveItem(source_, index, oldItem) {
        this.i.et(source_, index, oldItem);
    }
    /**
         * Assigns data source for the items.
        
        * @param source_  * Array of the data source items.
        */
    setWidgetLevelDataSource(source_) {
        this.i.fk(source_);
    }
    /**
         * Resets items data source.
        
        */
    removeWidgetLevelDataSource() {
        this.i.fb();
    }
    /**
         * Invoked when style is updated.
        
        */
    styleUpdated() {
        this.i.fp();
    }
    /**
         * Raised when the slice's label is clicked.
        */
    get labelClick() {
        if (this._labelClick == null) {
            this._labelClick = new EventEmitter();
            this.i.labelClick = delegateCombine(this.i.labelClick, (o, e) => {
                this._runInZone(() => {
                    let outerArgs = new LabelClickEventArgs();
                    outerArgs._provideImplementation(e);
                    this._labelClick.emit({
                        sender: this,
                        args: outerArgs
                    });
                });
            });
        }
        return this._labelClick;
    }
    /**
         * Raised when the SelectedItem property is changing.  This event is cancelable.
        */
    get selectedItemChanging() {
        if (this._selectedItemChanging == null) {
            this._selectedItemChanging = new EventEmitter();
            this.i.selectedItemChanging = delegateCombine(this.i.selectedItemChanging, (o, e) => {
                this._runInZone(() => {
                    let outerArgs = new SelectedItemChangingEventArgs();
                    outerArgs._provideImplementation(e);
                    this._selectedItemChanging.emit({
                        sender: this,
                        args: outerArgs
                    });
                });
            });
        }
        return this._selectedItemChanging;
    }
    /**
         * Raised when the SelectedItems collection is changing.  This event is cancelable.
        */
    get selectedItemsChanging() {
        if (this._selectedItemsChanging == null) {
            this._selectedItemsChanging = new EventEmitter();
            this.i.selectedItemsChanging = delegateCombine(this.i.selectedItemsChanging, (o, e) => {
                this._runInZone(() => {
                    let outerArgs = new SelectedItemsChangingEventArgs();
                    outerArgs._provideImplementation(e);
                    this._selectedItemsChanging.emit({
                        sender: this,
                        args: outerArgs
                    });
                });
            });
        }
        return this._selectedItemsChanging;
    }
    /**
         * Raised when the SelectedItem property has changed.
        */
    get selectedItemChanged() {
        if (this._selectedItemChanged == null) {
            this._selectedItemChanged = new EventEmitter();
            this.i.selectedItemChanged = delegateCombine(this.i.selectedItemChanged, (o, e) => {
                this._runInZone(() => {
                    let outerArgs = new SelectedItemChangedEventArgs();
                    outerArgs._provideImplementation(e);
                    this._selectedItemChanged.emit({
                        sender: this,
                        args: outerArgs
                    });
                });
            });
        }
        return this._selectedItemChanged;
    }
    /**
         * Raised when the SelectedItems collection has changed.
        */
    get selectedItemsChanged() {
        if (this._selectedItemsChanged == null) {
            this._selectedItemsChanged = new EventEmitter();
            this.i.selectedItemsChanged = delegateCombine(this.i.selectedItemsChanged, (o, e) => {
                this._runInZone(() => {
                    let outerArgs = new SelectedItemsChangedEventArgs();
                    outerArgs._provideImplementation(e);
                    this._selectedItemsChanged.emit({
                        sender: this,
                        args: outerArgs
                    });
                });
            });
        }
        return this._selectedItemsChanged;
    }
    /**
         * Raised when the slice is clicked.
        */
    get sliceClick() {
        if (this._sliceClick == null) {
            this._sliceClick = new EventEmitter();
            this.i.sliceClick = delegateCombine(this.i.sliceClick, (o, e) => {
                this._runInZone(() => {
                    let outerArgs = new SliceClickEventArgs();
                    outerArgs._provideImplementation(e);
                    this._sliceClick.emit({
                        sender: this,
                        args: outerArgs
                    });
                });
            });
        }
        return this._sliceClick;
    }
    _runInZone(act) {
        if (this._zoneRunner != null) {
            this._zoneRunner(act);
        }
        else {
            act();
        }
    }
}
IgxPieChartBaseComponent.propDecorators = {
    "innerExtent": [{ type: Input },],
    "valueMemberPath": [{ type: Input },],
    "labelMemberPath": [{ type: Input },],
    "legendLabelMemberPath": [{ type: Input },],
    "labelsPosition": [{ type: Input },],
    "labelOuterColor": [{ type: Input },],
    "labelInnerColor": [{ type: Input },],
    "leaderLineVisibility": [{ type: Input },],
    "leaderLineType": [{ type: Input },],
    "leaderLineMargin": [{ type: Input },],
    "toolTip": [{ type: Input },],
    "othersCategoryThreshold": [{ type: Input },],
    "othersCategoryType": [{ type: Input },],
    "othersCategoryText": [{ type: Input },],
    "explodedRadius": [{ type: Input },],
    "radiusFactor": [{ type: Input },],
    "allowSliceSelection": [{ type: Input },],
    "allowSliceExplosion": [{ type: Input },],
    "explodedSlices": [{ type: Input },],
    "legend": [{ type: Input },],
    "labelExtent": [{ type: Input },],
    "startAngle": [{ type: Input },],
    "sweepDirection": [{ type: Input },],
    "brushes": [{ type: Input },],
    "outlines": [{ type: Input },],
    "legendItemTemplate": [{ type: Input },],
    "legendItemBadgeTemplate": [{ type: Input },],
    "isSurfaceInteractionDisabled": [{ type: Input },],
    "formatLabel": [{ type: Input },],
    "formatLegendLabel": [{ type: Input },],
    "pixelScalingRatio": [{ type: Input },],
    "selectionMode": [{ type: Input },],
    "selectedItem": [{ type: Input },],
    "textStyle": [{ type: Input },],
    "labelClick": [{ type: Output },],
    "selectedItemChanging": [{ type: Output },],
    "selectedItemsChanging": [{ type: Output },],
    "selectedItemChanged": [{ type: Output },],
    "selectedItemsChanged": [{ type: Output },],
    "sliceClick": [{ type: Output },],
};
//# sourceMappingURL=igx-pie-chart-base-component.js.map