import { EventEmitter, Output, Input } from '@angular/core';
import { delegateCombine } from "igniteui-angular-core/ES2015/type";
import { ChartHitTestMode, ChartHitTestMode_$type } from "./ChartHitTestMode";
import { WindowResponse, WindowResponse_$type } from "./WindowResponse";
import { Visibility, Visibility_$type } from "igniteui-angular-core/ES2015/Visibility";
import { InteractionState, InteractionState_$type } from "igniteui-angular-core/ES2015/InteractionState";
import { ModifierKeys, ModifierKeys_$type } from "igniteui-angular-core/ES2015/ModifierKeys";
import { HorizontalAlignment, HorizontalAlignment_$type } from "igniteui-angular-core/ES2015/HorizontalAlignment";
import { ChartCursorEventArgs } from "./igx-chart-cursor-event-args";
import { DataChartMouseButtonEventArgs } from "./igx-data-chart-mouse-button-event-args";
import { ChartMouseEventArgs } from "./igx-chart-mouse-event-args";
import { RectChangedEventArgs } from "igniteui-angular-core/ES2015/igx-rect-changed-event-args";
import { fromPoint, toPoint, ensureBool, fromRect, toRect, ensureEnum, brushToString, stringToBrush } from "igniteui-angular-core/ES2015/componentUtil";
import { SyncSettings } from "./SyncSettings";
/**
 * Represents a control for viewing series objects.
*/
export const IgxSeriesViewerComponent_PROVIDERS = [];
export class IgxSeriesViewerComponent {
    constructor() {
        this._seriesCursorMouseMove = null;
        this._seriesMouseLeftButtonDown = null;
        this._seriesMouseLeftButtonUp = null;
        this._seriesMouseMove = null;
        this._seriesMouseEnter = null;
        this._seriesMouseLeave = null;
        this._windowRectChanged = null;
        this._sizeChanged = null;
        this._gridAreaRectChanged = null;
        this._zoneRunner = null;
        this._implementation = this.createImplementation();
        this._implementation.externalObject = this;
        this.onImplementationCreated();
    }
    createImplementation() {
        return null;
    }
    ngOnInit() {
    }
    get i() {
        return this._implementation;
    }
    onImplementationCreated() {
    }
    /**
         * Gets or sets the cross hair point (in world coordinates)
         * Either or both of the crosshair point's X and Y may be set to double.NaN, in which
         * case the relevant crosshair line is hidden.
        */
    get crosshairPoint() {
        return fromPoint(this.i.mc);
    }
    set crosshairPoint(v) {
        this.i.mc = toPoint(v);
    }
    /**
         * Gets or sets whether the series animations should be allowed when a range change has been detected on an axis.
        */
    get animateSeriesWhenAxisRangeChanges() {
        return this.i.ca;
    }
    set animateSeriesWhenAxisRangeChanges(v) {
        this.i.ca = ensureBool(v);
    }
    /**
         * Gets the viewport rectangle associated with the SeriesViewer, the physical dimensions of the plot area.
        */
    get viewportRect() {
        return fromRect(this.i.mx);
    }
    /**
         * Gets the EffectiveViewport rectangle, representing the effective viewport area after margins have been subtracted.
        */
    get effectiveViewport() {
        return fromRect(this.i.mo);
    }
    /**
         * Represents the subset area within the viewport into which content should be mapped.
         * This is the projection of the current EffectiveViewport into the viewport at current zoom level.
        */
    get contentViewport() {
        return fromRect(this.i.mn);
    }
    /**
         * A rectangle representing the portion of the SeriesViewer currently in view.
         * A rectangle at X=0, Y=0 with a Height and Width of 1 implies the entire plotting area is in view.  A Height and Width of .5 would imply that the view is halfway zoomed in.
        */
    get windowRect() {
        return fromRect(this.i.my);
    }
    set windowRect(v) {
        this.i.my = toRect(v);
    }
    /**
         * Gets or sets whether the series viewer should use cached tiles during zooms rather than the default live content.
        */
    get useTiledZooming() {
        return this.i.dg;
    }
    set useTiledZooming(v) {
        this.i.dg = ensureBool(v);
    }
    /**
         * Gets or sets whether the series viewer should prefer selecting higher resolution tiles over lower resolution tiles when performing tile zooming. Setting this to true will lower performance but increase quality.
        */
    get preferHigherResolutionTiles() {
        return this.i.c8;
    }
    set preferHigherResolutionTiles(v) {
        this.i.c8 = ensureBool(v);
    }
    /**
         * Gets or sets the maximum number of zoom tiles that the series viewer should cache while in tiled zooming mode.
        */
    get zoomTileCacheSize() {
        return this.i.e3;
    }
    set zoomTileCacheSize(v) {
        this.i.e3 = +v;
    }
    /**
         * Gets or sets the duration the highlighting/de-highlighting effects.
        */
    get highlightingTransitionDuration() {
        return this.i.e2;
    }
    set highlightingTransitionDuration(v) {
        this.i.e2 = +v;
    }
    /**
         * Gets or sets the whether the series viewer can allow the page to pan if a control pan is not possible in the requested direction.
        */
    get isPagePanningAllowed() {
        return this.i.cv;
    }
    set isPagePanningAllowed(v) {
        this.i.cv = ensureBool(v);
    }
    /**
         * Determines the method of hit testing used when mousing over elements in the chart.
        */
    get contentHitTestMode() {
        return this.i.ap;
    }
    set contentHitTestMode(v) {
        this.i.ap = ensureEnum(ChartHitTestMode_$type, v);
    }
    /**
         * Resolved method of hit testing used when the pointer is over elements in the chart.
        */
    get actualContentHitTestMode() {
        return this.i.ao;
    }
    /**
         * Gets or sets whether all surface interactions with the plot area should be disabled.
        */
    get isSurfaceInteractionDisabled() {
        return this.i.cw;
    }
    set isSurfaceInteractionDisabled(v) {
        this.i.cw = ensureBool(v);
    }
    get isMap() {
        return this.i.cu;
    }
    /**
         * The response to user panning and zooming: whether to update the view immediately while the user action is happening, or to defer the update to after the user action is complete.  The user action will be an action such as a mouse drag which causes panning and/or zooming to occur.
        */
    get windowResponse() {
        return this.i.ba;
    }
    set windowResponse(v) {
        this.i.ba = ensureEnum(WindowResponse_$type, v);
    }
    /**
         * Sets or gets the minimum width that the window rect is allowed to reach before being clamped.
         * Decrease this value if you want to allow for further zooming into the viewer.
         * If this value is lowered too much it can cause graphical corruption due to floating point arithmetic inaccuracy.
        */
    get windowRectMinWidth() {
        return this.i.eu;
    }
    set windowRectMinWidth(v) {
        this.i.eu = +v;
    }
    /**
         * Sets or gets the Synchronization channel to use for the SeriesViewer.
        */
    get syncChannel() {
        return this.i.gk;
    }
    set syncChannel(v) {
        this.i.gk = v;
    }
    /**
         * The visibility of the OverviewPlusDetailPane.
        */
    get overviewPlusDetailPaneVisibility() {
        return this.i.m2;
    }
    set overviewPlusDetailPaneVisibility(v) {
        this.i.m2 = ensureEnum(Visibility_$type, v);
    }
    /**
         * Gets or sets the current SeriesViewer's crosshair visibility override.
        */
    get crosshairVisibility() {
        return this.i.m1;
    }
    set crosshairVisibility(v) {
        this.i.m1 = ensureEnum(Visibility_$type, v);
    }
    /**
         * Gets or sets the brush used as the background for the current SeriesViewer object's plot area.
        */
    get plotAreaBackground() {
        return brushToString(this.i.l7);
    }
    set plotAreaBackground(v) {
        this.i.l7 = stringToBrush(v);
    }
    /**
         * Gets or sets the DefaultInteraction property.
         * The default interaction state defines the SeriesViewer's response to mouse events.
        */
    get defaultInteraction() {
        return this.i.bc;
    }
    set defaultInteraction(v) {
        this.i.bc = ensureEnum(InteractionState_$type, v);
    }
    /**
         * Gets or sets the current SeriesViewer's DragModifier property.
        */
    get dragModifier() {
        return this.i.lu;
    }
    set dragModifier(v) {
        this.i.lu = ensureEnum(ModifierKeys_$type, v);
    }
    /**
         * Gets or sets the current SeriesViewer's PanModifier property.
        */
    get panModifier() {
        return this.i.lv;
    }
    set panModifier(v) {
        this.i.lv = ensureEnum(ModifierKeys_$type, v);
    }
    /**
         * Gets or sets the preview rectangle.
         * The preview rectangle may be set to Rect.Empty, in which case the visible preview
         * strokePath is hidden.
        */
    get previewRect() {
        return fromRect(this.i.mt);
    }
    set previewRect(v) {
        this.i.mt = toRect(v);
    }
    /**
         * A number between 0 and 1 determining the position of the horizontal scroll.
         * This property is effectively a shortcut to the X position of the WindowRect property.
        */
    get windowPositionHorizontal() {
        return this.i.es;
    }
    set windowPositionHorizontal(v) {
        this.i.es = +v;
    }
    /**
         * A number between 0 and 1 determining the position of the vertical scroll.
         * This property is effectively a shortcut to the Y position of the WindowRect property.
        */
    get windowPositionVertical() {
        return this.i.et;
    }
    set windowPositionVertical(v) {
        this.i.et = +v;
    }
    /**
         * Text to display above the plot area.
        */
    get chartTitle() {
        return this.i.gm;
    }
    set chartTitle(v) {
        this.i.gm = v;
    }
    /**
         * Gets or sets the TitleHorizontalAlignment property.
        */
    get titleHorizontalAlignment() {
        return this.i.lt;
    }
    set titleHorizontalAlignment(v) {
        this.i.lt = ensureEnum(HorizontalAlignment_$type, v);
    }
    /**
         * Gets or sets the SubtitleHorizontalAlignment property.
        */
    get subtitleHorizontalAlignment() {
        return this.i.ls;
    }
    set subtitleHorizontalAlignment(v) {
        this.i.ls = ensureEnum(HorizontalAlignment_$type, v);
    }
    get titleTextStyle() {
        return this.i.gt;
    }
    set titleTextStyle(v) {
        this.i.gt = v;
    }
    get subtitleTextStyle() {
        return this.i.gh;
    }
    set subtitleTextStyle(v) {
        this.i.gh = v;
    }
    /**
         * Gets or sets the Color used for the Title Text.
        */
    get titleTextColor() {
        return brushToString(this.i.ma);
    }
    set titleTextColor(v) {
        this.i.ma = stringToBrush(v);
    }
    /**
         * Gets or sets the Color used for the Subtitle Text.
        */
    get subtitleTextColor() {
        return brushToString(this.i.l9);
    }
    set subtitleTextColor(v) {
        this.i.l9 = stringToBrush(v);
    }
    /**
         * Margin applied above the title.
        */
    get titleTopMargin() {
        return this.i.eq;
    }
    set titleTopMargin(v) {
        this.i.eq = +v;
    }
    /**
         * Margin applied to the left of the title.
        */
    get titleLeftMargin() {
        return this.i.eo;
    }
    set titleLeftMargin(v) {
        this.i.eo = +v;
    }
    /**
         * Margin applied to the right of the title.
        */
    get titleRightMargin() {
        return this.i.ep;
    }
    set titleRightMargin(v) {
        this.i.ep = +v;
    }
    /**
         * Margin applied below the title.
        */
    get titleBottomMargin() {
        return this.i.en;
    }
    set titleBottomMargin(v) {
        this.i.en = +v;
    }
    /**
         * Margin applied above the subtitle.
        */
    get subtitleTopMargin() {
        return this.i.em;
    }
    set subtitleTopMargin(v) {
        this.i.em = +v;
    }
    /**
         * Margin applied to the left of the subtitle.
        */
    get subtitleLeftMargin() {
        return this.i.ek;
    }
    set subtitleLeftMargin(v) {
        this.i.ek = +v;
    }
    /**
         * Margin applied to the right of the subtitle.
        */
    get subtitleRightMargin() {
        return this.i.el;
    }
    set subtitleRightMargin(v) {
        this.i.el = +v;
    }
    /**
         * Margin applied below the subtitle.
        */
    get subtitleBottomMargin() {
        return this.i.ej;
    }
    set subtitleBottomMargin(v) {
        this.i.ej = +v;
    }
    /**
         * Gets or sets the Subtitle property.
         * The Title property defines the Subtitle of the chart
        */
    get subtitle() {
        return this.i.ga;
    }
    set subtitle(v) {
        this.i.ga = v;
    }
    /**
         * Gets or sets the channel with which to synchronize.
        */
    get SyncChannel() {
        return this.i.a9 ? this.i.a9.ae : null;
    }
    set SyncChannel(v) {
        this.ensureSyncSettings();
        this.i.a9.ae = v;
    }
    /**
         * Gets or sets the bool used to display the window preview shadow.
        */
    get SynchronizeVertically() {
        return this.i.a9 ? this.i.a9.ad : false;
    }
    set SynchronizeVertically(v) {
        this.ensureSyncSettings();
        this.i.a9.ad = ensureBool(v);
    }
    /**
         * Gets or sets the bool used to display the window preview shadow.
        */
    get SynchronizeHorizontally() {
        return this.i.a9 ? this.i.a9.ac : false;
    }
    set SynchronizeHorizontally(v) {
        this.ensureSyncSettings();
        this.i.a9.ac = ensureBool(v);
    }
    ensureSyncSettings() {
        if (this.i.a9) {
            return;
        }
        this.i.a9 = new SyncSettings();
    }
    /**
         * Sets or gets the top margin to use around the chart content.
        */
    get topMargin() {
        return this.i.er;
    }
    set topMargin(v) {
        this.i.er = +v;
    }
    /**
         * Sets or gets the left margin to use around the chart content.
        */
    get leftMargin() {
        return this.i.eg;
    }
    set leftMargin(v) {
        this.i.eg = +v;
    }
    /**
         * Sets or gets the right margin to use around the chart content.
        */
    get rightMargin() {
        return this.i.ei;
    }
    set rightMargin(v) {
        this.i.ei = +v;
    }
    /**
         * Sets or gets the bottom margin to use around the chart content.
        */
    get bottomMargin() {
        return this.i.ec;
    }
    set bottomMargin(v) {
        this.i.ec = +v;
    }
    /**
         * Sets or gets the automatic width to add when automatically adding margins to the chart.
        */
    get autoMarginWidth() {
        return this.i.eb;
    }
    set autoMarginWidth(v) {
        this.i.eb = +v;
    }
    /**
         * Sets or gets the automatic height to add when automatically adding margins to the chart.
        */
    get autoMarginHeight() {
        return this.i.ea;
    }
    set autoMarginHeight(v) {
        this.i.ea = +v;
    }
    /**
         * Gets or sets the IsAntiAliasingEnabledDuringInteraction property.
        */
    get isAntiAliasingEnabledDuringInteraction() {
        return this.i.cm;
    }
    set isAntiAliasingEnabledDuringInteraction(v) {
        this.i.cm = ensureBool(v);
    }
    /**
         * Gets or sets the scaling value used to affect the pixel density of the control.
         * A higher scaling ratio will produce crisper visuals at the expense of memory.  Lower values will cause the control
         * to appear blurry.
        */
    get pixelScalingRatio() {
        return this.i.eh;
    }
    set pixelScalingRatio(v) {
        this.i.eh = +v;
    }
    /**
         * Method of pixel scaling to use during end user interaction with the chart.
        */
    get interactionPixelScalingRatio() {
        return this.i.ef;
    }
    set interactionPixelScalingRatio(v) {
        this.i.ef = +v;
    }
    /**
         * Uri for the background image to display behind the overview plus detail pane.
        */
    get overviewPlusDetailPaneBackgroundImageUri() {
        return this.i.fy;
    }
    set overviewPlusDetailPaneBackgroundImageUri(v) {
        this.i.fy = v;
    }
    /**
         * Gets the resolved pixel scaling ratio.
        */
    get actualPixelScalingRatio() {
        return this.i.d7;
    }
    /**
         * Resolved method of pixel scaling to use during end user interaction with the chart.
        */
    get actualInteractionPixelScalingRatio() {
        return this.i.d6;
    }
    /**
         * Gets the actual value of the window rectangle, which represents the current zoom level.
        */
    get actualWindowRect() {
        return fromRect(this.i.mk);
    }
    /**
         * A number between 0 and 1 determining the position of the horizontal scroll.
         * This property is effectively a shortcut to the Left of the ActualWindowRect property.
        */
    get actualWindowPositionHorizontal() {
        return this.i.d8;
    }
    /**
         * A number between 0 and 1 determining the position of the vertical scroll.
         * This property is effectively a shortcut to the Top of the ActualWindowRect property.
        */
    get actualWindowPositionVertical() {
        return this.i.d9;
    }
    /**
         * Hides the active main tooltip, if displayed.
        
        */
    hideToolTip() {
        this.i.hk();
    }
    /**
         * Manually starts a tiled zoom if one isn't already running.
        
        */
    startTiledZoomingIfNecessary() {
        this.i.j2();
    }
    /**
         * Manually ends a tiled zoom if one is running.
        
        */
    endTiledZoomingIfRunning() {
        this.i.hf();
    }
    /**
         * Clears the tile zoom tile cache so that new tiles will be generated. Only applies if the viewer is using a tile based zoom.
        
        */
    clearTileZoomCache() {
        this.i.g9();
    }
    /**
         * Resets the zoom level to default.
        
        */
    resetZoom() {
        this.i.jw();
    }
    /**
         * Gets actual window scale for horizontal dimension of the control
        
        */
    getActualWindowScaleHorizontal() {
        let iv = this.i.ed();
        return (iv);
    }
    /**
         * Gets actual window scale for vertical dimension of the control
        
        */
    getActualWindowScaleVertical() {
        let iv = this.i.ee();
        return (iv);
    }
    /**
         * Notification from the containing object that the container has been resized.
        
        */
    notifyContainerResized() {
        this.i.notifyContainerResized();
    }
    /**
         * Attaches the given series to the chart.
        
        * @param s  * The series to attach to the chart.
        */
    attachSeries(s) {
        this.i.g7((s == null ? null : s.i));
    }
    notifySetItem(source_, index, oldItem, newItem) {
        this.i.hw(source_, index, oldItem, newItem);
    }
    /**
         * Used to manually notify the SeriesViewer that the data source has reset or cleared its items.  Invoking this method is only necessary if that datasource is not observable.
        
        * @param source_  * The data source which was cleared or reset.
        */
    notifyClearItems(source_) {
        this.i.hr(source_);
    }
    notifyInsertItem(source_, index, newItem) {
        this.i.hu(source_, index, newItem);
    }
    notifyRemoveItem(source_, index, oldItem) {
        this.i.hv(source_, index, oldItem);
    }
    /**
         * Release any resources held by the control.
        
        */
    destroy() {
        this.i.hd();
    }
    /**
         * Use to force the SeriesViewer to finish any deferred work before printing or evaluating its visual.
         * This should only be called if the visual of the SeriesViewer needs to be synchronously saved or evaluated.
         * Calling this method too often will hinder the performance of the SeriesViewer.
        
        */
    flush() {
        this.i.flush();
    }
    /**
         * Occurs when the cursors are moved over a series in this SeriesViewer.
        */
    get seriesCursorMouseMove() {
        if (this._seriesCursorMouseMove == null) {
            this._seriesCursorMouseMove = new EventEmitter();
            this.i.seriesCursorMouseMove = delegateCombine(this.i.seriesCursorMouseMove, (o, e) => {
                let outerArgs = new ChartCursorEventArgs();
                outerArgs._provideImplementation(e);
                this._seriesCursorMouseMove.emit({
                    sender: this,
                    args: outerArgs
                });
            });
        }
        return this._seriesCursorMouseMove;
    }
    /**
         * Occurs when the left mouse button is pressed while the mouse pointer is over a Series.
        */
    get seriesMouseLeftButtonDown() {
        if (this._seriesMouseLeftButtonDown == null) {
            this._seriesMouseLeftButtonDown = new EventEmitter();
            this.i.seriesMouseLeftButtonDown = delegateCombine(this.i.seriesMouseLeftButtonDown, (o, e) => {
                this._runInZone(() => {
                    let outerArgs = new DataChartMouseButtonEventArgs();
                    outerArgs._provideImplementation(e);
                    this._seriesMouseLeftButtonDown.emit({
                        sender: this,
                        args: outerArgs
                    });
                });
            });
        }
        return this._seriesMouseLeftButtonDown;
    }
    /**
         * Occurs when the left mouse button is released while the mouse pointer is over a Series.
        */
    get seriesMouseLeftButtonUp() {
        if (this._seriesMouseLeftButtonUp == null) {
            this._seriesMouseLeftButtonUp = new EventEmitter();
            this.i.seriesMouseLeftButtonUp = delegateCombine(this.i.seriesMouseLeftButtonUp, (o, e) => {
                this._runInZone(() => {
                    let outerArgs = new DataChartMouseButtonEventArgs();
                    outerArgs._provideImplementation(e);
                    this._seriesMouseLeftButtonUp.emit({
                        sender: this,
                        args: outerArgs
                    });
                });
            });
        }
        return this._seriesMouseLeftButtonUp;
    }
    /**
         * Occurs when the mouse pointer moves while over a Series.
        */
    get seriesMouseMove() {
        if (this._seriesMouseMove == null) {
            this._seriesMouseMove = new EventEmitter();
            this.i.seriesMouseMove = delegateCombine(this.i.seriesMouseMove, (o, e) => {
                let outerArgs = new ChartMouseEventArgs();
                outerArgs._provideImplementation(e);
                this._seriesMouseMove.emit({
                    sender: this,
                    args: outerArgs
                });
            });
        }
        return this._seriesMouseMove;
    }
    /**
         * Occurs when the mouse pointer enters a Series.
        */
    get seriesMouseEnter() {
        if (this._seriesMouseEnter == null) {
            this._seriesMouseEnter = new EventEmitter();
            this.i.seriesMouseEnter = delegateCombine(this.i.seriesMouseEnter, (o, e) => {
                this._runInZone(() => {
                    let outerArgs = new ChartMouseEventArgs();
                    outerArgs._provideImplementation(e);
                    this._seriesMouseEnter.emit({
                        sender: this,
                        args: outerArgs
                    });
                });
            });
        }
        return this._seriesMouseEnter;
    }
    /**
         * Occurs when the mouse pointer leaves a Series.
        */
    get seriesMouseLeave() {
        if (this._seriesMouseLeave == null) {
            this._seriesMouseLeave = new EventEmitter();
            this.i.seriesMouseLeave = delegateCombine(this.i.seriesMouseLeave, (o, e) => {
                this._runInZone(() => {
                    let outerArgs = new ChartMouseEventArgs();
                    outerArgs._provideImplementation(e);
                    this._seriesMouseLeave.emit({
                        sender: this,
                        args: outerArgs
                    });
                });
            });
        }
        return this._seriesMouseLeave;
    }
    /**
         * Occurs just after the current SeriesViewer's window rectangle is changed.
        */
    get windowRectChanged() {
        if (this._windowRectChanged == null) {
            this._windowRectChanged = new EventEmitter();
            this.i.windowRectChanged = delegateCombine(this.i.windowRectChanged, (o, e) => {
                let outerArgs = new RectChangedEventArgs();
                outerArgs._provideImplementation(e);
                this._windowRectChanged.emit({
                    sender: this,
                    args: outerArgs
                });
            });
        }
        return this._windowRectChanged;
    }
    /**
         * Occurs after the size of the series viewer changes.
        */
    get sizeChanged() {
        if (this._sizeChanged == null) {
            this._sizeChanged = new EventEmitter();
            this.i.sizeChanged = delegateCombine(this.i.sizeChanged, (o, e) => {
                let outerArgs = new RectChangedEventArgs();
                outerArgs._provideImplementation(e);
                this._sizeChanged.emit({
                    sender: this,
                    args: outerArgs
                });
            });
        }
        return this._sizeChanged;
    }
    /**
         * Occurs just after the current SeriesViewer's grid area rectangle is changed.
         * The grid area may change as the result of the SeriesViewer being resized, or
         * of an axis being added or changing size, possibly in another SeriesViewer.
        */
    get gridAreaRectChanged() {
        if (this._gridAreaRectChanged == null) {
            this._gridAreaRectChanged = new EventEmitter();
            this.i.gridAreaRectChanged = delegateCombine(this.i.gridAreaRectChanged, (o, e) => {
                let outerArgs = new RectChangedEventArgs();
                outerArgs._provideImplementation(e);
                this._gridAreaRectChanged.emit({
                    sender: this,
                    args: outerArgs
                });
            });
        }
        return this._gridAreaRectChanged;
    }
    _runInZone(act) {
        if (this._zoneRunner != null) {
            this._zoneRunner(act);
        }
        else {
            act();
        }
    }
}
IgxSeriesViewerComponent.propDecorators = {
    "crosshairPoint": [{ type: Input },],
    "animateSeriesWhenAxisRangeChanges": [{ type: Input },],
    "windowRect": [{ type: Input },],
    "useTiledZooming": [{ type: Input },],
    "preferHigherResolutionTiles": [{ type: Input },],
    "zoomTileCacheSize": [{ type: Input },],
    "highlightingTransitionDuration": [{ type: Input },],
    "isPagePanningAllowed": [{ type: Input },],
    "contentHitTestMode": [{ type: Input },],
    "isSurfaceInteractionDisabled": [{ type: Input },],
    "windowResponse": [{ type: Input },],
    "windowRectMinWidth": [{ type: Input },],
    "syncChannel": [{ type: Input },],
    "overviewPlusDetailPaneVisibility": [{ type: Input },],
    "crosshairVisibility": [{ type: Input },],
    "plotAreaBackground": [{ type: Input },],
    "defaultInteraction": [{ type: Input },],
    "dragModifier": [{ type: Input },],
    "panModifier": [{ type: Input },],
    "previewRect": [{ type: Input },],
    "windowPositionHorizontal": [{ type: Input },],
    "windowPositionVertical": [{ type: Input },],
    "chartTitle": [{ type: Input },],
    "titleHorizontalAlignment": [{ type: Input },],
    "subtitleHorizontalAlignment": [{ type: Input },],
    "titleTextStyle": [{ type: Input },],
    "subtitleTextStyle": [{ type: Input },],
    "titleTextColor": [{ type: Input },],
    "subtitleTextColor": [{ type: Input },],
    "titleTopMargin": [{ type: Input },],
    "titleLeftMargin": [{ type: Input },],
    "titleRightMargin": [{ type: Input },],
    "titleBottomMargin": [{ type: Input },],
    "subtitleTopMargin": [{ type: Input },],
    "subtitleLeftMargin": [{ type: Input },],
    "subtitleRightMargin": [{ type: Input },],
    "subtitleBottomMargin": [{ type: Input },],
    "subtitle": [{ type: Input },],
    "SyncChannel": [{ type: Input },],
    "SynchronizeVertically": [{ type: Input },],
    "SynchronizeHorizontally": [{ type: Input },],
    "topMargin": [{ type: Input },],
    "leftMargin": [{ type: Input },],
    "rightMargin": [{ type: Input },],
    "bottomMargin": [{ type: Input },],
    "autoMarginWidth": [{ type: Input },],
    "autoMarginHeight": [{ type: Input },],
    "isAntiAliasingEnabledDuringInteraction": [{ type: Input },],
    "pixelScalingRatio": [{ type: Input },],
    "interactionPixelScalingRatio": [{ type: Input },],
    "overviewPlusDetailPaneBackgroundImageUri": [{ type: Input },],
    "seriesCursorMouseMove": [{ type: Output },],
    "seriesMouseLeftButtonDown": [{ type: Output },],
    "seriesMouseLeftButtonUp": [{ type: Output },],
    "seriesMouseMove": [{ type: Output },],
    "seriesMouseEnter": [{ type: Output },],
    "seriesMouseLeave": [{ type: Output },],
    "windowRectChanged": [{ type: Output },],
    "sizeChanged": [{ type: Output },],
    "gridAreaRectChanged": [{ type: Output },],
};
//# sourceMappingURL=igx-series-viewer-component.js.map