import { EventEmitter, Output, forwardRef, Input } from '@angular/core';
import { delegateCombine } from "igniteui-angular-core/ES2015/type";
import { AxisRangeChangedEventArgs } from "./igx-axis-range-changed-event-args";
import { IgxCategoryAxisBaseComponent } from "./igx-category-axis-base-component";
import { IgxAxisComponent } from "./igx-axis-component";
import { ensureBool } from "igniteui-angular-core/ES2015/componentUtil";
/**
 * Represents an category-based horizontal X axis that uses a DateTime scale.
*/
export const IgxTimeAxisBaseComponent_PROVIDERS = [{ provide: IgxCategoryAxisBaseComponent, useExisting: forwardRef(() => IgxTimeAxisBaseComponent) }, { provide: IgxAxisComponent, useExisting: forwardRef(() => IgxTimeAxisBaseComponent) }];
export class IgxTimeAxisBaseComponent extends IgxCategoryAxisBaseComponent {
    constructor() {
        super();
        this._actualRangeChanged = null;
    }
    get i() {
        return this._implementation;
    }
    /**
         * Gets or sets the DateTime mapping property for the axis.
        */
    get dateTimeMemberPath() {
        return this.i.dateTimeMemberPath;
    }
    set dateTimeMemberPath(v) {
        this.i.dateTimeMemberPath = v;
    }
    /**
         * Gets or sets whether the data assigned to the date time axis should be considered pre-sorted by date/time.
        */
    get isDataPreSorted() {
        return this.i.kv;
    }
    set isDataPreSorted(v) {
        this.i.kv = ensureBool(v);
    }
    /**
         * Gets the coerced minimum value.
        */
    get actualMinimumValue() {
        return this.i.actualMinimumValue;
    }
    /**
         * Gets the coerced maximum value.
        */
    get actualMaximumValue() {
        return this.i.actualMaximumValue;
    }
    /**
         * Gets or sets the axis MinimumValue.
        */
    get minimumValue() {
        return this.i.minimumValue;
    }
    set minimumValue(v) {
        this.i.minimumValue = v;
    }
    /**
         * Gets or sets the axis MaximumValue.
        */
    get maximumValue() {
        return this.i.maximumValue;
    }
    set maximumValue(v) {
        this.i.maximumValue = v;
    }
    /**
         * Checks if the axis is of date time axis type
        */
    get isDateTime() {
        return this.i.b5;
    }
    /**
         * Checks if axis requires sorting of items
        */
    get isSorting() {
        return this.i.cc;
    }
    /**
         * Gets the index of the data item with the value nearest the given value.
        
        * @param unscaledValue  * The value to find a value close to.
        */
    getIndexClosestToUnscaledValue(unscaledValue) {
        let iv = this.i.i$f(unscaledValue);
        return (iv);
    }
    /**
         * Updates the axis when the data has been changed.
        
        */
    notifyDataChanged() {
        this.i.i$i();
    }
    get actualRangeChanged() {
        if (this._actualRangeChanged == null) {
            this._actualRangeChanged = new EventEmitter();
            this.i.actualRangeChanged = delegateCombine(this.i.actualRangeChanged, (o, e) => {
                this._runInZone(() => {
                    let outerArgs = new AxisRangeChangedEventArgs();
                    outerArgs._provideImplementation(e);
                    this._actualRangeChanged.emit({
                        sender: this,
                        args: outerArgs
                    });
                });
            });
        }
        return this._actualRangeChanged;
    }
}
IgxTimeAxisBaseComponent.propDecorators = {
    "dateTimeMemberPath": [{ type: Input },],
    "isDataPreSorted": [{ type: Input },],
    "minimumValue": [{ type: Input },],
    "maximumValue": [{ type: Input },],
    "actualRangeChanged": [{ type: Output },],
};
//# sourceMappingURL=igx-time-axis-base-component.js.map