import { Component, forwardRef, Input, ChangeDetectionStrategy } from '@angular/core';
import { TimeAxisBreakCollection } from "./igx-time-axis-break-collection";
import { IgxTimeAxisBaseComponent } from "./igx-time-axis-base-component";
import { IgxCategoryAxisBaseComponent } from "./igx-category-axis-base-component";
import { IgxAxisComponent } from "./igx-axis-component";
import { TimeXAxis } from "./TimeXAxis";
import { TimeAxisBreakCollection as TimeAxisBreakCollection_internal } from "./TimeAxisBreakCollection";
import { TimeAxisBreak } from "./TimeAxisBreak";
import { SyncableObservableCollection$1 } from "igniteui-angular-core/ES2015/SyncableObservableCollection$1";
/**
 * A horizontal axis that uses a DateTime scale.
*/
export const IgxTimeXAxisComponent_PROVIDERS = [{ provide: IgxTimeAxisBaseComponent, useExisting: forwardRef(() => IgxTimeXAxisComponent) }, { provide: IgxCategoryAxisBaseComponent, useExisting: forwardRef(() => IgxTimeXAxisComponent) }, { provide: IgxAxisComponent, useExisting: forwardRef(() => IgxTimeXAxisComponent) }];
export class IgxTimeXAxisComponent extends IgxTimeAxisBaseComponent {
    constructor() {
        super();
        this._breaks = null;
    }
    createImplementation() {
        return new TimeXAxis();
    }
    get i() {
        return this._implementation;
    }
    /**
         * TimeAxisBreaks to apply to this axis, representing spans of time to omit, such as weekends.
        */
    get breaks() {
        if (this._breaks === null) {
            let coll = new TimeAxisBreakCollection();
            let innerColl = this.i.lw;
            let wasNull = false;
            if (!innerColl) {
                wasNull = true;
                innerColl = new TimeAxisBreakCollection_internal();
            }
            this._breaks = coll._fromInner(innerColl);
        }
        return this._breaks;
    }
    set breaks(v) {
        if (this._breaks !== null) {
            this._breaks._setSyncTarget(null);
            this._breaks = null;
        }
        let coll = new TimeAxisBreakCollection();
        this._breaks = coll._fromOuter(v);
        let syncColl = new SyncableObservableCollection$1(TimeAxisBreak.$type);
        let innerColl = this.i.lw;
        let wasNull = false;
        if (!innerColl) {
            wasNull = true;
            innerColl = new TimeAxisBreakCollection_internal();
        }
        syncColl._inner = innerColl;
        syncColl.clear();
        this._breaks._setSyncTarget(syncColl);
    }
    get isCategoryDateTime() {
        return this.i.b3;
    }
    /**
         * Gets the index of the data item with the value nearest the given value.
        
        * @param unscaledValue  * The value to find a value close to.
        */
    getIndexClosestToUnscaledValue(unscaledValue) {
        let iv = this.i.i$f(unscaledValue);
        return (iv);
    }
}
IgxTimeXAxisComponent.decorators = [
    { type: Component, args: [{
                selector: 'igx-time-x-axis',
                template: ``,
                providers: [{ provide: IgxTimeAxisBaseComponent, useExisting: forwardRef(() => IgxTimeXAxisComponent) }, { provide: IgxCategoryAxisBaseComponent, useExisting: forwardRef(() => IgxTimeXAxisComponent) }, { provide: IgxAxisComponent, useExisting: forwardRef(() => IgxTimeXAxisComponent) }],
                changeDetection: ChangeDetectionStrategy.OnPush
            },] },
];
/** @nocollapse */
IgxTimeXAxisComponent.ctorParameters = () => [];
IgxTimeXAxisComponent.propDecorators = {
    "breaks": [{ type: Input },],
};
//# sourceMappingURL=igx-time-x-axis-component.js.map