import { Type } from '@angular/core';
import { IgPoint } from "igniteui-angular-core/ES5/IgPoint";
import { TrendLineType } from "igniteui-angular-core/ES5/TrendLineType";
import { CategorySeriesMarkerCollisionAvoidance } from "./CategorySeriesMarkerCollisionAvoidance";
import { ConsolidatedItemHitTestBehavior } from "./ConsolidatedItemHitTestBehavior";
import { IgxCategorySeriesComponent } from "./igx-category-series-component";
import { IgxMarkerSeriesComponent } from "./igx-marker-series-component";
import { IgxSeriesComponent } from "./igx-series-component";
import { AnchoredCategorySeries } from "./AnchoredCategorySeries";
/**
 * Represents the base class for all IgxDataChartComponent anchored category/value series.
*/
export declare const IgxAnchoredCategorySeriesComponent_PROVIDERS: ({
    provide: typeof IgxMarkerSeriesComponent;
    useExisting: Type<any>;
} | {
    provide: typeof IgxSeriesComponent;
    useExisting: Type<any>;
})[];
export declare abstract class IgxAnchoredCategorySeriesComponent extends IgxCategorySeriesComponent {
    readonly i: AnchoredCategorySeries;
    constructor();
    /**
     * Gets or sets the value mapping property for the current series object.
    */
    valueMemberPath: string;
    /**
     * Gets or sets the trend type for the current series object.
    */
    trendLineType: TrendLineType;
    /**
     * Gets or sets the brush to use to draw the trend line.
    */
    trendLineBrush: string;
    /**
     * Gets the effective TrendLineBrush for this series.
    */
    readonly actualTrendLineBrush: string;
    /**
     * Gets or sets the thickness of the current series object's trend line.
    */
    trendLineThickness: number;
    /**
     * Gets or sets the trend line period for the current series.
     * The typical, and initial, value for trend line period is 7.
    */
    trendLinePeriod: number;
    /**
     * The desired behavior for markers in this series which are placed too close together for the current view, resulting in a collision.
    */
    markerCollisionAvoidance: CategorySeriesMarkerCollisionAvoidance;
    /**
     * Determines the item returned in hit-testing when the pointer is over an object which represents several consolidated items.
    */
    consolidatedItemHitTestBehavior: ConsolidatedItemHitTestBehavior;
    /**
     * Scrolls the series to display the item for the specified data item.
     * The series is scrolled by the minimum amount required to place the specified data item within
     * the central 80% of the visible axis.
    
    * @param item  * The data item (item) to scroll to.
    */
    scrollIntoView(item: any): boolean;
    /**
     * Gets the item that is the best match for the specified world coordinates.
    
    * @param world  * The world coordinates to use.
    */
    getItem(world: IgPoint): any;
}
