import * as tslib_1 from "tslib";
import { forwardRef, Input } from '@angular/core';
import { TrendLineType, TrendLineType_$type } from "igniteui-angular-core/ES5/TrendLineType";
import { CategorySeriesMarkerCollisionAvoidance, CategorySeriesMarkerCollisionAvoidance_$type } from "./CategorySeriesMarkerCollisionAvoidance";
import { ConsolidatedItemHitTestBehavior, ConsolidatedItemHitTestBehavior_$type } from "./ConsolidatedItemHitTestBehavior";
import { IgxCategorySeriesComponent } from "./igx-category-series-component";
import { IgxMarkerSeriesComponent } from "./igx-marker-series-component";
import { IgxSeriesComponent } from "./igx-series-component";
import { ensureEnum, brushToString, stringToBrush, toPoint } from "igniteui-angular-core/ES5/componentUtil";
/**
 * Represents the base class for all IgxDataChartComponent anchored category/value series.
*/
export var IgxAnchoredCategorySeriesComponent_PROVIDERS = [{ provide: IgxCategorySeriesComponent, useExisting: forwardRef(function () { return IgxAnchoredCategorySeriesComponent; }) }, { provide: IgxMarkerSeriesComponent, useExisting: forwardRef(function () { return IgxAnchoredCategorySeriesComponent; }) }, { provide: IgxSeriesComponent, useExisting: forwardRef(function () { return IgxAnchoredCategorySeriesComponent; }) }];
var IgxAnchoredCategorySeriesComponent = /** @class */ (function (_super) {
    tslib_1.__extends(IgxAnchoredCategorySeriesComponent, _super);
    function IgxAnchoredCategorySeriesComponent() {
        return _super.call(this) || this;
    }
    Object.defineProperty(IgxAnchoredCategorySeriesComponent.prototype, "i", {
        get: function () {
            return this._implementation;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgxAnchoredCategorySeriesComponent.prototype, "valueMemberPath", {
        /**
         * Gets or sets the value mapping property for the current series object.
        */
        get: /**
             * Gets or sets the value mapping property for the current series object.
            */
        function () {
            return this.i.ov;
        },
        set: function (v) {
            this.i.ov = v;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgxAnchoredCategorySeriesComponent.prototype, "trendLineType", {
        /**
         * Gets or sets the trend type for the current series object.
        */
        get: /**
             * Gets or sets the trend type for the current series object.
            */
        function () {
            return this.i.trendLineType;
        },
        set: function (v) {
            this.i.trendLineType = ensureEnum(TrendLineType_$type, v);
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgxAnchoredCategorySeriesComponent.prototype, "trendLineBrush", {
        /**
         * Gets or sets the brush to use to draw the trend line.
        */
        get: /**
             * Gets or sets the brush to use to draw the trend line.
            */
        function () {
            return brushToString(this.i.trendLineBrush);
        },
        set: function (v) {
            this.i.trendLineBrush = stringToBrush(v);
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgxAnchoredCategorySeriesComponent.prototype, "actualTrendLineBrush", {
        /**
         * Gets the effective TrendLineBrush for this series.
        */
        get: /**
             * Gets the effective TrendLineBrush for this series.
            */
        function () {
            return brushToString(this.i.pc);
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgxAnchoredCategorySeriesComponent.prototype, "trendLineThickness", {
        /**
         * Gets or sets the thickness of the current series object's trend line.
        */
        get: /**
             * Gets or sets the thickness of the current series object's trend line.
            */
        function () {
            return this.i.trendLineThickness;
        },
        set: function (v) {
            this.i.trendLineThickness = +v;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgxAnchoredCategorySeriesComponent.prototype, "trendLinePeriod", {
        /**
         * Gets or sets the trend line period for the current series.
         * The typical, and initial, value for trend line period is 7.
        */
        get: /**
             * Gets or sets the trend line period for the current series.
             * The typical, and initial, value for trend line period is 7.
            */
        function () {
            return this.i.trendLinePeriod;
        },
        set: function (v) {
            this.i.trendLinePeriod = +v;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgxAnchoredCategorySeriesComponent.prototype, "markerCollisionAvoidance", {
        /**
         * The desired behavior for markers in this series which are placed too close together for the current view, resulting in a collision.
        */
        get: /**
             * The desired behavior for markers in this series which are placed too close together for the current view, resulting in a collision.
            */
        function () {
            return this.i.oi;
        },
        set: function (v) {
            this.i.oi = ensureEnum(CategorySeriesMarkerCollisionAvoidance_$type, v);
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgxAnchoredCategorySeriesComponent.prototype, "consolidatedItemHitTestBehavior", {
        /**
         * Determines the item returned in hit-testing when the pointer is over an object which represents several consolidated items.
        */
        get: /**
             * Determines the item returned in hit-testing when the pointer is over an object which represents several consolidated items.
            */
        function () {
            return this.i.oj;
        },
        set: function (v) {
            this.i.oj = ensureEnum(ConsolidatedItemHitTestBehavior_$type, v);
        },
        enumerable: true,
        configurable: true
    });
    /**
     * Scrolls the series to display the item for the specified data item.
     * The series is scrolled by the minimum amount required to place the specified data item within
     * the central 80% of the visible axis.
    
    * @param item  * The data item (item) to scroll to.
    */
    /**
         * Scrolls the series to display the item for the specified data item.
         * The series is scrolled by the minimum amount required to place the specified data item within
         * the central 80% of the visible axis.
        
        * @param item  * The data item (item) to scroll to.
        */
    IgxAnchoredCategorySeriesComponent.prototype.scrollIntoView = /**
         * Scrolls the series to display the item for the specified data item.
         * The series is scrolled by the minimum amount required to place the specified data item within
         * the central 80% of the visible axis.
        
        * @param item  * The data item (item) to scroll to.
        */
    function (item) {
        var iv = this.i.c6(item);
        return (iv);
    };
    /**
     * Gets the item that is the best match for the specified world coordinates.
    
    * @param world  * The world coordinates to use.
    */
    /**
         * Gets the item that is the best match for the specified world coordinates.
        
        * @param world  * The world coordinates to use.
        */
    IgxAnchoredCategorySeriesComponent.prototype.getItem = /**
         * Gets the item that is the best match for the specified world coordinates.
        
        * @param world  * The world coordinates to use.
        */
    function (world) {
        var iv = this.i.ff(toPoint(world));
        return (iv);
    };
    IgxAnchoredCategorySeriesComponent.propDecorators = {
        "valueMemberPath": [{ type: Input },],
        "trendLineType": [{ type: Input },],
        "trendLineBrush": [{ type: Input },],
        "trendLineThickness": [{ type: Input },],
        "trendLinePeriod": [{ type: Input },],
        "markerCollisionAvoidance": [{ type: Input },],
        "consolidatedItemHitTestBehavior": [{ type: Input },],
    };
    return IgxAnchoredCategorySeriesComponent;
}(IgxCategorySeriesComponent));
export { IgxAnchoredCategorySeriesComponent };
//# sourceMappingURL=igx-anchored-category-series-component.js.map