import * as tslib_1 from "tslib";
import { Component, ViewContainerRef, Injector, ComponentFactoryResolver, Renderer2, ViewChild, Inject, Input, NgZone, ChangeDetectionStrategy } from '@angular/core';
import { DOCUMENT } from '@angular/platform-browser';
import { AngularRenderer, AngularWrapper } from "igniteui-angular-core/ES5/angular-renderer";
import { TypeRegistrar } from "igniteui-angular-core/ES5/type";
import { CategoryChart } from './CategoryChart';
import { CategoryChartType, CategoryChartType_$type } from './CategoryChartType';
import { CategorySeriesMarkerCollisionAvoidance, CategorySeriesMarkerCollisionAvoidance_$type } from './CategorySeriesMarkerCollisionAvoidance';
import { CategoryTransitionInMode, CategoryTransitionInMode_$type } from './CategoryTransitionInMode';
import { TransitionInSpeedType, TransitionInSpeedType_$type } from './TransitionInSpeedType';
import { fromBrushCollection, toBrushCollection, ensureEnum, ensureBool } from "igniteui-angular-core/ES5/componentUtil";
import { IgxXYChartComponent } from './igx-xy-chart-component';
import { DataChartStylingDefaults } from './DataChartStylingDefaults';
import { DataSeriesType } from "igniteui-angular-core/ES5/DataSeriesType";
import { DataContext } from "igniteui-angular-core/ES5/igx-data-context";
import { IgxCategoryXAxisComponent } from './igx-category-x-axis-component';
import { IgxNumericYAxisComponent } from './igx-numeric-y-axis-component';
export var IgxCategoryChartComponent_PROVIDERS = [];
/**
 * Represents a chart with an ordinal X-axis and a numeric Y-axis.
*/
var IgxCategoryChartComponent = /** @class */ (function (_super) {
    tslib_1.__extends(IgxCategoryChartComponent, _super);
    function IgxCategoryChartComponent(renderer, _elRef, document, ngZone, injector, componentFactoryResolver) {
        var _this = _super.call(this) || this;
        _this.renderer = renderer;
        _this._elRef = _elRef;
        _this.document = document;
        _this.ngZone = ngZone;
        _this.injector = injector;
        _this.componentFactoryResolver = componentFactoryResolver;
        _this._dataSource = null;
        _this._defaultTooltips = null;
        _this._zoneRunner = function (act) { return ngZone.run(act); };
        _this.container = renderer.createElement("div");
        renderer.appendChild(_elRef.element.nativeElement, _this.container);
        renderer.setStyle(_this.container, "display", "block");
        renderer.setStyle(_this.container, "width", "100%");
        renderer.setStyle(_this.container, "height", "100%");
        var root;
        root = _this.container;
        if (_this.container != null) {
            root = _this.container;
        }
        var ren = new AngularRenderer(root, _this.renderer, _this.document, _this.ngZone, true, DataChartStylingDefaults);
        _this._wrapper = ren;
        var chart = _this.i;
        _this._chart = chart;
        if (chart.xAxis) {
            var x = new IgxCategoryXAxisComponent();
            x._provideRenderer(ren);
            x._implementation = chart.xAxis;
            chart.xAxis.externalObject = x;
        }
        if (chart.yAxis) {
            var y = new IgxNumericYAxisComponent();
            y._provideRenderer(ren);
            y._implementation = chart.yAxis;
            chart.yAxis.externalObject = y;
        }
        chart.provideContainer(ren);
        _this.bindData();
        chart.notifyResized();
        ren.addSizeWatcher(function () {
            _this._chart.notifyResized();
        });
        return _this;
    }
    Object.defineProperty(IgxCategoryChartComponent.prototype, "height", {
        get: function () {
            return this._height;
        },
        set: function (value) {
            this._height = value;
            this.renderer.setStyle(this._elRef.element.nativeElement, "height", value);
            this._chart.notifyResized();
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgxCategoryChartComponent.prototype, "width", {
        get: function () {
            return this._width;
        },
        set: function (value) {
            this._width = value;
            this.renderer.setStyle(this._elRef.element.nativeElement, "width", value);
            this._chart.notifyResized();
        },
        enumerable: true,
        configurable: true
    });
    IgxCategoryChartComponent.prototype.ngOnDestroy = function () {
        this._chart.destroy();
        this._wrapper.destroy();
    };
    IgxCategoryChartComponent.prototype.createImplementation = function () {
        return new CategoryChart();
    };
    Object.defineProperty(IgxCategoryChartComponent.prototype, "i", {
        get: function () {
            return this._implementation;
        },
        enumerable: true,
        configurable: true
    });
    IgxCategoryChartComponent.prototype.createSeriesComponent = function (type) {
        if (TypeRegistrar.isRegistered(type)) {
            var s = TypeRegistrar.create(type);
            s.owner = this;
            s._provideRenderer(this.renderer);
            return s;
        }
        else {
            //we shouldn't get here, hopefully.
            throw Error("series type not loaded: " + type);
        }
    };
    IgxCategoryChartComponent.prototype.createSeries = function (type) {
        switch (type) {
            case DataSeriesType.Area:
                return this.createSeriesComponent('IgxAreaSeriesComponent');
            case DataSeriesType.Column:
                return this.createSeriesComponent('IgxColumnSeriesComponent');
            case DataSeriesType.Line:
                return this.createSeriesComponent('IgxLineSeriesComponent');
            case DataSeriesType.Point:
                return this.createSeriesComponent('IgxPointSeriesComponent');
            case DataSeriesType.Spline:
                return this.createSeriesComponent('IgxSplineSeriesComponent');
            case DataSeriesType.SplineArea:
                return this.createSeriesComponent('IgxSplineAreaSeriesComponent');
            case DataSeriesType.StepArea:
                return this.createSeriesComponent('IgxStepAreaSeriesComponent');
            case DataSeriesType.StepLine:
                return this.createSeriesComponent('IgxStepLineSeriesComponent');
            case DataSeriesType.Waterfall:
                return this.createSeriesComponent('IgxWaterfallSeriesComponent');
            default:
                return this.createSeriesComponent('IgxColumnSeriesComponent');
        }
    };
    Object.defineProperty(IgxCategoryChartComponent.prototype, "dataSource", {
        get: function () {
            return this._dataSource;
        },
        set: function (value) {
            this._dataSource = value;
            this.bindData();
        },
        enumerable: true,
        configurable: true
    });
    IgxCategoryChartComponent.prototype.bindData = function () {
        if (this._chart != null && this._chart !== undefined) {
            this._chart.itemsSource = this._dataSource;
        }
    };
    IgxCategoryChartComponent.prototype.ngAfterContentInit = function () {
        var _this = this;
        if (TypeRegistrar.isRegistered("IgxDataChartDefaultTooltipsComponent")) {
            var c = TypeRegistrar.get("IgxDataChartDefaultTooltipsComponent");
            var cf = this.componentFactoryResolver.resolveComponentFactory(c);
            //let cr = cf.create(this.injector);
            var cr_1 = this._dynamicContent.createComponent(cf);
            this._defaultTooltips = cr_1;
            cr_1.instance.onContentReady.subscribe(function () {
                _this._onDefaultTooltipsReady(cr_1);
            });
            this.container.appendChild(cr_1.location.nativeElement);
        }
    };
    IgxCategoryChartComponent.prototype.createTooltip = function () {
        if (!TypeRegistrar.isRegistered("IgxTooltipContainerComponent")) {
            return null;
        }
        var t = TypeRegistrar.get("IgxTooltipContainerComponent");
        var cf = this.componentFactoryResolver.resolveComponentFactory(t);
        //let cr = cf.create(this.injector);
        var cr = this._dynamicContent.createComponent(cf);
        var ele = cr.location.nativeElement;
        var self = this;
        ele.updateToolTip = function (c) {
            if (c.externalObject) {
                c = c.externalObject;
            }
            else {
                var ext = new DataContext();
                ext._implementation = c;
                c = ext;
            }
            if (ele.parentElement != self.container) {
                if (ele.parentElement != null) {
                    ele.parentElement.removeChild(ele);
                }
                self.container.appendChild(ele);
            }
            cr.instance.context = c;
            ele.style.display = "block";
            return true;
        };
        ele.hideToolTip = function () {
            ele.style.display = "none";
        };
        ele.style.display = "none";
        return cr;
    };
    IgxCategoryChartComponent.prototype._ensureTooltipCreated = function (series) {
        var _this = this;
        series._ensureTooltipCreated(function () { return _this.createTooltip(); }, function (ele) {
            var wrapper = new AngularWrapper(ele, _this.renderer, _this.ngZone);
            wrapper.updateToolTip = ele.updateToolTip;
            wrapper.hideToolTip = ele.hideToolTip;
            return wrapper;
        });
    };
    IgxCategoryChartComponent.prototype._createXAxis = function () {
        var x = new IgxCategoryXAxisComponent();
        x._provideRenderer(this.renderer);
        return x.i;
    };
    IgxCategoryChartComponent.prototype._createYAxis = function () {
        var y = new IgxNumericYAxisComponent();
        y.provideRenderer(this.renderer);
        return y.i;
    };
    IgxCategoryChartComponent.prototype._ensureDefaultTooltip = function (series) {
        if (this._defaultTooltips == null) {
            return;
        }
        this._defaultTooltips.instance["ensureDefaultTooltip"](series);
    };
    IgxCategoryChartComponent.prototype._onDefaultTooltipsReady = function (cr) {
        if (this.i.dataChart) {
            var currSeries = this.i.dataChart.series;
            for (var i = 0; i < currSeries.count; i++) {
                if (currSeries.item(i).externalObject.showDefaultTooltip) {
                    this._ensureDefaultTooltip(currSeries.item(i).externalObject);
                }
            }
        }
    };
    Object.defineProperty(IgxCategoryChartComponent.prototype, "transitionInDuration", {
        /**
     * Gets or sets the duration used for animating series plots when the chart is loading into view
    */
        get: /**
             * Gets or sets the duration used for animating series plots when the chart is loading into view
            */
        function () {
            return this.i.oh;
        },
        set: function (v) {
            this.i.oh = +v;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgxCategoryChartComponent.prototype, "transitionInEasingFunction", {
        /**
         * Gets or sets the easing function used for animating series plots when the chart is loading into view
         * This can be set to one of the known values "linear" or "cubic," or it can be set to an easing function which takes a single numeric parameter and returns a number.
        */
        get: /**
             * Gets or sets the easing function used for animating series plots when the chart is loading into view
             * This can be set to one of the known values "linear" or "cubic," or it can be set to an easing function which takes a single numeric parameter and returns a number.
            */
        function () {
            return this.i.ni;
        },
        set: function (v) {
            this.i.ni = v;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgxCategoryChartComponent.prototype, "chartType", {
        /**
         * Gets or sets the type of chart series to generate from the data.
        */
        get: /**
             * Gets or sets the type of chart series to generate from the data.
            */
        function () {
            return this.i.m3;
        },
        set: function (v) {
            this.i.m3 = ensureEnum(CategoryChartType_$type, v);
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgxCategoryChartComponent.prototype, "markerCollisionAvoidance", {
        /**
         * Gets or sets the behavior for markers in each series which are placed too close together for the current view, resulting in a collision.
        */
        get: /**
             * Gets or sets the behavior for markers in each series which are placed too close together for the current view, resulting in a collision.
            */
        function () {
            return this.i.m5;
        },
        set: function (v) {
            this.i.m5 = ensureEnum(CategorySeriesMarkerCollisionAvoidance_$type, v);
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgxCategoryChartComponent.prototype, "isTransitionInEnabled", {
        /**
         * Gets or sets whether animation of series plots is enabled when the chart is loading into view
        */
        get: /**
             * Gets or sets whether animation of series plots is enabled when the chart is loading into view
            */
        function () {
            return this.i.no;
        },
        set: function (v) {
            this.i.no = ensureBool(v);
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgxCategoryChartComponent.prototype, "transitionInMode", {
        /**
         * Gets or sets the method that determines how to animate series plots when the chart is loading into view
        */
        get: /**
             * Gets or sets the method that determines how to animate series plots when the chart is loading into view
            */
        function () {
            return this.i.m7;
        },
        set: function (v) {
            this.i.m7 = ensureEnum(CategoryTransitionInMode_$type, v);
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgxCategoryChartComponent.prototype, "transitionInSpeedType", {
        /**
         * Gets or sets the arrival speed used for animating series plots when the chart is loading into view
        */
        get: /**
             * Gets or sets the arrival speed used for animating series plots when the chart is loading into view
            */
        function () {
            return this.i.ng;
        },
        set: function (v) {
            this.i.ng = ensureEnum(TransitionInSpeedType_$type, v);
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgxCategoryChartComponent.prototype, "xAxisInterval", {
        /**
         * Gets or sets the frequency of displayed labels along the X-axis.
         * Gets or sets the set value is a factor that determines which labels will be hidden. For example, an interval of 2 will display every other label.
        */
        get: /**
             * Gets or sets the frequency of displayed labels along the X-axis.
             * Gets or sets the set value is a factor that determines which labels will be hidden. For example, an interval of 2 will display every other label.
            */
        function () {
            return this.i.n6;
        },
        set: function (v) {
            this.i.n6 = +v;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgxCategoryChartComponent.prototype, "xAxisMinorInterval", {
        /**
         * Gets or sets the frequency of displayed minor lines along the X-axis.
         * Gets or sets the set value is a factor that determines how the minor lines will be displayed.
        */
        get: /**
             * Gets or sets the frequency of displayed minor lines along the X-axis.
             * Gets or sets the set value is a factor that determines how the minor lines will be displayed.
            */
        function () {
            return this.i.n7;
        },
        set: function (v) {
            this.i.n7 = +v;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgxCategoryChartComponent.prototype, "xAxisGap", {
        /**
         * Gets or sets the amount of space between adjacent categories for the X-axis.
         * The gap is silently clamped to the range [0, 1] when used.
        */
        get: /**
             * Gets or sets the amount of space between adjacent categories for the X-axis.
             * The gap is silently clamped to the range [0, 1] when used.
            */
        function () {
            return this.i.n5;
        },
        set: function (v) {
            this.i.n5 = +v;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgxCategoryChartComponent.prototype, "xAxisOverlap", {
        /**
         * Gets or sets the amount of overlap between adjacent categories for the X-axis.
         * Gets or sets the overlap is silently clamped to the range [-1, 1] when used.
        */
        get: /**
             * Gets or sets the amount of overlap between adjacent categories for the X-axis.
             * Gets or sets the overlap is silently clamped to the range [-1, 1] when used.
            */
        function () {
            return this.i.n8;
        },
        set: function (v) {
            this.i.n8 = +v;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgxCategoryChartComponent.prototype, "yAxisInterval", {
        /**
         * Gets or sets the distance between each label and grid line along the Y-axis.
        */
        get: /**
             * Gets or sets the distance between each label and grid line along the Y-axis.
            */
        function () {
            return this.i.ob;
        },
        set: function (v) {
            this.i.ob = +v;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgxCategoryChartComponent.prototype, "yAxisIsLogarithmic", {
        /**
         * Gets or sets whether the Y-axis should use a logarithmic scale instead of a linear one.
         * Since log(-1) is imaginary and log(0) is undefined, it is recommended to enable this property only when the Y-axis minimum is greater than zero.
        */
        get: /**
             * Gets or sets whether the Y-axis should use a logarithmic scale instead of a linear one.
             * Since log(-1) is imaginary and log(0) is undefined, it is recommended to enable this property only when the Y-axis minimum is greater than zero.
            */
        function () {
            return this.i.nq;
        },
        set: function (v) {
            this.i.nq = ensureBool(v);
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgxCategoryChartComponent.prototype, "yAxisLogarithmBase", {
        /**
         * Gets or sets the base value to use in the log function when mapping the position of data items along the Y-axis.
         * This property is effective only when YAxisIsLogarithmic is true.
        */
        get: /**
             * Gets or sets the base value to use in the log function when mapping the position of data items along the Y-axis.
             * This property is effective only when YAxisIsLogarithmic is true.
            */
        function () {
            return this.i.oi;
        },
        set: function (v) {
            this.i.oi = +v;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgxCategoryChartComponent.prototype, "yAxisMinimumValue", {
        /**
         * Gets or sets the data value corresponding to the minimum value of the Y-axis.
        */
        get: /**
             * Gets or sets the data value corresponding to the minimum value of the Y-axis.
            */
        function () {
            return this.i.od;
        },
        set: function (v) {
            this.i.od = +v;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgxCategoryChartComponent.prototype, "yAxisMaximumValue", {
        /**
         * Gets or sets the data value corresponding to the maximum value of the Y-axis.
        */
        get: /**
             * Gets or sets the data value corresponding to the maximum value of the Y-axis.
            */
        function () {
            return this.i.oc;
        },
        set: function (v) {
            this.i.oc = +v;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgxCategoryChartComponent.prototype, "yAxisMinorInterval", {
        /**
         * Gets or sets the frequency of displayed minor lines along the Y-axis.
        */
        get: /**
             * Gets or sets the frequency of displayed minor lines along the Y-axis.
            */
        function () {
            return this.i.oe;
        },
        set: function (v) {
            this.i.oe = +v;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgxCategoryChartComponent.prototype, "xAxisActualMinimum", {
        /**
         * Gets the current minimum value for the X-axis.
        */
        get: /**
             * Gets the current minimum value for the X-axis.
            */
        function () {
            return this.i.n4;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgxCategoryChartComponent.prototype, "xAxisActualMaximum", {
        /**
         * Gets the current maximum value for the X-axis.
        */
        get: /**
             * Gets the current maximum value for the X-axis.
            */
        function () {
            return this.i.n3;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgxCategoryChartComponent.prototype, "yAxisActualMinimum", {
        /**
         * Gets the current minimum value for the Y-axis.
        */
        get: /**
             * Gets the current minimum value for the Y-axis.
            */
        function () {
            return this.i.oa;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgxCategoryChartComponent.prototype, "yAxisActualMaximum", {
        /**
         * Gets the current maximum value for the Y-axis.
        */
        get: /**
             * Gets the current maximum value for the Y-axis.
            */
        function () {
            return this.i.n9;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgxCategoryChartComponent.prototype, "negativeBrushes", {
        /**
         * Gets or sets the palette used for coloring negative items of Waterfall chart type.
        */
        get: /**
             * Gets or sets the palette used for coloring negative items of Waterfall chart type.
            */
        function () {
            return fromBrushCollection(this.i.m0);
        },
        set: function (v) {
            this.i.m0 = toBrushCollection(v);
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgxCategoryChartComponent.prototype, "negativeOutlines", {
        /**
         * Brushes to use for drawing negative elements, when using a chart type with contextual coloring, such as Waterfall.
        */
        get: /**
             * Brushes to use for drawing negative elements, when using a chart type with contextual coloring, such as Waterfall.
            */
        function () {
            return fromBrushCollection(this.i.m1);
        },
        set: function (v) {
            this.i.m1 = toBrushCollection(v);
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgxCategoryChartComponent.prototype, "animateSeriesWhenAxisRangeChanges", {
        /**
         * Gets or sets whether the series animations should be allowed when a range change has been detected on an axis.
        */
        get: /**
             * Gets or sets whether the series animations should be allowed when a range change has been detected on an axis.
            */
        function () {
            return this.i.nn;
        },
        set: function (v) {
            this.i.nn = ensureBool(v);
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgxCategoryChartComponent.prototype, "yAxisAbbreviateLargeNumbers", {
        /**
         * Gets or sets whether the large numbers on the Y-axis labels are abbreviated.
        */
        get: /**
             * Gets or sets whether the large numbers on the Y-axis labels are abbreviated.
            */
        function () {
            return this.i.np;
        },
        set: function (v) {
            this.i.np = ensureBool(v);
        },
        enumerable: true,
        configurable: true
    });
    /**
 * Export serialized visual data.

*/
    /**
         * Export serialized visual data.
        
        */
    IgxCategoryChartComponent.prototype.exportSerializedVisualData = /**
         * Export serialized visual data.
        
        */
    function () {
        var iv = this.i.ol();
        return (iv);
    };
    /**
     * Converts the given visual location to a data value.
    
    * @param unscaledValue  * The x-coordinate of the location to scale.
    */
    /**
         * Converts the given visual location to a data value.
        
        * @param unscaledValue  * The x-coordinate of the location to scale.
        */
    IgxCategoryChartComponent.prototype.getScaledValueX = /**
         * Converts the given visual location to a data value.
        
        * @param unscaledValue  * The x-coordinate of the location to scale.
        */
    function (unscaledValue) {
        var iv = this.i.nz(unscaledValue);
        return (iv);
    };
    /**
     * Converts the given data value to a visual location.
    
    * @param scaledValue  * The data value to unscale.
    */
    /**
         * Converts the given data value to a visual location.
        
        * @param scaledValue  * The data value to unscale.
        */
    IgxCategoryChartComponent.prototype.getUnscaledValueX = /**
         * Converts the given data value to a visual location.
        
        * @param scaledValue  * The data value to unscale.
        */
    function (scaledValue) {
        var iv = this.i.n1(scaledValue);
        return (iv);
    };
    /**
     * Converts the given visual location to a data value.
    
    * @param unscaledValue  * The y-coordinate of the location to scale.
    */
    /**
         * Converts the given visual location to a data value.
        
        * @param unscaledValue  * The y-coordinate of the location to scale.
        */
    IgxCategoryChartComponent.prototype.getScaledValueY = /**
         * Converts the given visual location to a data value.
        
        * @param unscaledValue  * The y-coordinate of the location to scale.
        */
    function (unscaledValue) {
        var iv = this.i.n0(unscaledValue);
        return (iv);
    };
    /**
     * Converts the given data value to a visual location.
    
    * @param scaledValue  * The data value to unscale.
    */
    /**
         * Converts the given data value to a visual location.
        
        * @param scaledValue  * The data value to unscale.
        */
    IgxCategoryChartComponent.prototype.getUnscaledValueY = /**
         * Converts the given data value to a visual location.
        
        * @param scaledValue  * The data value to unscale.
        */
    function (scaledValue) {
        var iv = this.i.n2(scaledValue);
        return (iv);
    };
    IgxCategoryChartComponent.decorators = [
        { type: Component, args: [{
                    selector: 'igx-category-chart',
                    template: "<ng-container #dynamicContent></ng-container>",
                    changeDetection: ChangeDetectionStrategy.OnPush,
                    providers: IgxCategoryChartComponent_PROVIDERS,
                    styles: ["\n\t\t:host {\n\t\t\tdisplay: block;\n\t\t}\n\t"]
                },] },
    ];
    //@@ZoneRunner
    /** @nocollapse */
    IgxCategoryChartComponent.ctorParameters = function () { return [
        { type: Renderer2, },
        { type: ViewContainerRef, },
        { type: undefined, decorators: [{ type: Inject, args: [DOCUMENT,] },] },
        { type: NgZone, },
        { type: Injector, },
        { type: ComponentFactoryResolver, },
    ]; };
    IgxCategoryChartComponent.propDecorators = {
        "_dynamicContent": [{ type: ViewChild, args: ["dynamicContent", { read: ViewContainerRef },] },],
        "height": [{ type: Input },],
        "width": [{ type: Input },],
        "dataSource": [{ type: Input },],
        "transitionInDuration": [{ type: Input },],
        "transitionInEasingFunction": [{ type: Input },],
        "chartType": [{ type: Input },],
        "markerCollisionAvoidance": [{ type: Input },],
        "isTransitionInEnabled": [{ type: Input },],
        "transitionInMode": [{ type: Input },],
        "transitionInSpeedType": [{ type: Input },],
        "xAxisInterval": [{ type: Input },],
        "xAxisMinorInterval": [{ type: Input },],
        "xAxisGap": [{ type: Input },],
        "xAxisOverlap": [{ type: Input },],
        "yAxisInterval": [{ type: Input },],
        "yAxisIsLogarithmic": [{ type: Input },],
        "yAxisLogarithmBase": [{ type: Input },],
        "yAxisMinimumValue": [{ type: Input },],
        "yAxisMaximumValue": [{ type: Input },],
        "yAxisMinorInterval": [{ type: Input },],
        "negativeBrushes": [{ type: Input },],
        "negativeOutlines": [{ type: Input },],
        "animateSeriesWhenAxisRangeChanges": [{ type: Input },],
        "yAxisAbbreviateLargeNumbers": [{ type: Input },],
    };
    return IgxCategoryChartComponent;
}(IgxXYChartComponent));
export { IgxCategoryChartComponent };
//# sourceMappingURL=igx-category-chart-component.js.map