import * as tslib_1 from "tslib";
import { Component, forwardRef, Input, ChangeDetectionStrategy } from '@angular/core';
import { IgxSeriesComponent } from "./igx-series-component";
import { CategoryItemHighlightType, CategoryItemHighlightType_$type } from "./CategoryItemHighlightType";
import { IgxAnnotationLayerComponent } from "./igx-annotation-layer-component";
import { CategoryItemHighlightLayer } from "./CategoryItemHighlightLayer";
import { ensureBool, ensureEnum } from "igniteui-angular-core/ES5/componentUtil";
/**
 * Represents an annotation layer that highlights items in a series that use a category axis
 * either by drawing a banded shape at their position, or by rendering a marker at their position.
 * Depending on the type of series, the default highlight will be affected. To override
 * the type of highlight used, you can set the HighlightType property.
*/
export var IgxCategoryItemHighlightLayerComponent_PROVIDERS = [{ provide: IgxAnnotationLayerComponent, useExisting: forwardRef(function () { return IgxCategoryItemHighlightLayerComponent; }) }, { provide: IgxSeriesComponent, useExisting: forwardRef(function () { return IgxCategoryItemHighlightLayerComponent; }) }];
var IgxCategoryItemHighlightLayerComponent = /** @class */ (function (_super) {
    tslib_1.__extends(IgxCategoryItemHighlightLayerComponent, _super);
    function IgxCategoryItemHighlightLayerComponent() {
        return _super.call(this) || this;
    }
    IgxCategoryItemHighlightLayerComponent.prototype.createImplementation = function () {
        return new CategoryItemHighlightLayer();
    };
    Object.defineProperty(IgxCategoryItemHighlightLayerComponent.prototype, "i", {
        get: function () {
            return this._implementation;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgxCategoryItemHighlightLayerComponent.prototype, "targetSeries", {
        /**
         * Gets or sets the series to target this annotation to. If null, this annotation targets all series simultaneously.
        */
        get: /**
             * Gets or sets the series to target this annotation to. If null, this annotation targets all series simultaneously.
            */
        function () {
            if (this.i.mm == null) {
                return null;
            }
            return this.i.mm.externalObject;
        },
        set: function (v) {
            v == null ? this.i.mm = null : this.i.mm = v.i;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgxCategoryItemHighlightLayerComponent.prototype, "useInterpolation", {
        /**
         * Gets or sets whether to use value interpolation when drawing a line through the best value for the pointer position.
        */
        get: /**
             * Gets or sets whether to use value interpolation when drawing a line through the best value for the pointer position.
            */
        function () {
            return this.i.mq;
        },
        set: function (v) {
            this.i.mq = ensureBool(v);
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgxCategoryItemHighlightLayerComponent.prototype, "highlightType", {
        /**
         * Gets or sets which type of highlight shape to use when highlighting items.
        */
        get: /**
             * Gets or sets which type of highlight shape to use when highlighting items.
            */
        function () {
            return this.i.mk;
        },
        set: function (v) {
            this.i.mk = ensureEnum(CategoryItemHighlightType_$type, v);
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgxCategoryItemHighlightLayerComponent.prototype, "markerTemplate", {
        /**
         * Gets or sets the template to use for marker visuals for the current series object.
        */
        get: /**
             * Gets or sets the template to use for marker visuals for the current series object.
            */
        function () {
            return this.i.m4;
        },
        set: function (v) {
            this.i.m4 = v;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgxCategoryItemHighlightLayerComponent.prototype, "bandHighlightWidth", {
        /**
         * Gets or sets the width to use for the highlight region if highlighting items in a grid aligned series (line, spline, etc), with a banded shape.
        */
        get: /**
             * Gets or sets the width to use for the highlight region if highlighting items in a grid aligned series (line, spline, etc), with a banded shape.
            */
        function () {
            return this.i.ms;
        },
        set: function (v) {
            this.i.ms = +v;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgxCategoryItemHighlightLayerComponent.prototype, "skipUnknownValues", {
        /**
         * Gets or sets whether to skip unknown values when searching for series values.
        */
        get: /**
             * Gets or sets whether to skip unknown values when searching for series values.
            */
        function () {
            return this.i.mp;
        },
        set: function (v) {
            this.i.mp = ensureBool(v);
        },
        enumerable: true,
        configurable: true
    });
    IgxCategoryItemHighlightLayerComponent.decorators = [
        { type: Component, args: [{
                    selector: 'igx-category-item-highlight-layer',
                    template: "",
                    providers: [{ provide: IgxAnnotationLayerComponent, useExisting: forwardRef(function () { return IgxCategoryItemHighlightLayerComponent; }) }, { provide: IgxSeriesComponent, useExisting: forwardRef(function () { return IgxCategoryItemHighlightLayerComponent; }) }],
                    changeDetection: ChangeDetectionStrategy.OnPush
                },] },
    ];
    /** @nocollapse */
    IgxCategoryItemHighlightLayerComponent.ctorParameters = function () { return []; };
    IgxCategoryItemHighlightLayerComponent.propDecorators = {
        "targetSeries": [{ type: Input },],
        "useInterpolation": [{ type: Input },],
        "highlightType": [{ type: Input },],
        "markerTemplate": [{ type: Input },],
        "bandHighlightWidth": [{ type: Input },],
        "skipUnknownValues": [{ type: Input },],
    };
    return IgxCategoryItemHighlightLayerComponent;
}(IgxAnnotationLayerComponent));
export { IgxCategoryItemHighlightLayerComponent };
//# sourceMappingURL=igx-category-item-highlight-layer-component.js.map