import * as tslib_1 from "tslib";
import { Component, forwardRef, Input, ChangeDetectionStrategy } from '@angular/core';
import { IgxSeriesComponent } from "./igx-series-component";
import { Visibility, Visibility_$type } from "igniteui-angular-core/ES5/Visibility";
import { IgxAnnotationLayerComponent } from "./igx-annotation-layer-component";
import { CrosshairLayer } from "./CrosshairLayer";
import { brushToString, stringToBrush, ensureBool, ensureEnum } from "igniteui-angular-core/ES5/componentUtil";
/**
 * Represents an annotation layer that displays crosshair lines that cross through the closest value of the target series under the cursor.
*/
export var IgxCrosshairLayerComponent_PROVIDERS = [{ provide: IgxAnnotationLayerComponent, useExisting: forwardRef(function () { return IgxCrosshairLayerComponent; }) }, { provide: IgxSeriesComponent, useExisting: forwardRef(function () { return IgxCrosshairLayerComponent; }) }];
var IgxCrosshairLayerComponent = /** @class */ (function (_super) {
    tslib_1.__extends(IgxCrosshairLayerComponent, _super);
    function IgxCrosshairLayerComponent() {
        return _super.call(this) || this;
    }
    IgxCrosshairLayerComponent.prototype.createImplementation = function () {
        return new CrosshairLayer();
    };
    Object.defineProperty(IgxCrosshairLayerComponent.prototype, "i", {
        get: function () {
            return this._implementation;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgxCrosshairLayerComponent.prototype, "horizontalLineStroke", {
        /**
         * Gets or sets the color to use for the horizontal line. Leave null for an automatic value.
        */
        get: /**
             * Gets or sets the color to use for the horizontal line. Leave null for an automatic value.
            */
        function () {
            return brushToString(this.i.n3);
        },
        set: function (v) {
            this.i.n3 = stringToBrush(v);
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgxCrosshairLayerComponent.prototype, "verticalLineStroke", {
        /**
         * Gets or sets the color to use for vertical line. Leave null for an automatic value.
        */
        get: /**
             * Gets or sets the color to use for vertical line. Leave null for an automatic value.
            */
        function () {
            return brushToString(this.i.n4);
        },
        set: function (v) {
            this.i.n4 = stringToBrush(v);
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgxCrosshairLayerComponent.prototype, "targetSeries", {
        /**
         * Gets or sets the series to target this annotation to. If null, this annotation targets all series simultaneously.
        */
        get: /**
             * Gets or sets the series to target this annotation to. If null, this annotation targets all series simultaneously.
            */
        function () {
            if (this.i.mk == null) {
                return null;
            }
            return this.i.mk.externalObject;
        },
        set: function (v) {
            v == null ? this.i.mk = null : this.i.mk = v.i;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgxCrosshairLayerComponent.prototype, "useInterpolation", {
        /**
         * Gets or sets whether to use value interpolation when drawing a line through the best value for the cursor position.
        */
        get: /**
             * Gets or sets whether to use value interpolation when drawing a line through the best value for the cursor position.
            */
        function () {
            return this.i.mn;
        },
        set: function (v) {
            this.i.mn = ensureBool(v);
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgxCrosshairLayerComponent.prototype, "isAxisAnnotationEnabled", {
        /**
         * Gets or sets whether to use value interpolation when drawing a line through the best value for the cursor position.
        */
        get: /**
             * Gets or sets whether to use value interpolation when drawing a line through the best value for the cursor position.
            */
        function () {
            return this.i.ml;
        },
        set: function (v) {
            this.i.ml = ensureBool(v);
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgxCrosshairLayerComponent.prototype, "xAxisAnnotationTextColor", {
        /**
         * Gets or sets the color to use for the x axis annotation text. Leave unset for an automatic value.
        */
        get: /**
             * Gets or sets the color to use for the x axis annotation text. Leave unset for an automatic value.
            */
        function () {
            return brushToString(this.i.n7);
        },
        set: function (v) {
            this.i.n7 = stringToBrush(v);
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgxCrosshairLayerComponent.prototype, "xAxisAnnotationBackground", {
        /**
         * Gets or sets the color to use for the x axis annotation backing. Leave unset for an automatic value.
        */
        get: /**
             * Gets or sets the color to use for the x axis annotation backing. Leave unset for an automatic value.
            */
        function () {
            return brushToString(this.i.n5);
        },
        set: function (v) {
            this.i.n5 = stringToBrush(v);
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgxCrosshairLayerComponent.prototype, "xAxisAnnotationInterpolatedValuePrecision", {
        /**
         * Gets or sets the precision to use displaying values for interpolated crosshair positions.
        */
        get: /**
             * Gets or sets the precision to use displaying values for interpolated crosshair positions.
            */
        function () {
            return this.i.mu;
        },
        set: function (v) {
            this.i.mu = +v;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgxCrosshairLayerComponent.prototype, "xAxisAnnotationOutline", {
        /**
         * Gets or sets the color to use for the x axis annotation outline. Leave unset for an automatic value.
        */
        get: /**
             * Gets or sets the color to use for the x axis annotation outline. Leave unset for an automatic value.
            */
        function () {
            return brushToString(this.i.n6);
        },
        set: function (v) {
            this.i.n6 = stringToBrush(v);
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgxCrosshairLayerComponent.prototype, "xAxisAnnotationPadding", {
        /**
         * Gets or sets the padding for the x axis annotation backing. Leave unset for an automatic value.
        */
        get: /**
             * Gets or sets the padding for the x axis annotation backing. Leave unset for an automatic value.
            */
        function () {
            return this.i.mq;
        },
        set: function (v) {
            this.i.mq = +v;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgxCrosshairLayerComponent.prototype, "xAxisAnnotationStrokeThickness", {
        /**
         * Gets or sets the stroke thickness for the x axis annotation backing. Leave unset for an automatic value.
        */
        get: /**
             * Gets or sets the stroke thickness for the x axis annotation backing. Leave unset for an automatic value.
            */
        function () {
            return this.i.mr;
        },
        set: function (v) {
            this.i.mr = +v;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgxCrosshairLayerComponent.prototype, "yAxisAnnotationTextColor", {
        /**
         * Gets or sets the color to use for the y axis annotation text. Leave unset for an automatic value.
        */
        get: /**
             * Gets or sets the color to use for the y axis annotation text. Leave unset for an automatic value.
            */
        function () {
            return brushToString(this.i.oa);
        },
        set: function (v) {
            this.i.oa = stringToBrush(v);
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgxCrosshairLayerComponent.prototype, "yAxisAnnotationBackground", {
        /**
         * Gets or sets the color to use for the y axis annotation backing. Leave unset for an automatic value.
        */
        get: /**
             * Gets or sets the color to use for the y axis annotation backing. Leave unset for an automatic value.
            */
        function () {
            return brushToString(this.i.n8);
        },
        set: function (v) {
            this.i.n8 = stringToBrush(v);
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgxCrosshairLayerComponent.prototype, "yAxisAnnotationInterpolatedValuePrecision", {
        /**
         * Gets or sets the precision to use displaying values for interpolated crosshair positions.
        */
        get: /**
             * Gets or sets the precision to use displaying values for interpolated crosshair positions.
            */
        function () {
            return this.i.mv;
        },
        set: function (v) {
            this.i.mv = +v;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgxCrosshairLayerComponent.prototype, "yAxisAnnotationOutline", {
        /**
         * Gets or sets the color to use for the y axis annotation outline. Leave unset for an automatic value.
        */
        get: /**
             * Gets or sets the color to use for the y axis annotation outline. Leave unset for an automatic value.
            */
        function () {
            return brushToString(this.i.n9);
        },
        set: function (v) {
            this.i.n9 = stringToBrush(v);
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgxCrosshairLayerComponent.prototype, "yAxisAnnotationPadding", {
        /**
         * Gets or sets the padding for the y axis annotation backing. Leave unset for an automatic value.
        */
        get: /**
             * Gets or sets the padding for the y axis annotation backing. Leave unset for an automatic value.
            */
        function () {
            return this.i.ms;
        },
        set: function (v) {
            this.i.ms = +v;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgxCrosshairLayerComponent.prototype, "yAxisAnnotationStrokeThickness", {
        /**
         * Gets or sets the stroke thickness for the y axis annotation backing. Leave unset for an automatic value.
        */
        get: /**
             * Gets or sets the stroke thickness for the y axis annotation backing. Leave unset for an automatic value.
            */
        function () {
            return this.i.mt;
        },
        set: function (v) {
            this.i.mt = +v;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgxCrosshairLayerComponent.prototype, "verticalLineVisibility", {
        /**
         * Gets or sets whether to display the vertical line.
        */
        get: /**
             * Gets or sets whether to display the vertical line.
            */
        function () {
            return this.i.oc;
        },
        set: function (v) {
            this.i.oc = ensureEnum(Visibility_$type, v);
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgxCrosshairLayerComponent.prototype, "horizontalLineVisibility", {
        /**
         * Gets or sets whether to display the horizontal line.
        */
        get: /**
             * Gets or sets whether to display the horizontal line.
            */
        function () {
            return this.i.ob;
        },
        set: function (v) {
            this.i.ob = ensureEnum(Visibility_$type, v);
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgxCrosshairLayerComponent.prototype, "skipUnknownValues", {
        /**
         * Gets or sets whether to skip unknown values when searching for series values.
        */
        get: /**
             * Gets or sets whether to skip unknown values when searching for series values.
            */
        function () {
            return this.i.mm;
        },
        set: function (v) {
            this.i.mm = ensureBool(v);
        },
        enumerable: true,
        configurable: true
    });
    IgxCrosshairLayerComponent.decorators = [
        { type: Component, args: [{
                    selector: 'igx-crosshair-layer',
                    template: "",
                    providers: [{ provide: IgxAnnotationLayerComponent, useExisting: forwardRef(function () { return IgxCrosshairLayerComponent; }) }, { provide: IgxSeriesComponent, useExisting: forwardRef(function () { return IgxCrosshairLayerComponent; }) }],
                    changeDetection: ChangeDetectionStrategy.OnPush
                },] },
    ];
    /** @nocollapse */
    IgxCrosshairLayerComponent.ctorParameters = function () { return []; };
    IgxCrosshairLayerComponent.propDecorators = {
        "horizontalLineStroke": [{ type: Input },],
        "verticalLineStroke": [{ type: Input },],
        "targetSeries": [{ type: Input },],
        "useInterpolation": [{ type: Input },],
        "isAxisAnnotationEnabled": [{ type: Input },],
        "xAxisAnnotationTextColor": [{ type: Input },],
        "xAxisAnnotationBackground": [{ type: Input },],
        "xAxisAnnotationInterpolatedValuePrecision": [{ type: Input },],
        "xAxisAnnotationOutline": [{ type: Input },],
        "xAxisAnnotationPadding": [{ type: Input },],
        "xAxisAnnotationStrokeThickness": [{ type: Input },],
        "yAxisAnnotationTextColor": [{ type: Input },],
        "yAxisAnnotationBackground": [{ type: Input },],
        "yAxisAnnotationInterpolatedValuePrecision": [{ type: Input },],
        "yAxisAnnotationOutline": [{ type: Input },],
        "yAxisAnnotationPadding": [{ type: Input },],
        "yAxisAnnotationStrokeThickness": [{ type: Input },],
        "verticalLineVisibility": [{ type: Input },],
        "horizontalLineVisibility": [{ type: Input },],
        "skipUnknownValues": [{ type: Input },],
    };
    return IgxCrosshairLayerComponent;
}(IgxAnnotationLayerComponent));
export { IgxCrosshairLayerComponent };
//# sourceMappingURL=igx-crosshair-layer-component.js.map