/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import * as tslib_1 from "tslib";
import { Injector, ComponentFactoryResolver, Component, Renderer2, ViewChild, ContentChildren, QueryList, Inject, Input, forwardRef, NgZone, ChangeDetectionStrategy, ViewContainerRef } from '@angular/core';
import { DOCUMENT } from '@angular/platform-browser';
import { IgxAxisComponent } from './igx-axis-component';
import { IgxSeriesComponent } from './igx-series-component';
import { GridMode, GridMode_$type } from './GridMode';
import { IgxSeriesViewerComponent } from './igx-series-viewer-component';
import { AngularRenderer, AngularWrapper } from "igniteui-angular-core/ES5/angular-renderer";
import { TypeRegistrar } from "igniteui-angular-core/ES5/type";
import { XamDataChart } from './XamDataChart';
import { CollectionAdapter, brushToString, stringToBrush, fromBrushCollection, toBrushCollection, ensureBool, ensureEnum } from "igniteui-angular-core/ES5/componentUtil";
import { DataChartStylingDefaults } from './DataChartStylingDefaults';
import { DataContext } from "igniteui-angular-core/ES5/igx-data-context";
import { SeriesCollection } from './igx-series-collection';
import { NotifyCollectionChangedAction } from "igniteui-angular-core/ES5/NotifyCollectionChangedAction";
import { AxisCollection } from './igx-axis-collection';
export var IgxDataChartComponent_PROVIDERS = [{ provide: IgxSeriesViewerComponent, useExisting: forwardRef(function () { return IgxDataChartComponent; }) }];
/**
 * Represents a chart area containing axes, series, an optional legend and other hosted content.
*/
var IgxDataChartComponent = /** @class */ (function (_super) {
    tslib_1.__extends(IgxDataChartComponent, _super);
    function IgxDataChartComponent(_renderer, _document, _elRef, _ngZone, _componentFactoryResolver, _injector) {
        var _this = _super.call(this) || this;
        _this._renderer = _renderer;
        _this._document = _document;
        _this._elRef = _elRef;
        _this._ngZone = _ngZone;
        _this._componentFactoryResolver = _componentFactoryResolver;
        _this._injector = _injector;
        /**
             * The series actually present in the chart. Do not directly modify this array.
             * This array's contents can be modified by causing Angular to reproject the child content.
             * Or adding and removing series from the manual series collection on the series property.
             */
        _this.actualSeries = [];
        /**
             * The axes actually present in the chart. Do not directly modify this array.
             * This array's contents can be modified by causing Angular to reproject the child content.
             * Or adding and removing axes from the manual axes collection on the axes property.
             */
        _this.actualAxes = [];
        _this._series = null;
        _this._axes = null;
        _this._dataSource = null;
        _this._axesAdapter = null;
        _this._seriesAdapter = null;
        _this._defaultTooltips = null;
        _this._zoneRunner = function (act) { return _this._ngZone.run(act); };
        _this._container = _renderer.createElement("div");
        _renderer.appendChild(_elRef.element.nativeElement, _this._container);
        _renderer.setStyle(_this._container, "display", "block");
        _renderer.setStyle(_this._container, "width", "100%");
        _renderer.setStyle(_this._container, "height", "100%");
        var root;
        root = _this._container;
        if (_this._container.nativeElement != null) {
            root = _this._container.nativeElement;
        }
        var ren = new AngularRenderer(root, _this._renderer, _this._document, _this._ngZone, true, DataChartStylingDefaults);
        _this._wrapper = ren;
        var chart = _this.i;
        _this._chart = chart;
        chart.provideContainer(ren);
        ren.addSizeWatcher(function () {
            _this._chart.notifyContainerResized();
        });
        return _this;
    }
    Object.defineProperty(IgxDataChartComponent.prototype, "height", {
        get: function () {
            return this._height;
        },
        set: function (value) {
            this._height = value;
            this._renderer.setStyle(this._elRef.element.nativeElement, "height", value);
            this._chart.notifyContainerResized();
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgxDataChartComponent.prototype, "width", {
        get: function () {
            return this._width;
        },
        set: function (value) {
            this._width = value;
            this._renderer.setStyle(this._elRef.element.nativeElement, "width", value);
            this._chart.notifyContainerResized();
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgxDataChartComponent.prototype, "series", {
        /**
         * A collection or manually added series for the chart.
        */
        get: /**
             * A collection or manually added series for the chart.
            */
        function () {
            var _this = this;
            if (this._series === null) {
                var coll = new SeriesCollection();
                var inner = coll._innerColl;
                inner.addListener(function (sender, e) {
                    switch (e.action) {
                        case NotifyCollectionChangedAction.Add:
                            _this._seriesAdapter.addManualItem(e.newItems.item(0));
                            break;
                        case NotifyCollectionChangedAction.Remove:
                            _this._seriesAdapter.removeManualItemAt(e.oldStartingIndex);
                            break;
                        case NotifyCollectionChangedAction.Replace:
                            _this._seriesAdapter.removeManualItemAt(e.oldStartingIndex);
                            _this._seriesAdapter.insertManualItem(e.newStartingIndex, e.newItems.item(0));
                            break;
                        case NotifyCollectionChangedAction.Reset:
                            _this._seriesAdapter.clearManualItems();
                            break;
                    }
                });
                this._series = coll;
            }
            return this._series;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgxDataChartComponent.prototype, "axes", {
        /**
         * A collection or manually added axes for the chart.
        */
        get: /**
             * A collection or manually added axes for the chart.
            */
        function () {
            var _this = this;
            if (this._axes === null) {
                var coll = new AxisCollection();
                var inner = coll._innerColl;
                inner.addListener(function (sender, e) {
                    switch (e.action) {
                        case NotifyCollectionChangedAction.Add:
                            _this._axesAdapter.addManualItem(e.newItems.item(0));
                            break;
                        case NotifyCollectionChangedAction.Remove:
                            _this._axesAdapter.removeManualItemAt(e.oldStartingIndex);
                            break;
                        case NotifyCollectionChangedAction.Replace:
                            _this._axesAdapter.removeManualItemAt(e.oldStartingIndex);
                            _this._axesAdapter.insertManualItem(e.newStartingIndex, e.newItems.item(0));
                            break;
                        case NotifyCollectionChangedAction.Reset:
                            _this._axesAdapter.clearManualItems();
                            break;
                    }
                });
                this._axes = coll;
            }
            return this._axes;
        },
        enumerable: true,
        configurable: true
    });
    IgxDataChartComponent.prototype.ngOnDestroy = function () {
        this._chart.destroy();
        this._wrapper.destroy();
    };
    IgxDataChartComponent.prototype.createImplementation = function () {
        return new XamDataChart();
    };
    Object.defineProperty(IgxDataChartComponent.prototype, "dataSource", {
        get: function () {
            return this._dataSource;
        },
        set: function (value) {
            this._dataSource = value;
            this.bindData();
        },
        enumerable: true,
        configurable: true
    });
    IgxDataChartComponent.prototype.bindData = function () {
        //console.log("binding data: " + this._dataSource);
        if (this.actualAxes && this.actualAxes.length > 0) {
            var currAxes = this.actualAxes;
            for (var i = 0; i < currAxes.length; i++) {
                currAxes[i].provideData(this._dataSource);
            }
        }
        if (this.actualSeries && this.actualSeries.length > 0) {
            var currSeries = this.actualSeries;
            for (var i = 0; i < currSeries.length; i++) {
                currSeries[i].provideData(this._dataSource);
            }
        }
    };
    IgxDataChartComponent.prototype.ngAfterContentInit = function () {
        var _this = this;
        if (TypeRegistrar.isRegistered("IgxDataChartDefaultTooltipsComponent")) {
            var c = TypeRegistrar.get("IgxDataChartDefaultTooltipsComponent");
            var cf = this._componentFactoryResolver.resolveComponentFactory(c);
            var cr_1 = this._dynamicContent.createComponent(cf);
            //let cr = cf.create(this._injector);
            this._defaultTooltips = cr_1;
            cr_1.instance.onContentReady.subscribe(function () {
                _this._onDefaultTooltipsReady(cr_1);
            });
            //this._container.appendChild(cr.location.nativeElement);
        }
        this._axesAdapter = new CollectionAdapter(this.contentAxes, this.i.axes, this.actualAxes, function (c) { return c.i; }, function (i) { i._provideRenderer(_this._wrapper); i.provideData(_this._dataSource); }, function (i) { i._provideRenderer(null); i.provideData(null); });
        this._seriesAdapter = new CollectionAdapter(this.contentSeries, this.i.series, this.actualSeries, function (c) { return c.i; }, function (i) {
            i.owner = _this;
            i._provideRenderer(_this._dataSource);
            i.provideData(_this._dataSource);
            //i.bindAxes(this.axes);
            //i.bindAxes(this.axes);
            _this._ensureDefaultTooltip(i);
            _this._ensureTooltipCreated(i);
        }, function (i) { i._provideRenderer(null); i.provideData(null); });
        this.i.notifyContainerResized();
    };
    IgxDataChartComponent.prototype._ensureTooltipCreated = function (series) {
        var _this = this;
        series._ensureTooltipCreated(function () { return _this.createTooltip(); }, function (ele) {
            var wrapper = new AngularWrapper(ele, _this._renderer, _this._ngZone);
            wrapper.updateToolTip = ele.updateToolTip;
            wrapper.hideToolTip = ele.hideToolTip;
            return wrapper;
        });
    };
    IgxDataChartComponent.prototype._ensureDefaultTooltip = function (series) {
        if (this._defaultTooltips == null) {
            return;
        }
        this._defaultTooltips.instance["ensureDefaultTooltip"](series);
    };
    IgxDataChartComponent.prototype._onDefaultTooltipsReady = function (cr) {
        if (this.actualSeries && this.actualSeries.length > 0) {
            var currSeries = this.actualSeries;
            for (var i = 0; i < currSeries.length; i++) {
                if (currSeries[i].showDefaultTooltip) {
                    this._ensureDefaultTooltip(currSeries[i]);
                }
            }
        }
    };
    IgxDataChartComponent.prototype.createTooltip = function () {
        if (!TypeRegistrar.isRegistered("IgxTooltipContainerComponent")) {
            return null;
        }
        var t = TypeRegistrar.get("IgxTooltipContainerComponent");
        var cf = this._componentFactoryResolver.resolveComponentFactory(t);
        //let cr = cf.create(this._injector);
        var cr = this._dynamicContent.createComponent(cf);
        var ele = cr.location.nativeElement;
        var self = this;
        ele.updateToolTip = function (c) {
            if (c.externalObject) {
                c = c.externalObject;
            }
            else {
                var ext = new DataContext();
                ext._implementation = c;
                c = ext;
            }
            if (ele.parentElement != self._container) {
                if (ele.parentElement != null) {
                    ele.parentElement.removeChild(ele);
                }
                self._container.appendChild(ele);
            }
            cr.instance.context = c;
            ele.style.display = "block";
            return true;
        };
        ele.hideToolTip = function () {
            ele.style.display = "none";
        };
        ele.style.display = "none";
        return cr;
    };
    Object.defineProperty(IgxDataChartComponent.prototype, "i", {
        get: function () {
            return this._implementation;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgxDataChartComponent.prototype, "isSquare", {
        /**
     * Gets or sets whether to use a square aspect ratio for the chart. This is locked to true for polar and radial charts.
    */
        get: /**
             * Gets or sets whether to use a square aspect ratio for the chart. This is locked to true for polar and radial charts.
            */
        function () {
            return this.i.nm;
        },
        set: function (v) {
            this.i.nm = ensureBool(v);
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgxDataChartComponent.prototype, "windowScaleHorizontal", {
        /**
         * A number between 0 and 1 determining the scale of the horizontal zoom.
         * This property is effectively a shortcut to the Width of the WindowRect property.
        */
        get: /**
             * A number between 0 and 1 determining the scale of the horizontal zoom.
             * This property is effectively a shortcut to the Width of the WindowRect property.
            */
        function () {
            return this.i.n5;
        },
        set: function (v) {
            this.i.n5 = +v;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgxDataChartComponent.prototype, "windowScaleVertical", {
        /**
         * A number between 0 and 1 determining the scale of the vertical zoom.
         * This property is effectively a shortcut to the Height of the WindowRect property.
        */
        get: /**
             * A number between 0 and 1 determining the scale of the vertical zoom.
             * This property is effectively a shortcut to the Height of the WindowRect property.
            */
        function () {
            return this.i.n6;
        },
        set: function (v) {
            this.i.n6 = +v;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgxDataChartComponent.prototype, "actualWindowScaleHorizontal", {
        /**
         * A number between 0 and 1 determining the scale of the horizontal zoom.
         * This property is effectively a shortcut to the Width of the ActualWindowRect property.
        */
        get: /**
             * A number between 0 and 1 determining the scale of the horizontal zoom.
             * This property is effectively a shortcut to the Width of the ActualWindowRect property.
            */
        function () {
            return this.i.nx;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgxDataChartComponent.prototype, "actualWindowScaleVertical", {
        /**
         * A number between 0 and 1 determining the scale of the vertical zoom.
         * This property is effectively a shortcut to the Height of the ActualWindowRect property.
        */
        get: /**
             * A number between 0 and 1 determining the scale of the vertical zoom.
             * This property is effectively a shortcut to the Height of the ActualWindowRect property.
            */
        function () {
            return this.i.ny;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgxDataChartComponent.prototype, "isHorizontalZoomEnabled", {
        /**
         * Gets or sets horizontal zoomability of the current control
        */
        get: /**
             * Gets or sets horizontal zoomability of the current control
            */
        function () {
            return this.i.nl;
        },
        set: function (v) {
            this.i.nl = ensureBool(v);
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgxDataChartComponent.prototype, "isVerticalZoomEnabled", {
        /**
         * Gets or sets vertical zoomability of the current control
        */
        get: /**
             * Gets or sets vertical zoomability of the current control
            */
        function () {
            return this.i.nn;
        },
        set: function (v) {
            this.i.nn = ensureBool(v);
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgxDataChartComponent.prototype, "gridMode", {
        /**
         * Gets or sets how grid lines are rendered in relation to series.
        */
        get: /**
             * Gets or sets how grid lines are rendered in relation to series.
            */
        function () {
            return this.i.na;
        },
        set: function (v) {
            this.i.na = ensureEnum(GridMode_$type, v);
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgxDataChartComponent.prototype, "alignsGridLinesToPixels", {
        /**
         * Gets or sets a value indicating whether grid and tick lines are aligned to device pixels.
        */
        get: /**
             * Gets or sets a value indicating whether grid and tick lines are aligned to device pixels.
            */
        function () {
            return this.i.nh;
        },
        set: function (v) {
            this.i.nh = ensureBool(v);
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgxDataChartComponent.prototype, "brushes", {
        /**
         * Gets or sets the palette of brushes to use for coloring the chart series.
        */
        get: /**
             * Gets or sets the palette of brushes to use for coloring the chart series.
            */
        function () {
            return fromBrushCollection(this.i.m3);
        },
        set: function (v) {
            this.i.m3 = toBrushCollection(v);
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgxDataChartComponent.prototype, "markerBrushes", {
        /**
         * Gets or sets the MarkerBrushes property.
         * The brushes property defines the palette from which automatically assigned series brushes are selected.
        */
        get: /**
             * Gets or sets the MarkerBrushes property.
             * The brushes property defines the palette from which automatically assigned series brushes are selected.
            */
        function () {
            return fromBrushCollection(this.i.m4);
        },
        set: function (v) {
            this.i.m4 = toBrushCollection(v);
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgxDataChartComponent.prototype, "outlines", {
        /**
         * Gets or sets the palette of brushes to use for outlines on the chart series.
        */
        get: /**
             * Gets or sets the palette of brushes to use for outlines on the chart series.
            */
        function () {
            return fromBrushCollection(this.i.m6);
        },
        set: function (v) {
            this.i.m6 = toBrushCollection(v);
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgxDataChartComponent.prototype, "markerOutlines", {
        /**
         * Gets or sets the MarkerOutlines property.
         * The brushes property defines the palette from which automatically assigned series brushes are selected.
        */
        get: /**
             * Gets or sets the MarkerOutlines property.
             * The brushes property defines the palette from which automatically assigned series brushes are selected.
            */
        function () {
            return fromBrushCollection(this.i.m5);
        },
        set: function (v) {
            this.i.m5 = toBrushCollection(v);
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgxDataChartComponent.prototype, "defaultAxisStroke", {
        /**
         * Gets or sets the DefaultAxisStroke property.
         * The DefaultAxisStroke property defines the brush which is used by the axes when no Axis.Stroke is set.
        */
        get: /**
             * Gets or sets the DefaultAxisStroke property.
             * The DefaultAxisStroke property defines the brush which is used by the axes when no Axis.Stroke is set.
            */
        function () {
            return brushToString(this.i.pi);
        },
        set: function (v) {
            this.i.pi = stringToBrush(v);
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgxDataChartComponent.prototype, "defaultAxisMajorStroke", {
        /**
         * Gets or sets the DefaultAxisMajorStroke property.
         * The DefaultAxisMajorStroke property defines the brush which is used by the axes when no Axis.MajorStroke is set.
        */
        get: /**
             * Gets or sets the DefaultAxisMajorStroke property.
             * The DefaultAxisMajorStroke property defines the brush which is used by the axes when no Axis.MajorStroke is set.
            */
        function () {
            return brushToString(this.i.pg);
        },
        set: function (v) {
            this.i.pg = stringToBrush(v);
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgxDataChartComponent.prototype, "defaultAxisMinorStroke", {
        /**
         * Gets or sets the DefaultAxisMinorStroke property.
         * The DefaultAxisMinorStroke property defines the brush which is used by the axes when no Axis.MinorStroke is set.
        */
        get: /**
             * Gets or sets the DefaultAxisMinorStroke property.
             * The DefaultAxisMinorStroke property defines the brush which is used by the axes when no Axis.MinorStroke is set.
            */
        function () {
            return brushToString(this.i.ph);
        },
        set: function (v) {
            this.i.ph = stringToBrush(v);
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgxDataChartComponent.prototype, "plotAreaMarginLeft", {
        /**
         * Margin applied to the left of the plot area.
        */
        get: /**
             * Margin applied to the left of the plot area.
            */
        function () {
            return this.i.n2;
        },
        set: function (v) {
            this.i.n2 = +v;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgxDataChartComponent.prototype, "plotAreaMarginTop", {
        /**
         * Margin applied above the plot area.
        */
        get: /**
             * Margin applied above the plot area.
            */
        function () {
            return this.i.n4;
        },
        set: function (v) {
            this.i.n4 = +v;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgxDataChartComponent.prototype, "plotAreaMarginRight", {
        /**
         * Margin applied to the right of the plot area.
        */
        get: /**
             * Margin applied to the right of the plot area.
            */
        function () {
            return this.i.n3;
        },
        set: function (v) {
            this.i.n3 = +v;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgxDataChartComponent.prototype, "plotAreaMarginBottom", {
        /**
         * Margin applied below the plot area.
        */
        get: /**
             * Margin applied below the plot area.
            */
        function () {
            return this.i.n1;
        },
        set: function (v) {
            this.i.n1 = +v;
        },
        enumerable: true,
        configurable: true
    });
    /**
 * Notifies the chart that the CSS styles in effect have been updated.

*/
    /**
         * Notifies the chart that the CSS styles in effect have been updated.
        
        */
    IgxDataChartComponent.prototype.styleUpdated = /**
         * Notifies the chart that the CSS styles in effect have been updated.
        
        */
    function () {
        this.i.oy();
    };
    /**
     * Export serialized visual data.
    
    */
    /**
         * Export serialized visual data.
        
        */
    IgxDataChartComponent.prototype.exportSerializedVisualData = /**
         * Export serialized visual data.
        
        */
    function () {
        var iv = this.i.og();
        return (iv);
    };
    IgxDataChartComponent.decorators = [
        { type: Component, args: [{
                    selector: 'igx-data-chart',
                    template: "<ng-container #dynamicContent></ng-container>",
                    changeDetection: ChangeDetectionStrategy.OnPush,
                    providers: [{ provide: IgxSeriesViewerComponent, useExisting: forwardRef(function () { return IgxDataChartComponent; }) }],
                    styles: ["\n\t\t:host {\n\t\t\tdisplay: block;\n\t\t}\n\t"]
                },] },
    ];
    /** @nocollapse */
    IgxDataChartComponent.ctorParameters = function () { return [
        { type: Renderer2, },
        { type: undefined, decorators: [{ type: Inject, args: [DOCUMENT,] },] },
        { type: ViewContainerRef, },
        { type: NgZone, },
        { type: ComponentFactoryResolver, },
        { type: Injector, },
    ]; };
    IgxDataChartComponent.propDecorators = {
        "contentAxes": [{ type: ContentChildren, args: [IgxAxisComponent,] },],
        "contentSeries": [{ type: ContentChildren, args: [IgxSeriesComponent,] },],
        "_dynamicContent": [{ type: ViewChild, args: ["dynamicContent", { read: ViewContainerRef },] },],
        "height": [{ type: Input },],
        "width": [{ type: Input },],
        "dataSource": [{ type: Input },],
        "isSquare": [{ type: Input },],
        "windowScaleHorizontal": [{ type: Input },],
        "windowScaleVertical": [{ type: Input },],
        "isHorizontalZoomEnabled": [{ type: Input },],
        "isVerticalZoomEnabled": [{ type: Input },],
        "gridMode": [{ type: Input },],
        "alignsGridLinesToPixels": [{ type: Input },],
        "brushes": [{ type: Input },],
        "markerBrushes": [{ type: Input },],
        "outlines": [{ type: Input },],
        "markerOutlines": [{ type: Input },],
        "defaultAxisStroke": [{ type: Input },],
        "defaultAxisMajorStroke": [{ type: Input },],
        "defaultAxisMinorStroke": [{ type: Input },],
        "plotAreaMarginLeft": [{ type: Input },],
        "plotAreaMarginTop": [{ type: Input },],
        "plotAreaMarginRight": [{ type: Input },],
        "plotAreaMarginBottom": [{ type: Input },],
    };
    return IgxDataChartComponent;
}(IgxSeriesViewerComponent));
export { IgxDataChartComponent };
//# sourceMappingURL=igx-data-chart-component.js.map