import * as tslib_1 from "tslib";
import { Component, forwardRef, Input, ChangeDetectionStrategy } from '@angular/core';
import { IgxSeriesComponent } from "./igx-series-component";
import { FinalValueSelectionMode, FinalValueSelectionMode_$type } from "./FinalValueSelectionMode";
import { IgxAnnotationLayerComponent } from "./igx-annotation-layer-component";
import { FinalValueLayer } from "./FinalValueLayer";
import { ensureEnum, brushToString, stringToBrush } from "igniteui-angular-core/ES5/componentUtil";
/**
 * Represents an annotation layer that displays crosshair lines that cross through the closest value of the target series under the cursor.
*/
export var IgxFinalValueLayerComponent_PROVIDERS = [{ provide: IgxAnnotationLayerComponent, useExisting: forwardRef(function () { return IgxFinalValueLayerComponent; }) }, { provide: IgxSeriesComponent, useExisting: forwardRef(function () { return IgxFinalValueLayerComponent; }) }];
var IgxFinalValueLayerComponent = /** @class */ (function (_super) {
    tslib_1.__extends(IgxFinalValueLayerComponent, _super);
    function IgxFinalValueLayerComponent() {
        return _super.call(this) || this;
    }
    IgxFinalValueLayerComponent.prototype.createImplementation = function () {
        return new FinalValueLayer();
    };
    Object.defineProperty(IgxFinalValueLayerComponent.prototype, "i", {
        get: function () {
            return this._implementation;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgxFinalValueLayerComponent.prototype, "targetSeries", {
        /**
         * Gets or sets the series to target this annotation to. If null, this annotation targets all series simultaneously.
        */
        get: /**
             * Gets or sets the series to target this annotation to. If null, this annotation targets all series simultaneously.
            */
        function () {
            if (this.i.ml == null) {
                return null;
            }
            return this.i.ml.externalObject;
        },
        set: function (v) {
            v == null ? this.i.ml = null : this.i.ml = v.i;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgxFinalValueLayerComponent.prototype, "finalValueSelectionMode", {
        /**
         * Gets or sets how to select the final value to annotate.
        */
        get: /**
             * Gets or sets how to select the final value to annotate.
            */
        function () {
            return this.i.mk;
        },
        set: function (v) {
            this.i.mk = ensureEnum(FinalValueSelectionMode_$type, v);
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgxFinalValueLayerComponent.prototype, "axisAnnotationTextColor", {
        /**
         * Gets or sets the color to use for the axis annotation text. Leave unset for an automatic value.
        */
        get: /**
             * Gets or sets the color to use for the axis annotation text. Leave unset for an automatic value.
            */
        function () {
            return brushToString(this.i.nb);
        },
        set: function (v) {
            this.i.nb = stringToBrush(v);
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgxFinalValueLayerComponent.prototype, "axisAnnotationBackground", {
        /**
         * Gets or sets the color to use for the axis annotation backing. Leave unset for an automatic value.
        */
        get: /**
             * Gets or sets the color to use for the axis annotation backing. Leave unset for an automatic value.
            */
        function () {
            return brushToString(this.i.m9);
        },
        set: function (v) {
            this.i.m9 = stringToBrush(v);
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgxFinalValueLayerComponent.prototype, "axisAnnotationInterpolatedValuePrecision", {
        /**
         * Gets or sets the precision to use displaying values for interpolated crosshair positions.
        */
        get: /**
             * Gets or sets the precision to use displaying values for interpolated crosshair positions.
            */
        function () {
            return this.i.mq;
        },
        set: function (v) {
            this.i.mq = +v;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgxFinalValueLayerComponent.prototype, "axisAnnotationOutline", {
        /**
         * Gets or sets the color to use for the axis annotation outline. Leave unset for an automatic value.
        */
        get: /**
             * Gets or sets the color to use for the axis annotation outline. Leave unset for an automatic value.
            */
        function () {
            return brushToString(this.i.na);
        },
        set: function (v) {
            this.i.na = stringToBrush(v);
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgxFinalValueLayerComponent.prototype, "axisAnnotationPadding", {
        /**
         * Gets or sets the padding for the axis annotation backing. Leave unset for an automatic value.
        */
        get: /**
             * Gets or sets the padding for the axis annotation backing. Leave unset for an automatic value.
            */
        function () {
            return this.i.mo;
        },
        set: function (v) {
            this.i.mo = +v;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgxFinalValueLayerComponent.prototype, "axisAnnotationStrokeThickness", {
        /**
         * Gets or sets the stroke thickness for the axis annotation backing. Leave unset for an automatic value.
        */
        get: /**
             * Gets or sets the stroke thickness for the axis annotation backing. Leave unset for an automatic value.
            */
        function () {
            return this.i.mp;
        },
        set: function (v) {
            this.i.mp = +v;
        },
        enumerable: true,
        configurable: true
    });
    IgxFinalValueLayerComponent.decorators = [
        { type: Component, args: [{
                    selector: 'igx-final-value-layer',
                    template: "",
                    providers: [{ provide: IgxAnnotationLayerComponent, useExisting: forwardRef(function () { return IgxFinalValueLayerComponent; }) }, { provide: IgxSeriesComponent, useExisting: forwardRef(function () { return IgxFinalValueLayerComponent; }) }],
                    changeDetection: ChangeDetectionStrategy.OnPush
                },] },
    ];
    /** @nocollapse */
    IgxFinalValueLayerComponent.ctorParameters = function () { return []; };
    IgxFinalValueLayerComponent.propDecorators = {
        "targetSeries": [{ type: Input },],
        "finalValueSelectionMode": [{ type: Input },],
        "axisAnnotationTextColor": [{ type: Input },],
        "axisAnnotationBackground": [{ type: Input },],
        "axisAnnotationInterpolatedValuePrecision": [{ type: Input },],
        "axisAnnotationOutline": [{ type: Input },],
        "axisAnnotationPadding": [{ type: Input },],
        "axisAnnotationStrokeThickness": [{ type: Input },],
    };
    return IgxFinalValueLayerComponent;
}(IgxAnnotationLayerComponent));
export { IgxFinalValueLayerComponent };
//# sourceMappingURL=igx-final-value-layer-component.js.map