import { OnDestroy, EventEmitter, TemplateRef, AfterViewInit, ViewContainerRef, Injector, ComponentFactoryResolver, Renderer2, QueryList, ElementRef, NgZone } from '@angular/core';
import { FinancialChart } from './FinancialChart';
import { FinancialChartType } from './FinancialChartType';
import { IgxXYChartComponent } from './igx-xy-chart-component';
import { DataSeriesType } from "igniteui-angular-core/ES5/DataSeriesType";
import { FinancialChartVolumeType } from './FinancialChartVolumeType';
import { FinancialChartXAxisMode } from './FinancialChartXAxisMode';
import { FinancialChartYAxisMode } from './FinancialChartYAxisMode';
import { HorizontalAlignment } from "igniteui-angular-core/ES5/HorizontalAlignment";
import { AxisLabelsLocation } from './AxisLabelsLocation';
import { FinancialChartZoomSliderType } from './FinancialChartZoomSliderType';
import { IgxFinancialChartDefaultTemplatesComponent } from './igx-financial-chart-default-templates';
import { IgxTemplateContentComponent } from "igniteui-angular-core/ES5/igx-template-content-component";
import { FinancialIndicatorTypeCollection } from './igx-financial-indicator-type-collection';
import { FinancialOverlayTypeCollection } from './igx-financial-overlay-type-collection';
import { IndicatorDisplayTypeCollection } from './igx-indicator-display-type-collection';
import { FinancialChartRangeSelectorOptionCollection } from './igx-financial-chart-range-selector-option-collection';
import { FinancialChartCustomIndicatorArgs } from './igx-financial-chart-custom-indicator-args';
import { CustomIndicatorNameCollection } from './igx-custom-indicator-name-collection';
export declare const IgxFinancialChartComponent_PROVIDERS: any[];
/**
 * Represents a chart with an ordinal X-axis and a numeric Y-axis.
*/
export declare class IgxFinancialChartComponent extends IgxXYChartComponent implements AfterViewInit, OnDestroy {
    private renderer;
    private _elRef;
    private document;
    private ngZone;
    private injector;
    private componentFactoryResolver;
    container: Element;
    _dynamicContent: ViewContainerRef;
    _defaultTemplates: IgxFinancialChartDefaultTemplatesComponent;
    _templates: QueryList<IgxTemplateContentComponent>;
    _toolbarElement: ElementRef;
    _mainElement: ElementRef;
    private _height;
    private _width;
    height: string;
    width: string;
    rangeSelectorTemplate: TemplateRef<any>;
    trendlinePickerTemplate: TemplateRef<any>;
    overlayPickerTemplate: TemplateRef<any>;
    chartTypePickerTemplate: TemplateRef<any>;
    volumeTypePickerTemplate: TemplateRef<any>;
    indicatorPickerTemplate: TemplateRef<any>;
    toolbarTemplate: TemplateRef<any>;
    chartTemplate: TemplateRef<any>;
    private _wrapper;
    constructor(renderer: Renderer2, _elRef: ViewContainerRef, document: any, ngZone: NgZone, injector: Injector, componentFactoryResolver: ComponentFactoryResolver);
    private _checkToolbarSize();
    ngOnDestroy(): void;
    private onDocumentClick(ev);
    private rewrapAxis(axis);
    protected createImplementation(): FinancialChart;
    readonly i: FinancialChart;
    protected createSeriesComponent(type: string): any;
    protected createIndicator(typeName: string): any;
    protected createOverlay(typeName: string): any;
    protected createSeries(type: DataSeriesType): any;
    protected createXAxis(type: FinancialChartXAxisMode): any;
    protected createYAxis(type: FinancialChartYAxisMode): any;
    private _chart;
    private _dataSource;
    dataSource: Array<any>;
    bindData(): void;
    private _defaultTooltips;
    ngAfterViewInit(): void;
    private _createZoomSlider(hostEle);
    private createTooltip();
    private _ensureTooltipCreated(series);
    private _ensureDefaultTooltip(series);
    private _onDefaultTooltipsReady(cr);
    leftMargin: number;
    isHorizontalZoomEnabled: boolean;
    toolbarHeight: number;
    /**
     * Gets or sets whether the Y-axis should use a logarithmic scale instead of a linear one.
     * Since log(-1) is imaginary and log(0) is undefined, it is recommended to enable this property only when the Y-axis minimum is greater than zero.
    */
    yAxisIsLogarithmic: boolean;
    /**
     * Gets or sets the base value to use in the log function when mapping the position of data items along the Y-axis.
     * This property is effective only when YAxisIsLogarithmic is true.
    */
    yAxisLogarithmBase: number;
    /**
     * Gets or sets the distance between each label and grid line along the Y-axis.
    */
    yAxisInterval: number;
    /**
     * Gets or sets the data value corresponding to the minimum value of the Y-axis.
    */
    yAxisMinimumValue: number;
    /**
     * Gets or sets the data value corresponding to the maximum value of the Y-axis.
    */
    yAxisMaximumValue: number;
    /**
     * Gets or sets the frequency of displayed minor lines along the Y-axis.
    */
    yAxisMinorInterval: number;
    /**
     * Gets the current minimum value for the Y-axis.
    */
    readonly yAxisActualMinimum: number;
    /**
     * Gets the current maximum value for the Y-axis.
    */
    readonly yAxisActualMaximum: number;
    /**
     * The type of series to display in the volume pane.
    */
    volumeType: FinancialChartVolumeType;
    /**
     * The scaling mode of the X-axis.
    */
    xAxisMode: FinancialChartXAxisMode;
    /**
     * The scaling mode of the Y-axis.
    */
    yAxisMode: FinancialChartYAxisMode;
    /**
     * A boolean property controlling the visibility of the toolbar.
    */
    isToolbarVisible: boolean;
    /**
     * The type of price series to display in the main chart.
    */
    chartType: FinancialChartType;
    /**
     * Gets or sets Horizontal alignment of Y-axis labels.
    */
    yAxisLabelHorizontalAlignment: HorizontalAlignment;
    /**
     * A boolean indicating whether the chart should automatically zoom in vertically on the currently visible range of data.
     * When this property is set to true, panning and zooming along the X-axis will result in a corresponding zoom on the Y-axis, so that the visible range of data fills the zoom window as fully as possible.
    */
    isWindowSyncedToVisibleRange: boolean;
    private _indicatorTypes;
    /**
     * A collection indicating what financial indicator types to display on the Financial Chart.
    */
    indicatorTypes: FinancialIndicatorTypeCollection;
    private _overlayTypes;
    /**
     * A collection indicating what financial overlay types to display on the Financial Chart.
    */
    overlayTypes: FinancialOverlayTypeCollection;
    /**
     * Gets or sets whether the large numbers on the Y-axis labels are abbreviated.
    */
    yAxisAbbreviateLargeNumbers: boolean;
    /**
     * Gets or sets the rendering resolution for all series in this chart.
     * Where n = Resolution, for every n horizontal pixels, combine all items into a single datapoint.  When Resolution = 0, all datapoints will be rendered as graphical objects.  Charts with a higher resolution will have faster performance.
    */
    resolution: number;
    /**
     * The location of Y-axis labels, relative to the plot area.
    */
    yAxisLabelLocation: AxisLabelsLocation;
    /**
     * The type of series to display in the zoom slider pane.
    */
    zoomSliderType: FinancialChartZoomSliderType;
    /**
     * Gets or sets the palette used for coloring negative items of Waterfall chart type.
    */
    negativeBrushes: string[];
    /**
     * Brushes to use for drawing negative elements, when using a chart type with contextual coloring, such as Waterfall.
    */
    negativeOutlines: string[];
    /**
     * Brushes to use for filling financial overlays.
    */
    overlayBrushes: string[];
    /**
     * Brushes to use for outlining financial overlays.
    */
    overlayOutlines: string[];
    /**
     * Brushes to use for outlining volume series in the volume pane.
    */
    volumeOutlines: string[];
    /**
     * Brushes to use for filling volume series in the volume pane.
    */
    volumeBrushes: string[];
    /**
     * Brushes to use for negative elements in financial indicators.
    */
    indicatorNegativeBrushes: string[];
    /**
     * Brushes to use for financial indicators.
    */
    indicatorBrushes: string[];
    /**
     * The outline thickness of volume series in the volume pane.
    */
    volumeThickness: number;
    /**
     * The outline thickness of financial overlays.
    */
    overlayThickness: number;
    /**
     * The outline or stroke thickness of financial indicators.
    */
    indicatorThickness: number;
    private _indicatorDisplayTypes;
    /**
     * The display types of financial indicators.
    */
    indicatorDisplayTypes: IndicatorDisplayTypeCollection;
    /**
     * The period of financial indicators, where applicable.
    */
    indicatorPeriod: number;
    /**
     * The multiplier of financial indicators, where applicable.
    */
    indicatorMultiplier: number;
    /**
     * The smoothing period of financial indicators, where applicable.
    */
    indicatorSmoothingPeriod: number;
    /**
     * The short period of financial indicators, where applicable.
    */
    indicatorShortPeriod: number;
    /**
     * The long period of financial indicators, where applicable.
    */
    indicatorLongPeriod: number;
    /**
     * The signal period of financial indicators, where applicable.
    */
    indicatorSignalPeriod: number;
    private _rangeSelectorOptions;
    /**
     * A FinancialChartRangeSelectorOptionCollection containing the available range selector options on the toolbar.
    */
    rangeSelectorOptions: FinancialChartRangeSelectorOptionCollection;
    private _customIndicatorNames;
    /**
     * The names of custom indicators to add to the chart.
     * When CustomIndicatorNames is set, the ApplyCustomIndicators event will be raised for each custom indicator name.
    */
    customIndicatorNames: CustomIndicatorNameCollection;
    isVerticalZoomEnabled: boolean;
    zoomSliderXAxisMajorStroke: string;
    zoomSliderXAxisMajorStrokeThickness: number;
    provideContainer(container: any): void;
    notifyInsertItem(source_: any, index: number, newItem: any): void;
    notifyRemoveItem(source_: any, index: number, oldItem: any): void;
    notifyClearItems(source_: any): void;
    notifySetItem(source_: any, index: number, oldItem: any, newItem: any): void;
    /**
     * Returns visuals as a serialized string.
    
    */
    exportSerializedVisualData(): string;
    private _applyCustomIndicators;
    /**
     * Event raised by the chart when custom indicator data is needed from the application.
     * During series rendering, event will be raised once for each value in the CustomIndicatorNames collection.
    */
    readonly applyCustomIndicators: EventEmitter<{
        sender: any;
        args: FinancialChartCustomIndicatorArgs;
    }>;
}
