import { Type } from '@angular/core';
import { IgRect } from "igniteui-angular-core/ES5/IgRect";
import { IgPoint } from "igniteui-angular-core/ES5/IgPoint";
import { TrendLineType } from "igniteui-angular-core/ES5/TrendLineType";
import { PriceDisplayType } from "./PriceDisplayType";
import { IgxFinancialSeriesComponent } from "./igx-financial-series-component";
import { IgxSeriesComponent } from "./igx-series-component";
import { FinancialPriceSeries } from "./FinancialPriceSeries";
/**
 * Represents a IgxDataChartComponent financial price series that renders as Candlestick or OHLC representations.
 * Default required members: Open, Low, High, Close
*/
export declare const IgxFinancialPriceSeriesComponent_PROVIDERS: ({
    provide: typeof IgxFinancialSeriesComponent;
    useExisting: Type<any>;
} | {
    provide: typeof IgxSeriesComponent;
    useExisting: Type<any>;
})[];
export declare class IgxFinancialPriceSeriesComponent extends IgxFinancialSeriesComponent {
    protected createImplementation(): FinancialPriceSeries;
    readonly i: FinancialPriceSeries;
    constructor();
    /**
     * Gets or sets the trend type for the current financial series.
    */
    trendLineType: TrendLineType;
    /**
     * Gets or sets the brush to use to draw the trend line.
    */
    trendLineBrush: string;
    /**
     * Gets the effective TrendLineBrush for this FinancialPriceSeries.
    */
    readonly actualTrendLineBrush: string;
    /**
     * Gets or sets the thickness of the current FinancialPriceSeries object's trend line.
    */
    trendLineThickness: number;
    /**
     * Gets or sets the trend line period for the current series.
     * The typical, and initial, value for trend line period is 7.
    */
    trendLinePeriod: number;
    /**
     * Gets or sets the display type for the current FinancialPriceSeries object.
    */
    displayType: PriceDisplayType;
    /**
     * Brush to use for outlining negative elements in the series.
    */
    negativeOutline: string;
    /**
     * If possible, will return the best available value bounding box within the series that has the best value match for the world position provided.
    
    * @param world  * The world coordinate for which to get a value bounding box for
    */
    getSeriesValueBoundingBox(world: IgPoint): IgRect;
    /**
     * Scrolls the series to display the item for the specified data item.
     * The categorySeries is scrolled by the minimum amount required to place the specified data item within
     * the central 80% of the visible axis.
    
    * @param item  * The data item (item) to scroll to.
    */
    scrollIntoView(item: any): boolean;
    /**
     * For a category plotted series, returns the current width of the items within the categories. This only returns a value if the items have some form of width (e.g. columns, bars, etc.) otherwise 0 is returned.
    
    */
    getItemSpan(): number;
    setNegativeColors(negativeBrush: string, negativeOutline: string): void;
}
