import * as tslib_1 from "tslib";
import { forwardRef, Input } from '@angular/core';
import { MarkerType, MarkerType_$type } from "./MarkerType";
import { IgxSeriesComponent } from "./igx-series-component";
import { ensureEnum, brushToString, stringToBrush } from "igniteui-angular-core/ES5/componentUtil";
/**
 * Represents the base class for series containing markers.
*/
export var IgxMarkerSeriesComponent_PROVIDERS = [{ provide: IgxSeriesComponent, useExisting: forwardRef(function () { return IgxMarkerSeriesComponent; }) }];
var IgxMarkerSeriesComponent = /** @class */ (function (_super) {
    tslib_1.__extends(IgxMarkerSeriesComponent, _super);
    function IgxMarkerSeriesComponent() {
        return _super.call(this) || this;
    }
    Object.defineProperty(IgxMarkerSeriesComponent.prototype, "i", {
        get: function () {
            return this._implementation;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgxMarkerSeriesComponent.prototype, "hasMarkers", {
        /**
         * Returns whether the current series supports visual markers.
        */
        get: /**
             * Returns whether the current series supports visual markers.
            */
        function () {
            return this.i.hasMarkers;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgxMarkerSeriesComponent.prototype, "markerType", {
        /**
         * Gets or sets the marker type for the current series object.
         * If the MarkerTemplate property is set, the setting of the MarkerType property will be ignored.
        */
        get: /**
             * Gets or sets the marker type for the current series object.
             * If the MarkerTemplate property is set, the setting of the MarkerType property will be ignored.
            */
        function () {
            return this.i.li;
        },
        set: function (v) {
            this.i.li = ensureEnum(MarkerType_$type, v);
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgxMarkerSeriesComponent.prototype, "markerTemplate", {
        /**
         * Gets or sets the MarkerTemplate for the current series object.
        */
        get: /**
             * Gets or sets the MarkerTemplate for the current series object.
            */
        function () {
            return this.i.l1;
        },
        set: function (v) {
            this.i.l1 = v;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgxMarkerSeriesComponent.prototype, "actualMarkerTemplate", {
        /**
         * Gets the effective marker template for the current series object.
        */
        get: /**
             * Gets the effective marker template for the current series object.
            */
        function () {
            return this.i.lz;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgxMarkerSeriesComponent.prototype, "markerBrush", {
        /**
         * Gets or sets the brush that specifies how the current series object's marker interiors are painted.
        */
        get: /**
             * Gets or sets the brush that specifies how the current series object's marker interiors are painted.
            */
        function () {
            return brushToString(this.i.me);
        },
        set: function (v) {
            this.i.me = stringToBrush(v);
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgxMarkerSeriesComponent.prototype, "actualMarkerBrush", {
        /**
         * Gets the effective marker brush for the current series object.
        */
        get: /**
             * Gets the effective marker brush for the current series object.
            */
        function () {
            return brushToString(this.i.mc);
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgxMarkerSeriesComponent.prototype, "markerOutline", {
        /**
         * Gets or sets the brush that specifies how the current series object's marker outlines are painted.
        */
        get: /**
             * Gets or sets the brush that specifies how the current series object's marker outlines are painted.
            */
        function () {
            return brushToString(this.i.mf);
        },
        set: function (v) {
            this.i.mf = stringToBrush(v);
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgxMarkerSeriesComponent.prototype, "actualMarkerOutline", {
        /**
         * Gets the effective marker outline for the current series object.
        */
        get: /**
             * Gets the effective marker outline for the current series object.
            */
        function () {
            return brushToString(this.i.md);
        },
        enumerable: true,
        configurable: true
    });
    IgxMarkerSeriesComponent.propDecorators = {
        "markerType": [{ type: Input },],
        "markerTemplate": [{ type: Input },],
        "markerBrush": [{ type: Input },],
        "markerOutline": [{ type: Input },],
    };
    return IgxMarkerSeriesComponent;
}(IgxSeriesComponent));
export { IgxMarkerSeriesComponent };
//# sourceMappingURL=igx-marker-series-component.js.map