import * as tslib_1 from "tslib";
import { EventEmitter, Output, Component, forwardRef, Input, ChangeDetectionStrategy } from '@angular/core';
import { delegateCombine } from "igniteui-angular-core/ES5/type";
import { TimeAxisLabelFormatCollection } from "./igx-time-axis-label-format-collection";
import { AxisRangeChangedEventArgs } from "./igx-axis-range-changed-event-args";
import { IgxCategoryXAxisComponent } from "./igx-category-x-axis-component";
import { IgxCategoryAxisBaseComponent } from "./igx-category-axis-base-component";
import { IgxAxisComponent } from "./igx-axis-component";
import { OrdinalTimeXAxis } from "./OrdinalTimeXAxis";
import { TimeAxisLabelFormatCollection as TimeAxisLabelFormatCollection_internal } from "./TimeAxisLabelFormatCollection";
import { TimeAxisLabelFormat } from "./TimeAxisLabelFormat";
import { SyncableObservableCollection$1 } from "igniteui-angular-core/ES5/SyncableObservableCollection$1";
/**
 * A horizontal axis that uses an ordinal DateTime scale.
 * On an ordinal time axis, datapoints are aligned according to their order in the ItemsSource, like a category axis.
*/
export var IgxOrdinalTimeXAxisComponent_PROVIDERS = [{ provide: IgxCategoryXAxisComponent, useExisting: forwardRef(function () { return IgxOrdinalTimeXAxisComponent; }) }, { provide: IgxCategoryAxisBaseComponent, useExisting: forwardRef(function () { return IgxOrdinalTimeXAxisComponent; }) }, { provide: IgxAxisComponent, useExisting: forwardRef(function () { return IgxOrdinalTimeXAxisComponent; }) }];
var IgxOrdinalTimeXAxisComponent = /** @class */ (function (_super) {
    tslib_1.__extends(IgxOrdinalTimeXAxisComponent, _super);
    function IgxOrdinalTimeXAxisComponent() {
        var _this = _super.call(this) || this;
        _this._labelFormats = null;
        _this._actualRangeChanged = null;
        return _this;
    }
    IgxOrdinalTimeXAxisComponent.prototype.createImplementation = function () {
        return new OrdinalTimeXAxis();
    };
    Object.defineProperty(IgxOrdinalTimeXAxisComponent.prototype, "i", {
        get: function () {
            return this._implementation;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgxOrdinalTimeXAxisComponent.prototype, "dateTimeMemberPath", {
        get: function () {
            return this.i.lq;
        },
        set: function (v) {
            this.i.lq = v;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgxOrdinalTimeXAxisComponent.prototype, "labelFormats", {
        /**
         * A list of axis label formats to apply, which are selected according to the visible axis range.
         * The label format selected will be the one with the largest range smaller than the visible range of the axis.
        */
        get: /**
             * A list of axis label formats to apply, which are selected according to the visible axis range.
             * The label format selected will be the one with the largest range smaller than the visible range of the axis.
            */
        function () {
            if (this._labelFormats === null) {
                var coll = new TimeAxisLabelFormatCollection();
                var innerColl = this.i.ld;
                var wasNull = false;
                if (!innerColl) {
                    wasNull = true;
                    innerColl = new TimeAxisLabelFormatCollection_internal();
                }
                this._labelFormats = coll._fromInner(innerColl);
            }
            return this._labelFormats;
        },
        set: function (v) {
            if (this._labelFormats !== null) {
                this._labelFormats._setSyncTarget(null);
                this._labelFormats = null;
            }
            var coll = new TimeAxisLabelFormatCollection();
            this._labelFormats = coll._fromOuter(v);
            var syncColl = new SyncableObservableCollection$1(TimeAxisLabelFormat.$type);
            var innerColl = this.i.ld;
            var wasNull = false;
            if (!innerColl) {
                wasNull = true;
                innerColl = new TimeAxisLabelFormatCollection_internal();
            }
            syncColl._inner = innerColl;
            syncColl.clear();
            this._labelFormats._setSyncTarget(syncColl);
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgxOrdinalTimeXAxisComponent.prototype, "actualRangeChanged", {
        get: function () {
            var _this = this;
            if (this._actualRangeChanged == null) {
                this._actualRangeChanged = new EventEmitter();
                this.i.actualRangeChanged = delegateCombine(this.i.actualRangeChanged, function (o, e) {
                    _this._runInZone(function () {
                        var outerArgs = new AxisRangeChangedEventArgs();
                        outerArgs._provideImplementation(e);
                        _this._actualRangeChanged.emit({
                            sender: _this,
                            args: outerArgs
                        });
                    });
                });
            }
            return this._actualRangeChanged;
        },
        enumerable: true,
        configurable: true
    });
    IgxOrdinalTimeXAxisComponent.decorators = [
        { type: Component, args: [{
                    selector: 'igx-ordinal-time-x-axis',
                    template: "",
                    providers: [{ provide: IgxCategoryXAxisComponent, useExisting: forwardRef(function () { return IgxOrdinalTimeXAxisComponent; }) }, { provide: IgxCategoryAxisBaseComponent, useExisting: forwardRef(function () { return IgxOrdinalTimeXAxisComponent; }) }, { provide: IgxAxisComponent, useExisting: forwardRef(function () { return IgxOrdinalTimeXAxisComponent; }) }],
                    changeDetection: ChangeDetectionStrategy.OnPush
                },] },
    ];
    /** @nocollapse */
    IgxOrdinalTimeXAxisComponent.ctorParameters = function () { return []; };
    IgxOrdinalTimeXAxisComponent.propDecorators = {
        "dateTimeMemberPath": [{ type: Input },],
        "labelFormats": [{ type: Input },],
        "actualRangeChanged": [{ type: Output },],
    };
    return IgxOrdinalTimeXAxisComponent;
}(IgxCategoryXAxisComponent));
export { IgxOrdinalTimeXAxisComponent };
//# sourceMappingURL=igx-ordinal-time-x-axis-component.js.map